@@ -286,7 +286,7 @@ gboolean cairo_dock_add_module_to_modele (gchar *cModuleName, CairoDockModule *p
 		memset (&iter, 0, sizeof (GtkTreeIter));
 		gtk_list_store_append (GTK_LIST_STORE (pModele), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (pModele), &iter,
-			CAIRO_DOCK_MODEL_NAME, dgettext (pModule->pVisitCard->cGettextDomain, pModule->pVisitCard->cTitle),
+			CAIRO_DOCK_MODEL_NAME, pModule->pVisitCard->cTitle,
 			CAIRO_DOCK_MODEL_RESULT, cModuleName,
 			CAIRO_DOCK_MODEL_DESCRIPTION_FILE, dgettext (pModule->pVisitCard->cGettextDomain, pModule->pVisitCard->cDescription),
 			CAIRO_DOCK_MODEL_IMAGE, pModule->pVisitCard->cPreviewFilePath,
@@ -534,22 +534,12 @@ void cairo_dock_update_desklet_visibility_widgets (CairoDesklet *pDesklet, GSLis
 {
 	CairoDockGroupKeyWidget *pGroupKeyWidget;
 	GtkWidget *pOneWidget;
-	Window Xid = GDK_WINDOW_XID (pDesklet->container.pWidget->window);
-	/*gboolean bIsAbove=FALSE, bIsBelow=FALSE;
-	cairo_dock_xwindow_is_above_or_below (Xid, &bIsAbove, &bIsBelow);  // gdk_window_get_state bugue.
-	gboolean bIsUtility = cairo_dock_window_is_utility (Xid);*/
-	gboolean bIsSticky = cairo_dock_xwindow_is_sticky (Xid);
+	gboolean bIsSticky = cairo_dock_desklet_is_sticky (pDesklet);
+	CairoDeskletVisibility iVisibility = pDesklet->iVisibility;
 	
 	pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, "Desklet", "accessibility");
 	g_return_if_fail (pGroupKeyWidget != NULL && pGroupKeyWidget->pSubWidgetList != NULL);
 	pOneWidget = pGroupKeyWidget->pSubWidgetList->data;
-	CairoDeskletVisibility iVisibility;
-	/*if (bIsAbove) 						iVisibility = CAIRO_DESKLET_KEEP_ABOVE;
-	else if (bIsBelow) 					iVisibility = CAIRO_DESKLET_KEEP_BELOW;
-	else if (bIsUtility) 				iVisibility = CAIRO_DESKLET_ON_WIDGET_LAYER;
-	else if (pDesklet->bSpaceReserved)  iVisibility = CAIRO_DESKLET_RESERVE_SPACE;
-	else 								iVisibility = CAIRO_DESKLET_NORMAL;*/
-	iVisibility = pDesklet->iVisibility;
 	gtk_combo_box_set_active (GTK_COMBO_BOX (pOneWidget), iVisibility);
 	
 	pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, "Desklet", "sticky");
