@@ -43,9 +43,10 @@
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-gui-items.h"
 
-#define CAIRO_DOCK_LAUNCHER_PANEL_WIDTH 1150
+#define CAIRO_DOCK_LAUNCHER_PANEL_WIDTH 1200
 #define CAIRO_DOCK_LAUNCHER_PANEL_HEIGHT 700
 #define CAIRO_DOCK_LEFT_PANE_MIN_WIDTH 100
+#define CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH 340
 #define CAIRO_DOCK_RIGHT_PANE_MIN_WIDTH 800
 
 extern gchar *g_cCurrentLaunchersPath;
@@ -71,6 +72,7 @@ typedef enum {
 	CD_MODEL_NB_COLUMNS
 	} CDModelColumns;
 
+
   ///////////////
  // CALLBACKS //
 ///////////////
@@ -384,7 +386,7 @@ static gboolean _on_select_one_item_in_tree (GtkTreeSelection * selection, GtkTr
 				FALSE,  // vertical packaging
 				0,  // no info bar
 				cDefaultMessage,
-				CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_LOGO,
+				CAIRO_DOCK_SHARE_DATA_DIR"/images/"CAIRO_DOCK_LOGO,
 				pDataGarbage);
 			g_free (cDefaultMessage);
 		}
@@ -394,16 +396,6 @@ static gboolean _on_select_one_item_in_tree (GtkTreeSelection * selection, GtkTr
 		//g_print ("on presente %s...\n", pIcon->cDesktopFileName);
 		gchar *cConfFilePath = (*pIcon->cDesktopFileName == '/' ? g_strdup (pIcon->cDesktopFileName) : g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, pIcon->cDesktopFileName));
 		
-		// update launcher's conf file to get possible new keys/comments.
-		CairoDockDesktopFileType iLauncherType;
-		if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
-			iLauncherType = CAIRO_DOCK_DESKTOP_FILE_FOR_SEPARATOR;
-		else if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pIcon))
-			iLauncherType = CAIRO_DOCK_DESKTOP_FILE_FOR_CONTAINER;
-		else
-			iLauncherType = CAIRO_DOCK_DESKTOP_FILE_FOR_LAUNCHER;
-		cairo_dock_update_launcher_desktop_file (cConfFilePath, iLauncherType);
-		
 		// build launcher's widgets
 		pDataGarbage = g_ptr_array_new ();
 		s_pCurrentLauncherWidget = cairo_dock_build_conf_file_widget (cConfFilePath,
@@ -467,7 +459,7 @@ static void _add_one_icon_to_model (Icon *pIcon, GtkTreeStore *model, GtkTreeIte
 			if (cImagePath == NULL || ! g_file_test (cImagePath, G_FILE_TEST_EXISTS))
 			{
 				g_free (cImagePath);
-				cImagePath = g_strdup (CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_DEFAULT_ICON_NAME);
+				cImagePath = g_strdup (CAIRO_DOCK_SHARE_DATA_DIR"/icons/"CAIRO_DOCK_DEFAULT_ICON_NAME);
 			}
 		}
 	}
@@ -487,7 +479,7 @@ static void _add_one_icon_to_model (Icon *pIcon, GtkTreeStore *model, GtkTreeIte
 	if (CAIRO_DOCK_IS_USER_SEPARATOR (pIcon))  // separator
 		cName = "---------";
 	else if (CAIRO_DOCK_IS_APPLET (pIcon))  // applet
-		cName = dgettext (pIcon->pModuleInstance->pModule->pVisitCard->cGettextDomain, pIcon->pModuleInstance->pModule->pVisitCard->cTitle);
+		cName = pIcon->pModuleInstance->pModule->pVisitCard->cTitle;
 	else  // launcher
 		cName = (pIcon->cInitialName ? pIcon->cInitialName : pIcon->cName);
 	
@@ -595,8 +587,15 @@ static GtkTreeModel *_build_tree_model (void)
 	cairo_dock_foreach_desklet ((CairoDockForeachDeskletFunc) _add_one_desklet_to_model, model);
 	cairo_dock_foreach_module ((GHRFunc)_add_one_module_to_model, model);
 	CairoDockModule *pModule = cairo_dock_find_module_from_name ("Help");
-	CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
-	_add_one_module ("Help", pModuleInstance, model);
+	if (pModule != NULL)
+	{
+		if (pModule->pInstancesList == NULL)  // Help is not active, so is not already in the icons list.
+		{
+			///CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
+			///_add_one_module ("Help", pModuleInstance, model);
+			/// add it ...
+		}
+	}
 	return GTK_TREE_MODEL (model);
 }
 
@@ -733,6 +732,8 @@ static GtkWidget *show_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockMo
 	
 	if (g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] < CAIRO_DOCK_LAUNCHER_PANEL_WIDTH)  // ecran trop petit, on va essayer de reserver au moins R pixels pour le panneau de droite (avec un minimum de L pixels pour celui de gauche).
 		gtk_paned_set_position (GTK_PANED (s_pLauncherPane), MAX (CAIRO_DOCK_LEFT_PANE_MIN_WIDTH, w - CAIRO_DOCK_RIGHT_PANE_MIN_WIDTH));
+	else  // we set a default width rather than letting GTK guess the best, because the right panel is more important than the left one.
+		gtk_paned_set_position (GTK_PANED (s_pLauncherPane), CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH);
 	
 	gtk_widget_show_all (s_pLauncherWindow);
 	
