@@ -50,7 +50,7 @@
 #define CAIRO_DOCK_NB_BUTTONS_BY_ROW 4
 #define CAIRO_DOCK_NB_BUTTONS_BY_ROW_MIN 3
 #define CAIRO_DOCK_TABLE_MARGIN 12
-#define CAIRO_DOCK_CONF_PANEL_WIDTH 1150
+#define CAIRO_DOCK_CONF_PANEL_WIDTH 1250
 #define CAIRO_DOCK_CONF_PANEL_WIDTH_MIN 800
 #define CAIRO_DOCK_CONF_PANEL_HEIGHT 700
 #define CAIRO_DOCK_PREVIEW_WIDTH 200
@@ -61,7 +61,6 @@
 #define CAIRO_DOCK_PLUGINS_EXTRAS_URL "http://extras.glx-dock.org"
 
 extern CairoDockDesktopGeometry g_desktopGeometry;
-extern gboolean g_bEnterHelpOnce;
 extern int g_iMajorVersion, g_iMinorVersion, g_iMicroVersion;
 
 extern gchar *g_cConfFile;
@@ -152,21 +151,24 @@ static GtkWidget *cairo_dock_present_group_widget (const gchar *cConfFilePath, C
 
 gchar *_get_valid_module_conf_file (CairoDockModule *pModule)
 {
-	if (pModule->pInstancesList != NULL)
+	if (pModule->pInstancesList != NULL)  // module is already instanciated, take the first instance's conf-file.
 	{
 		CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
 		return g_strdup (pModuleInstance->cConfFilePath);
 	}
-	else
+	else if (pModule->pVisitCard->cConfFileName != NULL)  // not instanciated yet, take a conf-file in the module's user dir, or the default conf-file.
 	{
-		//gchar *cUserDataDirPath = g_strdup_printf ("%s/plug-ins/%s", g_cCurrentThemePath, pModule->pVisitCard->cUserDataDir);
+		// open the module's user dir.
 		gchar *cUserDataDirPath = cairo_dock_check_module_conf_dir (pModule);
+		cd_debug ("cUserDataDirPath: %s", cUserDataDirPath);
 		GDir *dir = g_dir_open (cUserDataDirPath, 0, NULL);
 		if (dir == NULL)
 		{
 			g_free (cUserDataDirPath);
 			return NULL;
 		}
+		
+		// look for a conf-file.
 		const gchar *cFileName;
 		gchar *cInstanceFilePath = NULL;
 		while ((cFileName = g_dir_read_name (dir)) != NULL)
@@ -180,17 +182,20 @@ gchar *_get_valid_module_conf_file (CairoDockModule *pModule)
 			break;
 		}
 		g_dir_close (dir);
-		if (cInstanceFilePath == NULL)  // no conf file present yet, let's copy the default one into the applet's folder.
+		// if no conf-file, copy the default one into the folder and take this one.
+		if (cInstanceFilePath == NULL)  // no conf file present yet.
 		{
-			gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pModule->cConfFilePath, cUserDataDirPath);
+			gboolean r = cairo_dock_copy_file (pModule->cConfFilePath, cUserDataDirPath);
+			/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pModule->cConfFilePath, cUserDataDirPath);
 			int r = system (cCommand);
-			g_free (cCommand);
-			if (r == 0)
+			g_free (cCommand);*/
+			if (r)  // copy ok
 				cInstanceFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, pModule->pVisitCard->cConfFileName);
 		}
 		g_free (cUserDataDirPath);
 		return cInstanceFilePath;
 	}
+	return NULL;
 }
 
 static GString *sBuffer = NULL;
@@ -441,7 +446,8 @@ void cairo_dock_apply_filter_on_group_list (gchar **pKeyWords, gboolean bAllWord
 	if (sBuffer == NULL)
 		sBuffer = g_string_new ("");
 	CairoDockGroupDescription *pGroupDescription, *pInternalGroupDescription;
-	gchar *cKeyWord, *str = NULL, *cModifiedText = NULL, *cDescription, *cToolTip = NULL;
+	gchar *cKeyWord, *str = NULL, *cModifiedText = NULL;
+	const gchar *cDescription, *cToolTip = NULL;
 	gboolean bFound, bFrameVisible;
 	GtkWidget *pGroupBox, *pLabel, *pCategoryFrame, *pCurrentCategoryFrame = NULL;
 	GKeyFile *pKeyFile;
@@ -482,7 +488,7 @@ void cairo_dock_apply_filter_on_group_list (gchar **pKeyWords, gboolean bAllWord
 		cGettextDomain = pGroupDescription->cGettextDomain;
 		bFound = FALSE;
 		
-		cDescription = dgettext (cGettextDomain, pGroupDescription->cTitle);
+		cDescription = pGroupDescription->cTitle;
 		if (bSearchInToolTip)
 			cToolTip = dgettext (cGettextDomain, pGroupDescription->cDescription);
 		//g_print ("cDescription : %s (%s)(%x,%x)\n", cDescription, cToolTip, cModifiedText, str);
@@ -578,11 +584,11 @@ void cairo_dock_apply_filter_on_group_list (gchar **pKeyWords, gboolean bAllWord
 				for (iNbWords = 0; pKeyWords[iNbWords] != NULL; iNbWords ++);
 				gboolean *bFoundWords = g_new0 (gboolean , iNbWords);
 				
-				gchar *cUsefulComment;
+				const gchar *cUsefulComment;
 				gchar iElementType;
 				guint iNbElements;
 				gchar **pAuthorizedValuesList;
-				gchar *cTipString;
+				const gchar *cTipString;
 				gboolean bIsAligned;
 				gchar **pKeyList;
 				gchar *cGroupName, *cKeyName, *cKeyComment;
@@ -1263,7 +1269,7 @@ static inline GtkWidget *_make_image (const gchar *cImage, int iSize)
 			if (!g_file_test (cIconPath, G_FILE_TEST_EXISTS))
 			{
 				g_free (cIconPath);
-				cIconPath = g_strconcat (CAIRO_DOCK_SHARE_DATA_DIR"/", cImage, NULL);
+				cIconPath = g_strconcat (CAIRO_DOCK_SHARE_DATA_DIR"/icons/", cImage, NULL);
 			}
 		}
 		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size (cIconPath ? cIconPath : cImage, iSize, iSize, NULL);
@@ -1342,7 +1348,7 @@ static inline CairoDockGroupDescription *_add_group_button (const gchar *cGroupN
 			if (!g_file_test (cIconPath, G_FILE_TEST_EXISTS))
 			{
 				g_free (cIconPath);
-				cIconPath = g_strconcat (CAIRO_DOCK_SHARE_DATA_DIR"/", cIcon, NULL);
+				cIconPath = g_strconcat (CAIRO_DOCK_SHARE_DATA_DIR"/icons/", cIcon, NULL);
 			}
 		}
 	}
@@ -1384,7 +1390,7 @@ static inline CairoDockGroupDescription *_add_group_button (const gchar *cGroupN
 	GtkWidget *pButtonHBox = gtk_hbox_new (FALSE, CAIRO_DOCK_FRAME_MARGIN);
 	GtkWidget *pImage = _make_image (cIconPath, CAIRO_DOCK_GROUP_ICON_SIZE);
 	gtk_box_pack_start (GTK_BOX (pButtonHBox), pImage, FALSE, FALSE, 0);
-	pGroupDescription->pLabel = gtk_label_new (dgettext (pGroupDescription->cGettextDomain, pGroupDescription->cTitle));
+	pGroupDescription->pLabel = gtk_label_new (pGroupDescription->cTitle);
 	gtk_box_pack_start (GTK_BOX (pButtonHBox),
 		pGroupDescription->pLabel,
 		FALSE,
@@ -1474,28 +1480,28 @@ static void _add_main_groups_buttons (void)
 		"icon-position.svg",
 		CAIRO_DOCK_CATEGORY_BEHAVIOR,
 		N_("Set the position of the main dock."),
-		N_("Position"));
+		_("Position"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Docks");
 	
 	pGroupDescription = _add_one_main_group_button ("Accessibility",
 		"icon-visibility.svg",
 		CAIRO_DOCK_CATEGORY_BEHAVIOR,
 		N_("Do you like your dock to be always visible,\n or on the contrary unobtrusive?\nConfigure the way you access your docks and sub-docks!"),
-		N_("Visibility"));
+		_("Visibility"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Docks");
 	
 	pGroupDescription = _add_one_main_group_button ("TaskBar",
 		"icon-taskbar.png",
 		CAIRO_DOCK_CATEGORY_BEHAVIOR,
 		N_("Display and interact with currently open windows."),
-		N_("Taskbar"));
+		_("Taskbar"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Taskbar");
 	
 	pGroupDescription = _add_one_main_group_button ("System",
 		"icon-system.svg",
 		CAIRO_DOCK_CATEGORY_BEHAVIOR,
 		N_("All of the parameters you will never want to tweak."),
-		N_("System"));
+		_("System"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Docks");
 	pGroupDescription->pManagers = g_list_prepend (pGroupDescription->pManagers, (gchar*)"Connection");
 	pGroupDescription->pManagers = g_list_prepend (pGroupDescription->pManagers, (gchar*)"Containers");
@@ -1505,14 +1511,14 @@ static void _add_main_groups_buttons (void)
 		"icon-background.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Set a background for your dock."),
-		N_("Background"));
+		_("Background"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Docks");
 	
 	pGroupDescription = _add_one_main_group_button ("Views",
 		"icon-views.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Select a view for each of your docks."),
-		N_("Views"));
+		_("Views"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Backends");
 	pGroupDescription->pExtensions = g_list_prepend (NULL, (gchar*)"dock rendering");
 	
@@ -1520,7 +1526,7 @@ static void _add_main_groups_buttons (void)
 		"icon-dialogs.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Configure text bubble appearance."),
-		N_("Dialog boxes"));
+		_("Dialog boxes"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Dialogs");
 	pGroupDescription->pExtensions = g_list_prepend (NULL, (gchar*)"dialog rendering");
 	
@@ -1528,7 +1534,7 @@ static void _add_main_groups_buttons (void)
 		"icon-desklets.png",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Applets can be displayed on your desktop as widgets."),
-		N_("Desklets"));
+		_("Desklets"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Desklets");
 	pGroupDescription->pExtensions = g_list_prepend (NULL, (gchar*)"desklet rendering");
 	
@@ -1536,14 +1542,14 @@ static void _add_main_groups_buttons (void)
 		"icon-icons.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("All about icons:\n size, reflection, icon theme,..."),
-		N_("Icons"));
+		_("Icons"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Icons");
 	
 	pGroupDescription = _add_one_main_group_button ("Indicators",
 		"icon-indicators.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Indicators are additional markers for your icons."),
-		N_("Indicators"));
+		_("Indicators"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Indicators");
 	pGroupDescription->pExtensions = g_list_prepend (NULL, (gchar*)"drop indicator");
 	
@@ -1551,7 +1557,7 @@ static void _add_main_groups_buttons (void)
 		"icon-labels.svg",
 		CAIRO_DOCK_CATEGORY_THEME,
 		N_("Define icon caption and quick-info style."),
-		N_("Captions"));
+		_("Captions"));
 	pGroupDescription->pManagers = g_list_prepend (NULL, (gchar*)"Icons");
 }
 
@@ -2287,7 +2293,7 @@ static GtkWidget *cairo_dock_present_group_widget (const gchar *cConfFilePath, C
 		// on rajoute la page du module interne en 1er dans le notebook.
 		if (pNoteBook != NULL)
 		{
-			GtkWidget *pLabel = gtk_label_new (dgettext (pGroupDescription->cGettextDomain, pGroupDescription->cTitle));
+			GtkWidget *pLabel = gtk_label_new (pGroupDescription->cTitle);
 			GtkWidget *pLabelContainer = NULL;
 			GtkWidget *pAlign = NULL;
 			if (pGroupDescription->cIcon != NULL && *pGroupDescription->cIcon != '\0')
@@ -2330,7 +2336,7 @@ static GtkWidget *cairo_dock_present_group_widget (const gchar *cConfFilePath, C
 	
 	s_pCurrentGroup = pGroupDescription;
 	
-	gtk_window_set_title (GTK_WINDOW (s_pMainWindow), dgettext (pGroupDescription->cGettextDomain, pGroupDescription->cTitle));
+	gtk_window_set_title (GTK_WINDOW (s_pMainWindow), pGroupDescription->cTitle);
 	
 	if (pInstance != NULL && pGroupDescription->load_custom_widget != NULL)
 		pGroupDescription->load_custom_widget (pInstance, pKeyFile);
@@ -2341,7 +2347,7 @@ static GtkWidget *cairo_dock_present_group_widget (const gchar *cConfFilePath, C
 	
 	//\_______________ On met a jour la frame du groupe (label + check-button).
 	GtkWidget *pLabel = gtk_label_new (NULL);
-	gchar *cLabel = g_strdup_printf ("<span font_desc=\"Sans 12\" color=\"#81728C\"><u><b>%s</b></u></span>", dgettext (pGroupDescription->cGettextDomain, pGroupDescription->cTitle));
+	gchar *cLabel = g_strdup_printf ("<span font_desc=\"Sans 12\" color=\"#81728C\"><u><b>%s</b></u></span>", pGroupDescription->cTitle);
 	gtk_label_set_markup (GTK_LABEL (pLabel), cLabel);
 	g_free (cLabel);
 	gtk_frame_set_label_widget (GTK_FRAME (s_pGroupFrame), pLabel);
@@ -2480,15 +2486,7 @@ static void cairo_dock_show_group (CairoDockGroupDescription *pGroupDescription)
 	}
 	else  // c'est un module, on recupere son fichier de conf en entier.
 	{
-		if (pModule->pInstancesList != NULL)
-		{
-			pModuleInstance = pModule->pInstancesList->data;
-			cConfFilePath = g_strdup (pModuleInstance->cConfFilePath);
-		}
-		else
-		{
-			cConfFilePath = _get_valid_module_conf_file (pModule);
-		}
+		cConfFilePath = _get_valid_module_conf_file (pModule);
 		
 		bSingleGroup = FALSE;
 	}
@@ -2520,37 +2518,9 @@ static void cairo_dock_apply_current_filter (gchar **pKeyWords, gboolean bAllWor
 }
 
 
-
-static void _present_help_from_dialog (int iClickedButton, GtkWidget *pInteractiveWidget, gpointer data, CairoDialog *pDialog)
-{
-	if (iClickedButton == 0 || iClickedButton == -1)  // click OK or press Enter.
-	{
-		CairoDockModule *pModule = cairo_dock_find_module_from_name ("Help");
-		g_return_if_fail (pModule != NULL);
-		cairo_dock_build_main_ihm (g_cConfFile, FALSE);
-		cairo_dock_present_module_gui (pModule);
-	}
-}
 static GtkWidget * show_main_gui (void)
 {
 	GtkWidget *pWindow = cairo_dock_build_main_ihm (g_cConfFile, FALSE);
-	CairoDockModule *pModule = cairo_dock_find_module_from_name ("Help");
-	if (pModule != NULL)
-	{
-		if (! g_bEnterHelpOnce)
-		{
-			Icon *pIcon = cairo_dock_get_dialogless_icon ();
-			cairo_dock_show_dialog_full (_("It appears that you've never entered the help module before.\nIf you are having difficulty configuring the dock, or if you want to customise it,\nthe Help module is here for you!\nWould you like to take a look at it now?"),
-				pIcon,
-				CAIRO_CONTAINER (g_pMainDock),
-				10e3,
-				CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON,
-				NULL,
-				(CairoDockActionOnAnswerFunc) _present_help_from_dialog,
-				NULL,
-				NULL);
-		}
-	}
 	return pWindow;
 }
 
