@@ -37,6 +37,7 @@
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-launcher-factory.h"
 #include "cairo-dock-desktop-file-factory.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-themes-manager.h"
 #include "cairo-dock-applications-manager.h"
 #include "cairo-dock-backends-manager.h"
@@ -191,11 +192,9 @@ static gchar * _make_simple_conf_file (void)
 	//\_____________ On actualise le fichier de conf simple.
 	// on cree le fichier au besoin, et on l'ouvre.
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s", g_cCurrentThemePath, CAIRO_DOCK_SIMPLE_CONF_FILE);
-	if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
+	///if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // since we remove the opengl effects params, we need to overwrite the file each time. TODO: fix this ...
 	{
-		gchar *cCommand = g_strdup_printf ("cp \"%s/%s\" \"%s\"", CAIRO_DOCK_SHARE_DATA_DIR, CAIRO_DOCK_SIMPLE_CONF_FILE, cConfFilePath);
-		int r = system (cCommand);
-		g_free (cCommand);
+		cairo_dock_copy_file (CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_SIMPLE_CONF_FILE, cConfFilePath);
 	}
 	
 	GKeyFile* pSimpleKeyFile = cairo_dock_open_key_file (cConfFilePath);
@@ -203,7 +202,9 @@ static gchar * _make_simple_conf_file (void)
 	
 	if (cairo_dock_conf_file_needs_update (pSimpleKeyFile, CAIRO_DOCK_VERSION))
 	{
-		cairo_dock_flush_conf_file (pSimpleKeyFile, cConfFilePath, CAIRO_DOCK_SHARE_DATA_DIR, CAIRO_DOCK_SIMPLE_CONF_FILE);
+		///cairo_dock_flush_conf_file (pSimpleKeyFile, cConfFilePath, CAIRO_DOCK_SHARE_DATA_DIR, CAIRO_DOCK_SIMPLE_CONF_FILE);
+		cairo_dock_upgrade_conf_file (cConfFilePath, pSimpleKeyFile, CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_SIMPLE_CONF_FILE);
+		
 		g_key_file_free (pSimpleKeyFile);
 		pSimpleKeyFile = cairo_dock_open_key_file (cConfFilePath);
 		g_return_val_if_fail (pSimpleKeyFile != NULL, NULL);
@@ -495,6 +496,7 @@ static gboolean on_apply_config_simple (gpointer data)
 	int iTaskbarType = g_key_file_get_integer (pSimpleKeyFile, "Behavior", "taskbar", NULL);
 	if (iTaskbarType != s_iTaskbarType)
 	{
+		cd_debug ("s_iTaskbarType : %d / %d", s_iTaskbarType, iTaskbarType);
 		gboolean bShowAppli = TRUE, bHideVisible, bCurrentDesktopOnly, bMixLauncherAppli, bGroupAppliByClass;
 		switch (iTaskbarType)
 		{
@@ -528,7 +530,9 @@ static gboolean on_apply_config_simple (gpointer data)
 			g_key_file_set_boolean (pKeyFile, "TaskBar", "current desktop only", bCurrentDesktopOnly);
 			g_key_file_set_boolean (pKeyFile, "TaskBar", "mix launcher appli", bMixLauncherAppli);
 			g_key_file_set_boolean (pKeyFile, "TaskBar", "group by class", bGroupAppliByClass);
+			cd_debug (" taskbar : %d; %d; %d; %d", bHideVisible, bCurrentDesktopOnly, bMixLauncherAppli, bGroupAppliByClass);
 		}
+		s_iTaskbarType = iTaskbarType;
 	}
 	
 	// animations
@@ -619,6 +623,7 @@ static gboolean on_apply_config_simple (gpointer data)
 				G_TYPE_INT, "Global", "appearance", iEffectOnDisappearance,
 				G_TYPE_INVALID);
 		}
+		s_iEffectOnDisappearance = iEffectOnDisappearance;
 	}
 	
 	g_strfreev (cOnMouseHover);
@@ -686,6 +691,7 @@ static gboolean on_apply_config_simple (gpointer data)
 	if (bSeparateIcons != s_bSeparateIcons)
 	{
 		g_key_file_set_integer (pKeyFile, "Icons", "separate_icons", (bSeparateIcons ? 3 : 0));
+		s_bSeparateIcons = bSeparateIcons;
 	}
 	
 	gchar *cIconOrder = g_key_file_get_string (pSimpleKeyFile, "Appearance", "icon's type order", NULL);
@@ -854,7 +860,7 @@ static void _make_modules_widget (GtkWidget *pSimpleConfigWindow)
 	//\______________ On construit le widget de prevue et on le rajoute a la suite.
 	gchar *cDefaultMessage = g_strdup_printf ("<b><span font_desc=\"Sans 14\">%s</span></b>", _("Click on an applet in order to have a preview and a description for it."));
 	GPtrArray *pDataGarbage = g_object_get_data (G_OBJECT (pSimpleConfigWindow), "garbage");
-	GtkWidget *pPreviewBox = cairo_dock_gui_make_preview_box (pSimpleConfigWindow, pOneWidget, FALSE, 1, cDefaultMessage, CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_LOGO, pDataGarbage);  // vertical packaging.
+	GtkWidget *pPreviewBox = cairo_dock_gui_make_preview_box (pSimpleConfigWindow, pOneWidget, FALSE, 1, cDefaultMessage, CAIRO_DOCK_SHARE_DATA_DIR"/images/"CAIRO_DOCK_LOGO, pDataGarbage);  // vertical packaging.
 	gtk_box_pack_start (GTK_BOX (myWidget->pKeyBox), pPreviewBox, FALSE, FALSE, 0);
 	g_free (cDefaultMessage);
 }
