@@ -47,7 +47,7 @@
 #include "cairo-dock-gui-themes.h"
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-dialog-manager.h"
-#include "cairo-dock-file-manager.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-log.h"
 #include "cairo-dock-desklet-factory.h"
 #include "cairo-dock-X-utilities.h"
@@ -72,6 +72,8 @@
 #define CAIRO_DOCK_SITE_URL "http://glx-dock.org"  // http://cairo-dock.vef.fr
 #define CAIRO_DOCK_FORUM_URL "http://forum.glx-dock.org"  // http://cairo-dock.vef.fr/bg_forumlist.php
 #define CAIRO_DOCK_PLUGINS_EXTRAS_URL "http://extras.glx-dock.org"
+#define CAIRO_DOCK_PAYPAL_URL "https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=UWQ3VVRB2ZTZS&lc=GB&item_name=Support%20Cairo%2dDock&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHosted"
+#define CAIRO_DOCK_FLATTR_URL "http://flattr.com/thing/370779/Support-Cairo-Dock-development"
 
 extern CairoDock *g_pMainDock;
 extern CairoDockDesktopGeometry g_desktopGeometry;
@@ -89,7 +91,6 @@ extern gboolean g_bEasterEggs;
 #define cairo_dock_icons_are_locked(...) (myDocksParam.bLockIcons || myDocksParam.bLockAll || g_bLocked)
 #define cairo_dock_is_locked(...) (myDocksParam.bLockAll || g_bLocked)
 
-
 static void _cairo_dock_edit_and_reload_conf (GtkMenuItem *pMenuItem, gpointer data)
 {
 	cairo_dock_show_main_gui ();
@@ -122,6 +123,8 @@ static void _cairo_dock_delete_dock (GtkMenuItem *pMenuItem, CairoDock *pDock)
 	if (answer != GTK_RESPONSE_YES)
 		return ;
 	
+	cairo_dock_remove_icons_from_dock (pDock, NULL, NULL);
+	
 	const gchar *cDockName = cairo_dock_search_dock_name (pDock);
 	cairo_dock_destroy_dock (pDock, cDockName);
 }
@@ -171,10 +174,16 @@ static void _cairo_dock_about (GtkMenuItem *pMenuItem, CairoContainer *pContaine
 	GtkWidget *pDialog = gtk_dialog_new_with_buttons (_("About Cairo-Dock"),
 		GTK_WINDOW (pContainer->pWidget),
 		GTK_DIALOG_DESTROY_WITH_PARENT,
-		"gtk-close",
+		GTK_STOCK_CLOSE,
 		GTK_RESPONSE_CLOSE,
 		NULL);
-	
+
+	// the dialog box is destroyed when the user responds
+	g_signal_connect_swapped (pDialog,
+		"response",
+		G_CALLBACK (gtk_widget_destroy),
+		pDialog);
+
 #if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 14)
 	GtkWidget *pContentBox = gtk_dialog_get_content_area (GTK_DIALOG(pDialog));
 #else
@@ -185,7 +194,7 @@ static void _cairo_dock_about (GtkMenuItem *pMenuItem, CairoContainer *pContaine
 	GtkWidget *pHBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (pContentBox), pHBox, FALSE, FALSE, 0);
 	
-	const gchar *cImagePath = CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_LOGO;
+	const gchar *cImagePath = CAIRO_DOCK_SHARE_DATA_DIR"/images/"CAIRO_DOCK_LOGO;
 	GtkWidget *pImage = gtk_image_new_from_file (cImagePath);
 	gtk_box_pack_start (GTK_BOX (pHBox), pImage, FALSE, FALSE, 0);
 	
@@ -195,19 +204,32 @@ static void _cairo_dock_about (GtkMenuItem *pMenuItem, CairoContainer *pContaine
 	GtkWidget *pLink = gtk_link_button_new_with_label (CAIRO_DOCK_SITE_URL, "Cairo-Dock (2007-2011)\n version "CAIRO_DOCK_VERSION);
 	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
 	
-	pLink = gtk_link_button_new_with_label (CAIRO_DOCK_FORUM_URL, _("Community site"));
-	gtk_widget_set_tooltip_text (pLink, _("Problems? Suggestions? Just want to talk to us? Come on over!"));
-	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
+	//~ pLink = gtk_link_button_new_with_label (CAIRO_DOCK_FORUM_URL, _("Community site"));
+	//~ gtk_widget_set_tooltip_text (pLink, _("Problems? Suggestions? Just want to talk to us? Come on over!"));
+	//~ gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
 	
 	pLink = gtk_link_button_new_with_label (CAIRO_DOCK_FILE_HOST_URL, _("Development site"));
 	gtk_widget_set_tooltip_text (pLink, _("Find the latest version of Cairo-Dock here !"));
 	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
 	
 	gchar *cAdress = g_strdup_printf (CAIRO_DOCK_PLUGINS_EXTRAS_URL"/%d.%d.%d", g_iMajorVersion, g_iMinorVersion, g_iMicroVersion);
-	pLink = gtk_link_button_new_with_label (cAdress, _("More applets"));
+	pLink = gtk_link_button_new_with_label (cAdress, _("Get more applets!"));
 	g_free (cAdress);
 	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
 	
+	gchar *cLabel = g_strdup_printf ("%s (Flattr)", _("Donate"));
+	pLink = gtk_link_button_new_with_label (CAIRO_DOCK_FLATTR_URL, cLabel);
+	g_free (cLabel);
+	gtk_widget_set_tooltip_text (pLink, _("Support the people who spend countless hours to bring you the best dock ever."));
+	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
+	
+	cLabel = g_strdup_printf ("%s (Paypal)", _("Donate"));
+	pLink = gtk_link_button_new_with_label (CAIRO_DOCK_PAYPAL_URL, cLabel);
+	g_free (cLabel);
+	gtk_widget_set_tooltip_text (pLink, _("Support the people who spend countless hours to bring you the best dock ever."));
+	gtk_box_pack_start (GTK_BOX (pVBox), pLink, FALSE, FALSE, 0);
+	
+	
 	// notebook
 	GtkWidget *pNoteBook = gtk_notebook_new ();
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (pNoteBook), TRUE);
@@ -216,31 +238,29 @@ static void _cairo_dock_about (GtkMenuItem *pMenuItem, CairoContainer *pContaine
 	
 	_cairo_dock_add_about_page (pNoteBook,
 		_("Development"),
-		"<b>Main developer :</b>\n  Fabounet (Fabrice Rey)\n\
-<b>Original idea/first development :</b>\n  Mac Slow\n\
-<b>Applets :</b>\n  Fabounet\n  Necropotame\n  Ctaf\n  ChAnGFu\n  Tofe\n  Paradoxxx_Zero\n  Mav\n  Nochka85\n  Ours_en_pluche\n  Eduardo Mucelli\n\
-<b>Patchs :</b>\n  Special thanks to Augur for his great help with OpenGL\n  Ctaf\n  M.Tasaka\n  Matttbe\n  Necropotame\n  Robrob\n  Smidgey\n  Tshirtman\n");
+		"<b>Main developer:</b>\n  Fabounet (Fabrice Rey)\n\
+<b>Original idea / first development:</b>\n  Mac Slow\n\
+<b>Applets:</b>\n  Fabounet\n  Necropotame\n  Ctaf\n  ChAnGFu\n  Tofe\n  Paradoxxx_Zero\n  Mav\n  Nochka85\n  Ours_en_pluche\n  Eduardo Mucelli\n\
+<b>Patches:</b>\n  Special thanks to Augur for his great help with OpenGL\n  Ctaf\n  M.Tasaka\n  Matttbe\n  Necropotame\n  Robrob\n  Smidgey\n  SQP\n  Tshirtman\n");
 	_cairo_dock_add_about_page (pNoteBook,
 		_("Artwork"),
-		"<b>Themes :</b>\n  Fabounet\n  Chilperik\n  Djoole\n  Glattering\n  Vilraleur\n  Lord Northam\n  Paradoxxx_Zero\n  Coz\n  Benoit2600\n  Nochka85\n  Taiebot65\n  Lylambda\n  MastroPino\n  Matttbe\n\
-<b>Translations :</b>\n  Fabounet\n  Ppmt \n  Jiro Kawada (Kawaji)\n  BiAji\n  Mattia Tavernini (Maathias)\n  Peter Thornqvist\n  Yannis Kaskamanidis\n  Eduardo Mucelli\n");
+		"<b>Themes:</b>\n  Fabounet\n  Chilperik\n  Djoole\n  Glattering\n  Vilraleur\n  Lord Northam\n  Paradoxxx_Zero\n  Coz\n  Benoit2600\n  Nochka85\n  Taiebot65\n  Lylambda\n  MastroPino\n  Matttbe\n\
+<b>Translations:</b>\n  Fabounet\n  Ppmt \n  Jiro Kawada (Kawaji)\n  BiAji\n  Mattia Tavernini (Maathias)\n  Peter Thornqvist\n  Yannis Kaskamanidis\n  Eduardo Mucelli\n");
 	_cairo_dock_add_about_page (pNoteBook,
 		_("Support"),
-		"<b>Installation script and web hosting :</b>\n  Mav\n\
-<b>Site (glx-dock.org) :</b>\n  Necropotame\n  Matttbe\n  Tdey\n\
-<b>LaunchPad :</b>\n  Matttbe\n  Mav\n\
-<b>Suggestions/Comments/Beta-Testers :</b>\n  AuraHxC\n  Chilperik\n  Cybergoll\n  Damster\n  Djoole\n  Glattering\n  Franksuse64\n  Mav\n  Necropotame\n  Nochka85\n  Ppmt\n  RavanH\n  Rhinopierroce\n  Rom1\n  Sombrero\n  Vilraleur");
+		"<b>Installation script and web hosting:</b>\n  Mav\n\
+<b>Site (glx-dock.org):</b>\n  Necropotame\n  Matttbe\n  Tdey\n\
+<b>LaunchPad:</b>\n  Matttbe\n  Mav\n\
+<b>Suggestions / Comments / Beta-Testers:</b>\n  AuraHxC\n  Chilperik\n  Cybergoll\n  Damster\n  Djoole\n  Glattering\n  Franksuse64\n  Mav\n  Necropotame\n  Nochka85\n  Ppmt\n  RavanH\n  Rhinopierroce\n  Rom1\n  Sombrero\n  Vilraleur");
 	
 	gtk_widget_show_all (pDialog);
-	///gtk_window_set_position (GTK_WINDOW (pDialog), GTK_WIN_POS_CENTER_ALWAYS);  // un GTK_WIN_POS_CENTER simple ne marche pas, probablement parceque la fenetre n'est pas encore realisee. le 'always' ne pose pas de probleme, puisqu'on ne peut pas redimensionner le dialogue.
 	
 	gtk_window_resize (GTK_WINDOW (pDialog),
 		MIN (CAIRO_DOCK_ABOUT_WIDTH, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]),
 		MIN (CAIRO_DOCK_ABOUT_HEIGHT, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
 	
 	gtk_window_set_keep_above (GTK_WINDOW (pDialog), TRUE);
-	gtk_dialog_run (GTK_DIALOG (pDialog));
-	gtk_widget_destroy (pDialog);
+	//don't use gtk_dialog_run(), as we don't want to block the dock
 }
 
 static void _launch_url (const gchar *cURL)
@@ -293,9 +313,10 @@ static void _cairo_dock_add_autostart (GtkMenuItem *pMenuItem, gpointer data)
 			return ;
 		}
 	}
-	gchar *cCommand = g_strdup_printf ("cp '/usr/share/applications/cairo-dock%s.desktop' '%s'", (g_bForceCairo ? "-cairo" : ""), cCairoAutoStartDirPath);
+	cairo_dock_copy_file ("/usr/share/applications/cairo-dock.desktop", cCairoAutoStartDirPath);
+	/**gchar *cCommand = g_strdup_printf ("cp '/usr/share/applications/cairo-dock%s.desktop' '%s'", (g_bForceCairo ? "-cairo" : ""), cCairoAutoStartDirPath);
 	int r = system (cCommand);
-	g_free (cCommand);
+	g_free (cCommand);*/
 	g_free (cCairoAutoStartDirPath);
 }
 
@@ -325,7 +346,9 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 	//\_________________________ On ajoute le sous-menu Cairo-Dock.
 	GtkWidget *pMenuItem, *image;
 	GdkPixbuf *pixbuf;
-	pMenuItem = gtk_image_menu_item_new_with_label ("Cairo-Dock");
+	
+	GtkWidget *pSubMenu = cairo_dock_create_sub_menu ("Cairo-Dock", menu, CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON);
+	/**pMenuItem = gtk_image_menu_item_new_with_label ("Cairo-Dock");
 	pixbuf = gdk_pixbuf_new_from_file_at_size (CAIRO_DOCK_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON, 32, 32, NULL);
 	image = gtk_image_new_from_pixbuf (pixbuf);
 	g_object_unref (pixbuf);
@@ -333,7 +356,7 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 	gtk_menu_shell_append  (GTK_MENU_SHELL (menu), pMenuItem);
 	
 	GtkWidget *pSubMenu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenu);
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenu);*/
 	
 	if (! cairo_dock_is_locked ())
 	{
@@ -363,7 +386,7 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 		if (! cairo_dock_theme_manager_is_integrated ())
 		{
 			pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("Manage themes"),
-				CAIRO_DOCK_SHARE_DATA_DIR"/icon-appearance.svg",
+				CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-appearance.svg",
 				(GFunc)_cairo_dock_initiate_theme_management,
 				pSubMenu,
 				NULL);
@@ -374,7 +397,7 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 		gtk_menu_shell_append (GTK_MENU_SHELL (pSubMenu), pMenuItem);
 		
 		pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (myDocksParam.bLockIcons ? _("Unlock icons") : _("Lock icons"),
-			CAIRO_DOCK_SHARE_DATA_DIR"/icon-lock-icons.svg",
+			CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-lock-icons.svg",
 			(GFunc)_cairo_dock_lock_icons,
 			pSubMenu, NULL);
 		gtk_widget_set_tooltip_text (pMenuItem, _("This will (un)lock the position of the icons."));
@@ -382,11 +405,18 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 	if (! g_bLocked)
 	{
 		pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (myDocksParam.bLockAll ? _("Unlock dock") : _("Lock dock"),
-			CAIRO_DOCK_SHARE_DATA_DIR"/icon-lock-icons.svg",
+			CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-lock-icons.svg",
 			(GFunc)_cairo_dock_lock_all,
 			pSubMenu,
 			NULL);
-			gtk_widget_set_tooltip_text (pMenuItem, _("This will (un)lock the whole dock."));
+			if (myDocksParam.bLockAll)
+			{
+				gtk_widget_set_tooltip_text (pMenuItem, _("This will allow you to add or remove launchers and applets, and configure the program."));
+			}
+			else
+			{
+				gtk_widget_set_tooltip_text (pMenuItem, _("This will prevent any modification of the current theme, and hide all the unnecessary entries in the menus."));
+			}
 	}
 	
 	if (CAIRO_DOCK_IS_DOCK (pContainer) && ! CAIRO_DOCK (pContainer)->bAutoHide)
@@ -414,13 +444,6 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 	g_free (cCairoAutoStartEntryPath2);
 	g_free (cCairoAutoStartDirPath);
 	
-	pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("Help"),
-		GTK_STOCK_HELP,
-		(GFunc)_cairo_dock_present_help,
-		pSubMenu,
-		NULL);
-	gtk_widget_set_tooltip_text (pMenuItem, _("There are no problems, only solutions (and a lot of useful hints!)"));
-	
 	pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("Get more applets!"),
 		GTK_STOCK_ADD,
 		(GFunc)_cairo_dock_show_third_party_applets,
@@ -428,6 +451,13 @@ gboolean cairo_dock_notification_build_container_menu (gpointer *pUserData, Icon
 		NULL);
 	gtk_widget_set_tooltip_text (pMenuItem, _("Third-party applets provide integration with many programs, like Pidgin"));
 	
+	pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("Help"),
+		GTK_STOCK_HELP,
+		(GFunc)_cairo_dock_present_help,
+		pSubMenu,
+		NULL);
+	gtk_widget_set_tooltip_text (pMenuItem, _("There are no problems, only solutions (and a lot of useful hints!)"));
+	
 	cairo_dock_add_in_menu_with_stock_and_data (_("About"),
 		GTK_STOCK_ABOUT,
 		(GFunc)_cairo_dock_about,
@@ -540,6 +570,14 @@ static void cairo_dock_add_sub_dock (GtkMenuItem *pMenuItem, gpointer *data)
 	_cairo_dock_create_launcher (icon, pDock, CAIRO_DOCK_DESKTOP_FILE_FOR_CONTAINER);
 }
 
+static gboolean _show_new_dock_msg (gchar *cDockName)
+{
+	CairoDock *pDock = cairo_dock_search_dock_from_name (cDockName);
+	if (pDock)
+		cairo_dock_show_temporary_dialog_with_default_icon (_("The new dock has been created.\nNow move some launchers or applets into it by right-clicking on the icon -> move to another dock"), NULL, CAIRO_CONTAINER (pDock), 10000);
+	g_free (cDockName);
+	return FALSE;
+}
 static void cairo_dock_add_main_dock (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	gchar *cDockName = cairo_dock_add_root_dock_config ();
@@ -548,7 +586,7 @@ static void cairo_dock_add_main_dock (GtkMenuItem *pMenuItem, gpointer *data)
 	
 	cairo_dock_gui_trigger_reload_items ();  // pas de signal "new_dock"
 	
-	cairo_dock_show_general_message (_("The new dock has been created.\nNow move some launchers or applets into it by right-clicking on the icon -> move to another dock"), 10000);  // on le place pas sur le nouveau dock, car sa fenetre n'est pas encore bien placee (0,0).
+	g_timeout_add_seconds (1, (GSourceFunc)_show_new_dock_msg, g_strdup (cDockName));  // delai, car sa fenetre n'est pas encore bien placee (0,0).
 }
 
 static void cairo_dock_add_separator (GtkMenuItem *pMenuItem, gpointer *data)
@@ -558,6 +596,11 @@ static void cairo_dock_add_separator (GtkMenuItem *pMenuItem, gpointer *data)
 	_cairo_dock_create_launcher (icon, pDock, CAIRO_DOCK_DESKTOP_FILE_FOR_SEPARATOR);
 }
 
+static void _cairo_dock_launch_class_action (GtkMenuItem *pMenuItem, gchar *cCommand)
+{
+	cairo_dock_launch_command (cCommand);
+}
+
 static void _cairo_dock_modify_launcher (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	Icon *icon = data[0];
@@ -670,7 +713,7 @@ static void _cairo_dock_remove_module_instance (GtkMenuItem *pMenuItem, gpointer
 		icon = (CAIRO_DESKLET (pContainer))->pIcon;  // l'icone cliquee du desklet n'est pas forcement celle qui contient le module !
 	g_return_if_fail (CAIRO_DOCK_IS_APPLET (icon));
 	
-	gchar *question = g_strdup_printf (_("You're about to remove this applet (%s) from the dock. Are you sure?"), icon->pModuleInstance->pModule->pVisitCard->cModuleName);
+	gchar *question = g_strdup_printf (_("You're about to remove this applet (%s) from the dock. Are you sure?"), icon->pModuleInstance->pModule->pVisitCard->cTitle);
 	int answer = cairo_dock_ask_question_and_wait (question, icon, CAIRO_CONTAINER (pContainer));
 	if (answer == GTK_RESPONSE_YES)
 	{
@@ -795,11 +838,16 @@ static void _cairo_dock_remove_custom_appli_icon (GtkMenuItem *pMenuItem, gpoint
 	CairoDock *pDock = data[1];
 	if (! CAIRO_DOCK_IS_APPLI (icon))
 		return;
-	gchar *cCustomIcon = g_strdup_printf ("%s/%s.png", g_cCurrentIconsPath, icon->cClass);
+	
+	const gchar *cClassIcon = cairo_dock_get_class_icon (icon->cClass);
+	if (cClassIcon == NULL)
+		cClassIcon = icon->cClass;
+	
+	gchar *cCustomIcon = g_strdup_printf ("%s/%s.png", g_cCurrentIconsPath, cClassIcon);
 	if (!g_file_test (cCustomIcon, G_FILE_TEST_EXISTS))
 	{
 		g_free (cCustomIcon);
-		cCustomIcon = g_strdup_printf ("%s/%s.svg", g_cCurrentIconsPath, icon->cClass);
+		cCustomIcon = g_strdup_printf ("%s/%s.svg", g_cCurrentIconsPath, cClassIcon);
 		if (!g_file_test (cCustomIcon, G_FILE_TEST_EXISTS))
 		{
 			g_free (cCustomIcon);
@@ -808,9 +856,10 @@ static void _cairo_dock_remove_custom_appli_icon (GtkMenuItem *pMenuItem, gpoint
 	}
 	if (cCustomIcon != NULL)
 	{
-		gchar *cCommand = g_strdup_printf ("rm -f \"%s\"", cCustomIcon);
+		g_remove (cCustomIcon);
+		/**gchar *cCommand = g_strdup_printf ("rm -f \"%s\"", cCustomIcon);
 		int r = system (cCommand);
-		g_free (cCommand);
+		g_free (cCommand);*/
 		cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pDock));
 		cairo_dock_redraw_icon (icon, CAIRO_CONTAINER (pDock));
 	}
@@ -861,26 +910,19 @@ static void _cairo_dock_make_launcher_from_appli (GtkMenuItem *pMenuItem, gpoint
 	
 	// on trouve le .desktop du programme.
 	cd_debug ("%s (%s)\n", __func__, icon->cClass);
-	gchar *cDesktopFilePath = g_strdup_printf ("/usr/share/applications/%s.desktop", icon->cClass);
-	if (! g_file_test (cDesktopFilePath, G_FILE_TEST_EXISTS))  // on n'a pas trouve la, on cherche chez KDE.
+	gchar *cDesktopFilePath = g_strdup (cairo_dock_get_class_desktop_file (icon->cClass));
+	if (cDesktopFilePath == NULL)
 	{
-		g_free (cDesktopFilePath);
-		cDesktopFilePath = g_strdup_printf ("/usr/share/applications/kde4/%s.desktop", icon->cClass);
-		if (! g_file_test (cDesktopFilePath, G_FILE_TEST_EXISTS))  // toujours rien, on utilise locate.
+		gchar *cCommand = g_strdup_printf ("locate /%s.desktop --limit=1 -i", icon->cClass);
+		gchar *cResult = cairo_dock_launch_command_sync (cCommand);
+		if (cResult != NULL && *cResult != '\0')
+		{
+			if (cResult[strlen (cResult) - 1] == '\n')
+				cResult[strlen (cResult) - 1] = '\0';
+			cDesktopFilePath = cResult;
+		}
+		else  // chercher un desktop qui contienne command="command from /proc"...
 		{
-			g_free (cDesktopFilePath);
-			cDesktopFilePath = NULL;
-			
-			gchar *cCommand = g_strdup_printf ("locate /%s.desktop --limit=1 -i", icon->cClass);
-			gchar *cResult = cairo_dock_launch_command_sync (cCommand);
-			if (cResult != NULL && *cResult != '\0')
-			{
-				if (cResult[strlen (cResult) - 1] == '\n')
-					cResult[strlen (cResult) - 1] = '\0';
-				cDesktopFilePath = cResult;
-				cResult = NULL;
-			}
-			// else chercher un desktop qui contiennent command=class...
 			g_free (cResult);
 		}
 	}
@@ -1170,9 +1212,7 @@ static void _add_desktops_entry (GtkWidget *pMenu, gboolean bAll, gpointer *data
 }
 static void _add_add_entry (GtkWidget *pMenu, gpointer *data, gboolean bAddSeparator, gboolean bAddLauncher)
 {
-	GtkWidget *pMenuItem = _add_entry_in_menu (_("Add"), GTK_STOCK_ADD, NULL, pMenu);
-	GtkWidget *pSubMenuAdd = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuAdd);
+	GtkWidget *pSubMenuAdd = cairo_dock_create_sub_menu (_("Add"), pMenu, GTK_STOCK_ADD);
 	
 	_add_entry_in_menu (_("Sub-dock"), GTK_STOCK_ADD, cairo_dock_add_sub_dock, pSubMenuAdd);
 	
@@ -1183,10 +1223,11 @@ static void _add_add_entry (GtkWidget *pMenu, gpointer *data, gboolean bAddSepar
 	
 	if (bAddLauncher)
 	{
-		pMenuItem = _add_entry_in_menu (_("Custom launcher"), GTK_STOCK_ADD, cairo_dock_add_launcher, pSubMenuAdd);
+		GtkWidget *pMenuItem = _add_entry_in_menu (_("Custom launcher"), GTK_STOCK_ADD, cairo_dock_add_launcher, pSubMenuAdd);
 		gtk_widget_set_tooltip_text (pMenuItem, _("Usually you would drag a launcher from the menu and drop it on the dock."));
 	}
 }
+
 gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *icon, CairoContainer *pContainer, GtkWidget *menu)
 {
 	static gpointer *data = NULL;
@@ -1201,18 +1242,31 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 	gchar *cLabel;
 	gboolean bAddSeparator = ! (CAIRO_DOCK_IS_DOCK (pContainer) && CAIRO_DOCK (pContainer)->iRefCount > 0);  // pas sur les sous-docks.
 	
-	//\_________________________ Si pas d'icone dans un dock, on s'arrete la.
+	//\_________________________ Clic en-dehors d'une icone utile => on s'arrete la.
 	if (CAIRO_DOCK_IS_DOCK (pContainer) && (icon == NULL || CAIRO_DOCK_IS_AUTOMATIC_SEPARATOR (icon)))
 	{
 		if (! cairo_dock_is_locked ())
 		{
 			Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (CAIRO_DOCK (pContainer), NULL);
-			if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pPointingIcon))
+			if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pPointingIcon) || CAIRO_DOCK (pContainer)->iRefCount == 0)
 				_add_add_entry (menu, data, TRUE, TRUE);
 		}
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	}
-
+	
+	//\_________________________ class actions.
+	if (icon && icon->cClass != NULL)
+	{
+		const GList *pClassMenuItems = cairo_dock_get_class_menu_items (icon->cClass);
+		gchar **pClassItem;
+		const GList *m;
+		for (m = pClassMenuItems; m != NULL; m = m->next)
+		{
+			pClassItem = m->data;
+			pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (pClassItem[0], pClassItem[2], (GFunc)_cairo_dock_launch_class_action, menu, pClassItem[1]);
+		}
+	}
+	
 	//\_________________________ On rajoute des actions de modifications sur le dock.
 	gboolean bAddNewEntries = FALSE;
 	if (! cairo_dock_is_locked () && CAIRO_DOCK_IS_DOCK (pContainer) && icon && (cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (CAIRO_DOCK_LAUNCHER) || cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (CAIRO_DOCK_APPLET)))
@@ -1240,9 +1294,10 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 				pMenuItem = _add_entry_in_menu (CAIRO_DOCK_IS_USER_SEPARATOR (icon) ? _("Remove this separator") : _("Remove this launcher"), GTK_STOCK_REMOVE, _cairo_dock_remove_launcher, menu);
 				gtk_widget_set_tooltip_text (pMenuItem, _("You can remove a launcher by dragging it out of the dock with the mouse ."));
 				
-				pMenuItem = _add_entry_in_menu (_("Move to another dock"), GTK_STOCK_JUMP_TO, NULL, menu);
+				GtkWidget *pSubMenuDocks = cairo_dock_create_sub_menu (_("Move to another dock"), menu, GTK_STOCK_JUMP_TO);
+				/**pMenuItem = _add_entry_in_menu (_("Move to another dock"), GTK_STOCK_JUMP_TO, NULL, menu);
 				GtkWidget *pSubMenuDocks = gtk_menu_new ();
-				gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuDocks);
+				gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuDocks);*/
 				g_object_set_data (G_OBJECT (pSubMenuDocks), "launcher", icon);
 				pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("New main dock"), GTK_STOCK_NEW, (GFunc)_cairo_dock_move_launcher_to_dock, pSubMenuDocks, NULL);
 				g_object_set_data (G_OBJECT (pMenuItem), "launcher", icon);
@@ -1264,10 +1319,11 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		//\_________________________ On rajoute les actions supplementaires sur les icones d'applis.
 		Icon *pAppli = cairo_dock_get_icon_with_Xid (icon->Xid);  // un inhibiteur ne contient pas les donnees, mais seulement la reference a l'appli, donc on recupere celle-ci pour avoir son etat.
 		
-		pMenuItem = gtk_menu_item_new_with_label (_("Other actions"));
+		GtkWidget *pSubMenuOtherActions = cairo_dock_create_sub_menu (_("Other actions"), menu, NULL);
+		/**pMenuItem = gtk_menu_item_new_with_label (_("Other actions"));
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), pMenuItem);
 		GtkWidget *pSubMenuOtherActions = gtk_menu_new ();
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuOtherActions);
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuOtherActions);*/
 		
 		pMenuItem = _add_entry_in_menu (_("Move to this desktop"), GTK_STOCK_JUMP_TO, _cairo_dock_move_appli_to_current_desktop, pSubMenuOtherActions);
 		if (pAppli && cairo_dock_appli_is_on_current_desktop (pAppli))
@@ -1296,11 +1352,15 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		{
 			if (myTaskbarParam.bOverWriteXIcons)
 			{
-				gchar *cCustomIcon = g_strdup_printf ("%s/%s.png", g_cCurrentIconsPath, icon->cClass);
+				const gchar *cClassIcon = cairo_dock_get_class_icon (icon->cClass);
+				if (cClassIcon == NULL)
+					cClassIcon = icon->cClass;
+				
+				gchar *cCustomIcon = g_strdup_printf ("%s/%s.png", g_cCurrentIconsPath, cClassIcon);
 				if (!g_file_test (cCustomIcon, G_FILE_TEST_EXISTS))
 				{
 					g_free (cCustomIcon);
-					cCustomIcon = g_strdup_printf ("%s/%s.svg", g_cCurrentIconsPath, icon->cClass);
+					cCustomIcon = g_strdup_printf ("%s/%s.svg", g_cCurrentIconsPath, cClassIcon);
 					if (!g_file_test (cCustomIcon, G_FILE_TEST_EXISTS))
 					{
 						g_free (cCustomIcon);
@@ -1328,7 +1388,7 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		
 		_add_entry_in_menu (_("Show"), GTK_STOCK_FIND, _cairo_dock_show_appli, menu);
 		
-		_add_entry_in_menu (icon->bIsMaximized ? _("Unmaximise") : _("Maximise"), icon->bIsMaximized ? CAIRO_DOCK_SHARE_DATA_DIR"/icon-restore.png" : CAIRO_DOCK_SHARE_DATA_DIR"/icon-maximize.png", _cairo_dock_maximize_appli, menu);
+		_add_entry_in_menu (icon->bIsMaximized ? _("Unmaximise") : _("Maximise"), icon->bIsMaximized ? CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-restore.svg" : CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-maximize.svg", _cairo_dock_maximize_appli, menu);
 		
 		if (! icon->bIsHidden)
 		{
@@ -1336,7 +1396,7 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 				cLabel = g_strdup_printf ("%s (%s)", _("Minimise"), _("middle-click"));
 			else
 				cLabel = g_strdup (_("Minimise"));
-			_add_entry_in_menu (cLabel, CAIRO_DOCK_SHARE_DATA_DIR"/icon-minimize.png", _cairo_dock_minimize_appli, menu);
+			_add_entry_in_menu (cLabel, CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-minimize.svg", _cairo_dock_minimize_appli, menu);
 			g_free (cLabel);
 		}
 		
@@ -1344,7 +1404,7 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 			cLabel = g_strdup_printf ("%s (%s)", _("Close"), _("middle-click"));
 		else
 			cLabel = g_strdup (_("Close"));
-		_add_entry_in_menu (cLabel, CAIRO_DOCK_SHARE_DATA_DIR"/icon-close.png", _cairo_dock_close_appli, menu);
+		_add_entry_in_menu (cLabel, CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-close.svg", _cairo_dock_close_appli, menu);
 		g_free (cLabel);
 	}
 	else if (CAIRO_DOCK_IS_MULTI_APPLI (icon))
@@ -1357,10 +1417,11 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		bAddSeparator = TRUE;
 		
 		//\_________________________ On rajoute les actions supplementaires sur la classe.
-		pMenuItem = gtk_menu_item_new_with_label (_("Other actions"));
+		GtkWidget *pSubMenuOtherActions = cairo_dock_create_sub_menu (_("Other actions"), menu, NULL);
+		/**pMenuItem = gtk_menu_item_new_with_label (_("Other actions"));
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), pMenuItem);
 		GtkWidget *pSubMenuOtherActions = gtk_menu_new ();
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuOtherActions);
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuOtherActions);*/
 		
 		_add_entry_in_menu (_("Move all to this desktop"), GTK_STOCK_JUMP_TO, _cairo_dock_move_class_to_current_desktop, pSubMenuOtherActions);
 		
@@ -1370,9 +1431,9 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		
 		_add_entry_in_menu (_("Show all"), GTK_STOCK_FIND, _cairo_dock_show_class, menu);
 
-		_add_entry_in_menu (_("Minimise all"), CAIRO_DOCK_SHARE_DATA_DIR"/icon-minimize.png", _cairo_dock_minimize_class, menu);
+		_add_entry_in_menu (_("Minimise all"), CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-minimize.svg", _cairo_dock_minimize_class, menu);
 		
-		_add_entry_in_menu (_("Close all"), CAIRO_DOCK_SHARE_DATA_DIR"/icon-close.png", _cairo_dock_close_class, menu);
+		_add_entry_in_menu (_("Close all"), CAIRO_DOCK_SHARE_DATA_DIR"/icons/icon-close.svg", _cairo_dock_close_class, menu);
 	}
 	
 	//\_________________________ On rajoute les actions sur les applets/desklets.
@@ -1412,9 +1473,10 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 			
 			if (CAIRO_DOCK_IS_DOCK (pContainer) && pIconModule->cParentDockName != NULL)  // sinon bien sur ca n'est pas la peine de presenter l'option (Cairo-Penguin par exemple)
 			{
-				pMenuItem = _add_entry_in_menu (_("Move to another dock"), GTK_STOCK_JUMP_TO, NULL, menu);
+				GtkWidget *pSubMenuDocks = cairo_dock_create_sub_menu (_("Move to another dock"), menu, GTK_STOCK_JUMP_TO);
+				/**pMenuItem = _add_entry_in_menu (_("Move to another dock"), GTK_STOCK_JUMP_TO, NULL, menu);
 				GtkWidget *pSubMenuDocks = gtk_menu_new ();
-				gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuDocks);
+				gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuDocks);*/
 				g_object_set_data (G_OBJECT (pSubMenuDocks), "launcher", pIconModule);
 				pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("New main dock"), GTK_STOCK_NEW, (GFunc)_cairo_dock_move_launcher_to_dock, pSubMenuDocks, NULL);
 				g_object_set_data (G_OBJECT (pMenuItem), "launcher", pIconModule);
@@ -1433,19 +1495,11 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		}
 		bAddSeparator = TRUE;
 		
-		pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("Visibility"), GTK_STOCK_FIND, NULL, menu, NULL);
-		GtkWidget *pSubMenuAccessibility = gtk_menu_new ();
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenuAccessibility);
+		GtkWidget *pSubMenuAccessibility = cairo_dock_create_sub_menu (_("Visibility"), menu, GTK_STOCK_FIND);
 		
 		GSList *group = NULL;
 
-		Window Xid = GDK_WINDOW_XID (pContainer->pWidget->window);
-		/*gboolean bIsAbove=FALSE, bIsBelow=FALSE;
-		cairo_dock_xwindow_is_above_or_below (Xid, &bIsAbove, &bIsBelow);  // gdk_window_get_state bugue.
-		gboolean bIsUtility = cairo_dock_window_is_utility (Xid);  // gtk_window_get_type_hint me renvoie toujours 0 !
-		gboolean bIsDock = (CAIRO_DESKLET (pContainer)->bSpaceReserved);
-		gboolean bIsNormal = (!bIsAbove && !bIsBelow && !bIsUtility && !bIsDock);*/
-		gboolean bIsSticky = cairo_dock_xwindow_is_sticky (Xid);
+		gboolean bIsSticky = cairo_dock_desklet_is_sticky (CAIRO_DESKLET (pContainer));
 		CairoDesklet *pDesklet = CAIRO_DESKLET (pContainer);
 		CairoDeskletVisibility iVisibility = pDesklet->iVisibility;
 		
@@ -1477,7 +1531,7 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 			if (iVisibility == CAIRO_DESKLET_ON_WIDGET_LAYER/*bIsUtility*/)
 				gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(pMenuItem), TRUE);
 			g_signal_connect(G_OBJECT(pMenuItem), "toggled", G_CALLBACK(_cairo_dock_keep_on_widget_layer), data);
-			gtk_widget_set_tooltip_text (pMenuItem, _("Set behaviour in Compiz to: (name=cairo-dock & type=utility)"));
+			//gtk_widget_set_tooltip_text (pMenuItem, _("Set behaviour in Compiz to: (name=cairo-dock & type=Utility)"));
 		}
 		
 		pMenuItem = gtk_radio_menu_item_new_with_label(group, _("Reserve space"));
@@ -1495,7 +1549,7 @@ gboolean cairo_dock_notification_build_icon_menu (gpointer *pUserData, Icon *ico
 		
 		pMenuItem = gtk_check_menu_item_new_with_label(_("Lock position"));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), pMenuItem);
-		if (CAIRO_DESKLET (pContainer)->bPositionLocked)
+		if (pDesklet->bPositionLocked)
 			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(pMenuItem), TRUE);
 		g_signal_connect(G_OBJECT(pMenuItem), "toggled", G_CALLBACK(_cairo_dock_lock_position), data);
 	}
