@@ -38,7 +38,7 @@
 #include "cairo-dock-desklet-factory.h"
 #include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-dialog-manager.h"
-#include "cairo-dock-file-manager.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-config.h"
@@ -182,13 +182,13 @@ static gboolean _launch_icon_command (Icon *icon, CairoDock *pDock)
 	}
 	if (! bSuccess)
 	{
-		cairo_dock_request_icon_animation (icon, pDock, "blink", 1);  // 1 blink if fail.
+		cairo_dock_request_icon_animation (icon, CAIRO_CONTAINER (pDock), "blink", 1);  // 1 blink if fail.
 	}
 	return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
 }
 gboolean cairo_dock_notification_click_icon (gpointer pUserData, Icon *icon, CairoContainer *pContainer, guint iButtonState)
 {
-	//g_print ("+ %s (%s)\n", __func__, icon ? icon->cName : "no icon");
+	//g_print ("+ %s (%s, %d)\n", __func__, icon ? icon->cCommand : "no icon", CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon));
 	if (icon == NULL || ! CAIRO_DOCK_IS_DOCK (pContainer))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	CairoDock *pDock = CAIRO_DOCK (pContainer);
@@ -208,15 +208,18 @@ gboolean cairo_dock_notification_click_icon (gpointer pUserData, Icon *icon, Cai
 	// scale on an icon holding a class sub-dock.
 	if (CAIRO_DOCK_IS_MULTI_APPLI(icon))
 	{
-		if (cairo_dock_wm_present_class (icon->cClass))
+		if ( (!myDocksParam.bShowSubDockOnClick  // if sub-docks are shown on mouse over
+		|| GTK_WIDGET_VISIBLE (icon->pSubDock->container.pWidget)  // or this sub-dock is already visible
+		|| myTaskbarParam.bPresentClassOnClick)  // or we explicitely allowed to skip the sub-dock
+		&& cairo_dock_wm_present_class (icon->cClass)) // we use the scale plugin if it's possible
 		{
-			if (icon->pSubDock)
+			if (icon->pSubDock)  // in case the dock is visible or about to be visible, hide it, as it would confuse the user to have both.
 				cairo_dock_emit_leave_signal (CAIRO_CONTAINER (icon->pSubDock));
 			return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
 		}
 	}
 	
-	// else handle sub-docks showing on click, applis and launchers.
+	// else handle sub-docks showing on click, applis and launchers (not applets).
 	if (icon->pSubDock != NULL && (myDocksParam.bShowSubDockOnClick || !GTK_WIDGET_VISIBLE (icon->pSubDock->container.pWidget)))  // icon pointing to a sub-dock with either "sub-dock activation on click" option enabled, or sub-dock not visible -> open the sub-dock
 	{
 		cairo_dock_show_subdock (icon, pDock);
@@ -322,6 +325,7 @@ gboolean cairo_dock_notification_scroll_icon (gpointer pUserData, Icon *icon, Ca
 
 gboolean cairo_dock_notification_drop_data (gpointer pUserData, const gchar *cReceivedData, Icon *icon, double fOrder, CairoContainer *pContainer)
 {
+	cd_debug ("take the drop");
 	if (! CAIRO_DOCK_IS_DOCK (pContainer))
 		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 	
@@ -329,18 +333,20 @@ gboolean cairo_dock_notification_drop_data (gpointer pUserData, const gchar *cRe
 	CairoDock *pReceivingDock = pDock;
 	if (g_str_has_suffix (cReceivedData, ".desktop"))  // .desktop -> add a new launcher if dropped on or amongst launchers. 
 	{
-		if ((myIconsParam.iSeparateIcons == 1 || myIconsParam.iSeparateIcons == 3) && CAIRO_DOCK_IS_NORMAL_APPLI (icon))
+		cd_debug (" dropped a .desktop");
+		if ((myIconsParam.iSeparateIcons == 1 || myIconsParam.iSeparateIcons == 3) && CAIRO_DOCK_ICON_TYPE_IS_APPLI (icon))
 			return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-		if ((myIconsParam.iSeparateIcons == 2 || myIconsParam.iSeparateIcons == 3) && CAIRO_DOCK_IS_APPLET (icon))
+		if ((myIconsParam.iSeparateIcons == 2 || myIconsParam.iSeparateIcons == 3) && CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon))
 			return CAIRO_DOCK_LET_PASS_NOTIFICATION;
-		if (fOrder == CAIRO_DOCK_LAST_ORDER && icon && icon->pSubDock != NULL)  // drop onto a container icon.
+		cd_debug (" add it");
+		if (fOrder == CAIRO_DOCK_LAST_ORDER && CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) && icon->pSubDock != NULL)  // drop onto a container icon.
 		{
 			pReceivingDock = icon->pSubDock;  // -> add into the pointed sub-dock.
 		}
 	}
 	else  // file.
 	{
-		if (fOrder == CAIRO_DOCK_LAST_ORDER)  // dropped on an icon
+		if (icon != NULL && fOrder == CAIRO_DOCK_LAST_ORDER)  // dropped on an icon
 		{
 			if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))  // sub-dock -> propagate to the sub-dock.
 			{
@@ -362,14 +368,14 @@ gboolean cairo_dock_notification_drop_data (gpointer pUserData, const gchar *cRe
 				g_spawn_command_line_async (cCommand, NULL);
 				g_free (cPath);
 				g_free (cCommand);
-				cairo_dock_request_icon_animation (icon, pDock, "blink", 2);
+				cairo_dock_request_icon_animation (icon, CAIRO_CONTAINER (pDock), "blink", 2);
 				return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
 			}
 			else  // skip any other case.
 			{
 				return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 			}
-		}  // else: dropped between 2 icons -> try to add it.
+		}  // else: dropped between 2 icons -> try to add it (for instance a script).
 	}
 
 	if (g_bLocked || myDocksParam.bLockAll)
@@ -387,7 +393,7 @@ void cairo_dock_set_custom_icon_on_appli (const gchar *cFilePath, Icon *icon, Ca
 	gchar *ext = strrchr (cFilePath, '.');
 	if (!ext)
 		return;
-	cd_debug ("%s (%s)", __func__, cFilePath);
+	cd_debug ("%s (%s)", __func__, cFilePath, icon->cFileName);
 	if ((strcmp (ext, ".png") == 0 || strcmp (ext, ".svg") == 0) && !myDocksParam.bLockAll && ! myDocksParam.bLockIcons)
 	{
 		if (!myTaskbarParam.bOverWriteXIcons)
@@ -405,10 +411,18 @@ void cairo_dock_set_custom_icon_on_appli (const gchar *cFilePath, Icon *icon, Ca
 			cPath = g_filename_from_uri (cFilePath, NULL, NULL);
 		}
 		
-		gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s/%s%s\"", cPath?cPath:cFilePath, g_cCurrentIconsPath, icon->cClass, ext);
+		const gchar *cClassIcon = cairo_dock_get_class_icon (icon->cClass);
+		if (cClassIcon == NULL)
+			cClassIcon = icon->cClass;
+		
+		gchar *cDestPath = g_strdup_printf ("%s/%s%s", g_cCurrentIconsPath, cClassIcon, ext);
+		cairo_dock_copy_file (cPath?cPath:cFilePath, cDestPath);
+		g_free (cDestPath);
+		g_free (cPath);
+		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s/%s%s\"", cPath?cPath:cFilePath, g_cCurrentIconsPath, icon->cClass, ext);
 		cd_debug (" -> '%s'", cCommand);
 		int r = system (cCommand);
-		g_free (cCommand);
+		g_free (cCommand);*/
 		
 		cairo_dock_reload_icon_image (icon, pContainer);
 		cairo_dock_redraw_icon (icon, pContainer);
