@@ -1,4 +1,4 @@
-/**
+/*
 * This file is a part of the Cairo-Dock project
 *
 * Copyright : (C) see the 'copyright' file.
@@ -27,51 +27,22 @@
 **    If you don't know what that means take a look at:
 **       http://www.gnu.org/licenses/licenses.html#GPL
 **
-** Original idea :
-**    Mirco Mueller, June 2006.
+*********************** VERSION 0 (2006) *********************
 **
-*********************** VERSION 0 (2006)*********************
-** author(s):
-**    Mirco "MacSlow" Mueller <macslow@bangang.de>
+** Original idea :
+**    Mirco "MacSlow" Mueller <macslow@bangang.de>, June 2006.
+** With the help of:
 **    Behdad Esfahbod <behdad@behdad.org>
 **    David Reveman <davidr@novell.com>
 **    Karl Lattimer <karl@qdh.org.uk>
+** Originally conceived as a stress-test for cairo, librsvg, and glitz.
 **
-** notes :
-**    Originally conceived as a stress-test for cairo, librsvg, and glitz.
-**
-** notes from original author:
-**
-**    I just know that some folks will bug me regarding this, so... yes there's
-**    nearly everything hard-coded, it is not nice, it is not very usable for
-**    easily (without any hard work) making a full dock-like application out of
-**    this, please don't email me asking to me to do so... for everybody else
-**    feel free to make use of it beyond this being a small but heavy stress
-**    test. I've written this on an Ubuntu-6.06 box running Xgl/compiz. The
-**    icons used are from the tango-project...
-**
-**        http://tango-project.org/
-**
-**    Over the last couple of days Behdad and David helped me (MacSlow) out a
-**    great deal by sending me additional tweaked and optimized versions. I've
-**    now merged all that with my recent additions.
-**
-*********************** VERSION 0.1.0 and above (2007-2011)*********************
+*********************** VERSION 0.1 and above (2007-2011) *********************
 **
 ** author(s) :
 **     Fabrice Rey <fabounet@glx-dock.org>
-**
-** notes :
-**     I've completely rewritten the calculation part, and the callback system.
-**     Plus added a conf file that allows to dynamically modify most of the parameters.
-**     Plus a visible zone that make the hiding/showing more friendly.
-**     Plus a menu and the drag'n'drop ability.
-**     Also I've separated functions in several files in order to make the code more readable.
-**     Now it sems more like a real dock !
-**
-**     Edit : plus a taskbar, plus an applet system,
-**            plus the container ability, plus different views, plus the top and vertical position, ...
-**
+** With the help of:
+**     A lot of people !!!
 **
 *******************************************************************************/
 
@@ -107,12 +78,13 @@
 #include "cairo-dock-file-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command_sync
+#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command
 
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-items.h"
 #include "cairo-dock-gui-backend.h"
 #include "cairo-dock-user-interaction.h"
+#include "help/cairo-dock-help.h"
 #include "cairo-dock-core.h"
 
 //#define CAIRO_DOCK_THEME_SERVER "http://themes.glx-dock.org"
@@ -125,7 +97,7 @@
 // Nom du repertoire des themes de dock.
 #define CAIRO_DOCK_THEMES_DIR "themes"
 // Nom du repertoire des themes de dock sur le serveur
-#define CAIRO_DOCK_DISTANT_THEMES_DIR "themes2.2"
+#define CAIRO_DOCK_DISTANT_THEMES_DIR "themes2.4"
 
 extern gchar *g_cCairoDockDataDir;
 extern gchar *g_cCurrentThemePath;
@@ -145,107 +117,25 @@ extern CairoDockModuleInstance *g_pCurrentModule;
 gboolean g_bForceCairo = FALSE;
 gboolean g_bLocked;
 
-static gchar *s_cLaunchCommand = NULL;
+static gboolean s_bSucessfulLaunch = FALSE;
+static GString *s_pLaunchCommand = NULL;
 static gchar *s_cLastVersion = NULL;
-gboolean g_bEnterHelpOnce = FALSE;
 static gchar *s_cDefaulBackend = NULL;
-static gboolean s_bTestComposite = TRUE;
 static gint s_iGuiMode = 0;  // 0 = simple mode, 1 = advanced mode
 static gint s_iLastYear = 0;
+static gint s_iNbCrashes = 0;
+
 
-static inline void _cancel_metacity_composite (void)
-{
-	int r = system ("gconftool-2 -s '/apps/metacity/general/compositing_manager' --type bool false");
-}
-static void _accept_metacity_composition (int iClickedButton, GtkWidget *pInteractiveWidget, gpointer data, CairoDialog *pDialog)
-{
-	cd_debug ("%s (%d)", __func__, iClickedButton);
-	if (iClickedButton == 1 || iClickedButton == -2)  // clic explicite sur "cancel", ou Echap ou auto-delete.
-	{
-		_cancel_metacity_composite ();
-	}
-	gboolean *bAccepted = data;
-	*bAccepted = TRUE;  // l'utilisateur a valide son choix.
-}
-static void _on_free_metacity_dialog (gpointer data)
-{
-	gboolean *bAccepted = data;
-	cd_debug ("%s (%d)", __func__, *bAccepted);
-	if (! *bAccepted)  // le dialogue s'est detruit sans que l'utilisateur n'ait valide la question => on annule tout.
-	{
-		_cancel_metacity_composite ();
-	}
-	g_free (data);
-}
-static void _toggle_remember_choice (GtkCheckButton *pButton, GtkWidget *pDialog)
-{
-	g_object_set_data (G_OBJECT (pDialog), "remember", GINT_TO_POINTER (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pButton))));
-}
 static gboolean _cairo_dock_successful_launch (gpointer data)
 {
-	if (g_str_has_suffix (s_cLaunchCommand, " -m"))
-		s_cLaunchCommand[strlen (s_cLaunchCommand)-3] = '\0';  // on enleve le mode maintenance.
-	
-	//\___________________ On teste le composite maintenant (au demarrage, le composite manager peut ne pas etre lance).
-	if (s_bTestComposite)
-	{
-		GdkScreen *pScreen = gdk_screen_get_default ();
-		if (! myContainersParam.bUseFakeTransparency && ! gdk_screen_is_composited (pScreen))
-		{
-			cd_warning ("no composite manager found");
-			// Si l'utilisateur utilise Metacity, on lui propose d'activer le composite.
-			gchar *cPsef = cairo_dock_launch_command_sync ("pgrep metacity");  // 'ps' ne marche pas, il faut le lancer dans un script :-/
-			if (cPsef != NULL && *cPsef != '\0')  // "metacity" a ete trouve.
-			{
-				Icon *pIcon = cairo_dock_get_dialogless_icon ();
-				GtkWidget *pAskBox = gtk_hbox_new (FALSE, 3);
-				GtkWidget *label = gtk_label_new (_("Don't ask me any more"));
-				GtkWidget *pCheckBox = gtk_check_button_new ();
-				gtk_box_pack_end (GTK_BOX (pAskBox), pCheckBox, FALSE, FALSE, 0);
-				gtk_box_pack_end (GTK_BOX (pAskBox), label, FALSE, FALSE, 0);
-				g_signal_connect (G_OBJECT (pCheckBox), "toggled", G_CALLBACK(_toggle_remember_choice), pAskBox);
-				int iClickedButton = cairo_dock_show_dialog_and_wait (_("To remove the black rectangle around the dock, you will need to activate a composite manager.\nFor instance, this can be done by activating desktop effects, launching Compiz, or activating the composition in Metacity.\nI can perform this last operation for you. Do you want to proceed ?"), pIcon, CAIRO_CONTAINER (g_pMainDock), 0., NULL, pAskBox);
-				
-				gboolean bRememberChoice = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pCheckBox));
-				gtk_widget_destroy (pAskBox); // le widget survit a un dialogue bloquant.
-				if (bRememberChoice)
-				{
-					s_bTestComposite = FALSE;
-				}
-				if (iClickedButton == 0 || iClickedButton == -1)  // ok or Enter.
-				{
-					int r = system ("gconftool-2 -s '/apps/metacity/general/compositing_manager' --type bool true");
-					///cairo_dock_show_dialog_with_question (_("Do you want to keep this setting?"), pIcon, CAIRO_CONTAINER (g_pMainDock), NULL, (CairoDockActionOnAnswerFunc) _accept_metacity_composition, NULL, NULL);
-					cairo_dock_show_dialog_full (_("Do you want to keep this setting?\nIn 15 seconds, the previous setting will be restored."), pIcon, CAIRO_CONTAINER (g_pMainDock), 15e3, NULL, NULL, (CairoDockActionOnAnswerFunc) _accept_metacity_composition, g_new0 (gboolean, 1), (GFreeFunc)_on_free_metacity_dialog);
-				}
-				
-			}
-			else  // sinon il a droit a un "message a caractere informatif".
-			{
-				cairo_dock_show_general_message (_("To remove the black rectangle around the dock, you will need to activate a composite manager.\nFor instance, this can be done by activating desktop effects, launching Compiz, or activating the composition in Metacity.\nIf your machine can't support composition, Cairo-Dock can emulate it. This option is in the 'System' module of the configuration, at the bottom of the page."), 0);
-			}
-			g_free (cPsef);
-		}
-		else  // a priori peu utile de le retester, surtout que le composite risque de ne pas etre actif tout de suite au demarrage.
-		{
-			s_bTestComposite = FALSE;
-		}
-		
-		if (! s_bTestComposite)
-		{
-			gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
-			cairo_dock_update_conf_file (cConfFilePath,
-				G_TYPE_BOOLEAN, "Launch", "test composite", s_bTestComposite,
-				G_TYPE_INVALID);
-			g_free (cConfFilePath);
-		}
-	}
+	s_bSucessfulLaunch = TRUE;
 	
+	// new year greetings.
 	time_t t = time (NULL);
 	struct tm st;
 	localtime_r (&t, &st);
 	
-	if (st.tm_mday <= 15 && st.tm_mon == 0 && s_iLastYear < st.tm_year + 1900)  // 2 premieres semaines de janvier.
+	if (!data && st.tm_mday <= 15 && st.tm_mon == 0 && s_iLastYear < st.tm_year + 1900)  // first 2 weeks of january + not first launch
 	{
 		s_iLastYear = st.tm_year + 1900;
 		gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
@@ -263,26 +153,46 @@ static gboolean _cairo_dock_successful_launch (gpointer data)
 	}
 	return FALSE;
 }
+static gboolean _cairo_dock_first_launch_setup (gpointer data)
+{
+	cairo_dock_launch_command (CAIRO_DOCK_SHARE_DATA_DIR"/scripts/initial-setup.sh");
+	return FALSE;
+}
 static void _cairo_dock_quit (int signal)
 {
 	gtk_main_quit ();
 }
 static void _cairo_dock_intercept_signal (int signal)
 {
-	cd_warning ("Cairo-Dock has crashed (sig %d).\nIt will be restarted now (%s).\nFeel free to report this bug on glx-dock.org to help improving the dock !", signal, s_cLaunchCommand);
+	cd_warning ("Cairo-Dock has crashed (sig %d).\nIt will be restarted now.\nFeel free to report this bug on glx-dock.org to help improving the dock!", signal);
 	g_print ("info on the system :\n");
 	int r = system ("uname -a");
+	
+	// if a module is responsible, expose it to public shame.
 	if (g_pCurrentModule != NULL)
 	{
 		g_print ("The applet '%s' may be the culprit", g_pCurrentModule->pModule->pVisitCard->cModuleName);
-		s_cLaunchCommand = g_strdup_printf ("%s -x \"%s\"", s_cLaunchCommand, g_pCurrentModule->pModule->pVisitCard->cModuleName);
+		if (! s_bSucessfulLaunch)  // else, be quiet.
+			g_string_append_printf (s_pLaunchCommand, " -x \"%s\"", g_pCurrentModule->pModule->pVisitCard->cModuleName);
 	}
 	else
 	{
 		g_print ("Couldn't guess if it was an applet's fault or not. It may have crashed inside the core or inside a thread\n");
 	}
-	execl ("/bin/sh", "/bin/sh", "-c", s_cLaunchCommand, (char *)NULL);  // on ne revient pas de cette fonction.
-	//execlp ("cairo-dock", "cairo-dock", s_cLaunchCommand, (char *)0);
+	
+	// if the crash occurs on startup, take additionnal measures; else just respawn quietly.
+	if (! s_bSucessfulLaunch)  // a crash on startup,
+	{
+		if (s_iNbCrashes < 2)  // the first 2 crashes, restart with a delay (in case we were launched too early on startup).
+			g_string_append (s_pLaunchCommand, " -w 2");  // 2s delay.
+		else if (g_pCurrentModule == NULL)  // several crashes, and no culprit => start in maintenance mode.
+			g_string_append (s_pLaunchCommand, " -m");
+		g_string_append_printf (s_pLaunchCommand, " -q %d", s_iNbCrashes + 1);  // increment the first-crash counter.
+	}  // else a random crash, respawn quietly.
+	
+	g_print ("restarting with '%s'...\n", s_pLaunchCommand->str);
+	execl ("/bin/sh", "/bin/sh", "-c", s_pLaunchCommand->str, (char *)NULL);  // on ne revient pas de cette fonction.
+	//execlp ("cairo-dock", "cairo-dock", s_pLaunchCommand->str, (char *)0);
 	cd_warning ("Sorry, couldn't restart the dock");
 }
 static void _cairo_dock_set_signal_interception (void)
@@ -304,49 +214,7 @@ static gboolean on_delete_maintenance_gui (GtkWidget *pWidget, GdkEvent *event,
 	return FALSE;  // TRUE <=> ne pas detruire la fenetre.
 }
 
-static void _entered_help_once (CairoDockModuleInstance *pInstance, GKeyFile *pKeyFile)
-{
-	if (!g_bEnterHelpOnce)
-	{
-		g_bEnterHelpOnce = TRUE;
-		gchar *cConfFilePath = g_strdup_printf ("%s/.cairo-dock", g_cCairoDockDataDir);
-		cairo_dock_update_conf_file (cConfFilePath,
-			G_TYPE_BOOLEAN, "Help", "entered once", g_bEnterHelpOnce,
-			G_TYPE_INVALID);
-		g_free (cConfFilePath);
-	}
-}
-static void _register_help_module (void)
-{
-	//\________________ ceci est un vilain hack ... mais je trouvais ca lourd de compiler un truc qui n'a aucun code, et puis comme ca on a l'aide meme sans les plug-ins.
-	CairoDockModule *pHelpModule = g_new0 (CairoDockModule, 1);
-	CairoDockVisitCard *pVisitCard = g_new0 (CairoDockVisitCard, 1);
-	pVisitCard->cModuleName = "Help";
-	pVisitCard->cTitle = _("Help");
-	pVisitCard->iMajorVersionNeeded = 2;
-	pVisitCard->iMinorVersionNeeded = 0;
-	pVisitCard->iMicroVersionNeeded = 0;
-	pVisitCard->cPreviewFilePath = NULL;
-	pVisitCard->cGettextDomain = NULL;
-	pVisitCard->cDockVersionOnCompilation = CAIRO_DOCK_VERSION;
-	pVisitCard->cUserDataDir = "help";
-	pVisitCard->cShareDataDir = CAIRO_DOCK_SHARE_DATA_DIR;
-	pVisitCard->cConfFileName = "help.conf";
-	pVisitCard->cModuleVersion = "0.1.1";
-	pVisitCard->iCategory = CAIRO_DOCK_CATEGORY_BEHAVIOR;
-	pVisitCard->cIconFilePath = CAIRO_DOCK_SHARE_DATA_DIR"/icon-help.svg";
-	pVisitCard->iSizeOfConfig = 0;
-	pVisitCard->iSizeOfData = 0;
-	pVisitCard->cDescription = N_("A useful FAQ which also contains a lot of hints.\nRoll your mouse over a sentence to make helpful popups appear.");
-	pVisitCard->cAuthor = "Fabounet";
-	
-	CairoDockModuleInterface *pInterface = g_new0 (CairoDockModuleInterface, 1);
-	pInterface->load_custom_widget = _entered_help_once;
-	
-	pHelpModule->pVisitCard = pVisitCard;
-	pHelpModule->pInterface = pInterface;
-	cairo_dock_register_module (pHelpModule);  // il sera vu par le modules-manager comme un module auto-loaded. 
-}
+static void PrintMuteFunc(const gchar *string) {}
 
 static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 {
@@ -362,12 +230,11 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 			g_free (s_cDefaulBackend);
 			s_cDefaulBackend = NULL;
 		}
-		s_bTestComposite = g_key_file_get_boolean (pKeyFile, "Launch", "test composite", NULL);
-		g_bEnterHelpOnce = g_key_file_get_boolean (pKeyFile, "Help", "entered once", NULL);
-		s_iGuiMode = g_key_file_get_integer (pKeyFile, "Gui", "mode", NULL);  // 0 si la cle n'est pas presente.
-		s_iLastYear = g_key_file_get_integer (pKeyFile, "Launch", "last year", NULL);  // 0 si la cle n'est pas presente.
+		
+		s_iGuiMode = g_key_file_get_integer (pKeyFile, "Gui", "mode", NULL);  // 0 by default
+		s_iLastYear = g_key_file_get_integer (pKeyFile, "Launch", "last year", NULL);  // 0 by default
 	}
-	else  // ancienne methode.
+	else  // first launch or old version, the file doesn't exist yet.
 	{
 		gchar *cLastVersionFilePath = g_strdup_printf ("%s/.cairo-dock-last-version", cCairoDockDataDir);
 		if (g_file_test (cLastVersionFilePath, G_FILE_TEST_EXISTS))
@@ -380,26 +247,12 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 		}
 		g_remove (cLastVersionFilePath);
 		g_free (cLastVersionFilePath);
-		g_key_file_set_string (pKeyFile, "Launch", "last version", s_cLastVersion);
+		g_key_file_set_string (pKeyFile, "Launch", "last version", s_cLastVersion?s_cLastVersion:"");
 		
 		g_key_file_set_string (pKeyFile, "Launch", "default backend", "");
-		g_key_file_set_boolean (pKeyFile, "Launch", "test composite", TRUE);
 		
-		gchar *cHelpHistory = g_strdup_printf ("%s/.help/entered-once", cCairoDockDataDir);
-		if (g_file_test (cHelpHistory, G_FILE_TEST_EXISTS))
-		{
-			g_bEnterHelpOnce = TRUE;
-		}
-		gchar *cCommand = g_strdup_printf ("rm -rf \"%s/.help\"", cCairoDockDataDir);
-		int r = system (cCommand);
-		g_free (cCommand);
-		g_free (cHelpHistory);
-		g_key_file_set_boolean (pKeyFile, "Help", "entered once", g_bEnterHelpOnce);
-		
-		s_iGuiMode = 0;
 		g_key_file_set_integer (pKeyFile, "Gui", "mode", s_iGuiMode);
 		
-		s_iLastYear = 0;
 		g_key_file_set_integer (pKeyFile, "Launch", "last year", s_iLastYear);
 		
 		cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
@@ -408,34 +261,45 @@ static void _cairo_dock_get_global_config (const gchar *cCairoDockDataDir)
 	g_free (cConfFilePath);
 }
 
-static gboolean _wait (GMainLoop *loop)
-{
-	g_main_loop_quit (loop);
-	return FALSE;
-}
 
 int main (int argc, char** argv)
 {
-	//\___________________ show the config panel if something has gone wrong in a previous life, or just quit to prevent infinite crash loop.
-	int i, iNbMaintenance=0;
-	GString *sCommandString = g_string_new (argv[0]);
+	//\___________________ build the command line used to respawn, and check if we have been launched from another life.
+	s_pLaunchCommand = g_string_new (argv[0]);
 	gchar *cDisableApplet = NULL;
+	int i;
 	for (i = 1; i < argc; i ++)
 	{
 		//g_print ("'%s'\n", argv[i]);
-		if (strcmp (argv[i], "-m") == 0)
-			iNbMaintenance ++;
-		
-		g_string_append_printf (sCommandString, " %s", argv[i]);
+		if (strcmp (argv[i], "-q") == 0)  // this option is only set by the dock itself, at the end of the command line.
+		{
+			s_iNbCrashes = atoi (argv[i+1]);
+			argc = i;  // remove this option, as it doesn't belong to the options table.
+			argv[i] = NULL;
+			break;
+		}
+		else if (strcmp (argv[i], "-w") == 0 || strcmp (argv[i], "-x") == 0)  // skip this option and its argument.
+		{
+			i ++;
+		}
+		else if (strcmp (argv[i], "-m") == 0)  // skip this option
+		{
+			// nothing else to do.
+		}
+		else  // keep this option in the command line.
+		{
+			g_string_append_printf (s_pLaunchCommand, " %s", argv[i]);
+		}
 	}
-	if (iNbMaintenance > 1)
+	if (s_iNbCrashes > 3)
 	{
 		g_print ("Sorry, Cairo-Dock has encoutered some problems, and will quit.\n");
 		return 1;
 	}
-	g_string_append (sCommandString, " -m");  // on relance avec le mode maintenance.
-	s_cLaunchCommand = sCommandString->str;
-	g_string_free (sCommandString, FALSE);
+
+	// mute all output messages if CD is not launched from a terminal
+	if (getenv("TERM") == NULL)  /// why not isatty(stdout) ?...
+		g_set_print_handler(PrintMuteFunc);
 	
 	gtk_init (&argc, &argv);
 	gtk_gl_init (&argc, &argv);
@@ -443,87 +307,88 @@ int main (int argc, char** argv)
 	GError *erreur = NULL;
 	
 	//\___________________ get app's options.
-	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSticky = FALSE, bNormalHint = FALSE, bCappuccino = FALSE, bPrintVersion = FALSE, bTesting = FALSE, bForceIndirectRendering = FALSE, bForceOpenGL = FALSE, bToggleIndirectRendering = FALSE, bKeepAbove = FALSE;
+	gboolean bSafeMode = FALSE, bMaintenance = FALSE, bNoSticky = FALSE, bNormalHint = FALSE, bCappuccino = FALSE, bPrintVersion = FALSE, bTesting = FALSE, bForceIndirectRendering = FALSE, bForceOpenGL = FALSE, bToggleIndirectRendering = FALSE, bKeepAbove = FALSE, bForceColors = FALSE;
 	gchar *cEnvironment = NULL, *cUserDefinedDataDir = NULL, *cVerbosity = 0, *cUserDefinedModuleDir = NULL, *cExcludeModule = NULL, *cThemeServerAdress = NULL;
 	int iDelay = 0;
-	GOptionEntry TableDesOptions[] =
+	GOptionEntry pOptionsTable[] =
 	{
-		{"log", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
-			&cVerbosity,
-			"log verbosity (debug,message,warning,critical,error); default is warning", NULL},
-		{"wait", 'w', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT,
-			&iDelay,
-			"wait for N seconds before starting; this is useful if you notice some problems when the dock starts with the session.", NULL},
+		{"cairo", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&g_bForceCairo,
+			_("Use Cairo backend."), NULL},
+		{"opengl", 'o', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bForceOpenGL,
+			_("Use OpenGL backend."), NULL},
 #ifdef HAVE_GLITZ
 		{"glitz", 'g', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&g_bUseGlitz,
-			"force Glitz backend (hardware acceleration for cairo, needs a glitz-enabled libcairo)", NULL},
+			_("Force Glitz backend (hardware acceleration for cairo, needs a glitz-enabled libcairo)."), NULL},
 #endif
-		{"cairo", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&g_bForceCairo,
-			"use Cairo backend", NULL},
-		{"opengl", 'o', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bForceOpenGL,
-			"use OpenGL backend", NULL},
 		{"indirect-opengl", 'O', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&bToggleIndirectRendering,
-			"use OpenGL backend with indirect rendering. There are very few case where this option should be used.", NULL},
-		{"indirect", 'i', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bForceIndirectRendering,
-			"deprecated - see -O", NULL},
-		{"keep-above", 'a', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bKeepAbove,
-			"keep the dock above other windows whatever", NULL},
-		{"no-sticky", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bNoSticky,
-			"don't make the dock appear on all desktops", NULL},
+			_("Use OpenGL backend with indirect rendering. There are very few case where this option should be used."), NULL},
 		{"env", 'e', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&cEnvironment,
-			"force the dock to consider this environnement - use it with care.", NULL},
+			_("Force the dock to consider this environnement - use it with care."), NULL},
 		{"dir", 'd', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&cUserDefinedDataDir,
-			"force the dock to load from this directory, instead of ~/.config/cairo-dock.", NULL},
-		{"maintenance", 'm', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bMaintenance,
-			"allow to edit the config before the dock is started and show the config panel on start", NULL},
-		{"exclude", 'x', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
-			&cExcludeModule,
-			"exclude a given plug-in from activating (it is still loaded though)", NULL},
-		{"safe-mode", 'f', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bSafeMode,
-			"don't load any plug-ins", NULL},
-		{"capuccino", 'C', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bCappuccino,
-			"Cairo-Dock makes anything, including coffee !", NULL},
-		{"version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bPrintVersion,
-			"print version and quit.", NULL},
-		{"modules-dir", 'M', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
-			&cUserDefinedModuleDir,
-			"ask the dock to load additionnal modules contained in this directory (though it is unsafe for your dock to load unnofficial modules).", NULL},
-		{"testing", 'T', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&bTesting,
-			"for debugging purpose only. The crash manager will not be started to hunt down the bugs.", NULL},
-		{"easter-eggs", 'E', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
-			&g_bEasterEggs,
-			"for debugging purpose only. Some hidden and still unstable options will be activated.", NULL},
+			_("Force the dock to load from this directory, instead of ~/.config/cairo-dock."), NULL},
 		{"server", 'S', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
 			&cThemeServerAdress,
-			"address of a server containing additional themes. This will overwrite the default server address.", NULL},
+			_("Address of a server containing additional themes. This will overwrite the default server address."), NULL},
+		{"wait", 'w', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT,
+			&iDelay,
+			_("Wait for N seconds before starting; this is useful if you notice some problems when the dock starts with the session."), NULL},
+		{"maintenance", 'm', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bMaintenance,
+			_("Allow to edit the config before the dock is started and show the config panel on start."), NULL},
+		{"exclude", 'x', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
+			&cExcludeModule,
+			_("Exclude a given plug-in from activating (it is still loaded though)."), NULL},
+		{"safe-mode", 'f', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bSafeMode,
+			_("Don't load any plug-ins."), NULL},
+		{"log", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
+			&cVerbosity,
+			_("Log verbosity (debug,message,warning,critical,error); default is warning."), NULL},
+		{"colors", 'A', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bForceColors,
+			_("Force to display some output messages with colors."), NULL},
+		{"version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bPrintVersion,
+			_("Print version and quit."), NULL},
 		{"locked", 'k', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
 			&g_bLocked,
-			"lock the dock so that any modification is impossible for users.", NULL},
+			_("Lock the dock so that any modification is impossible for users."), NULL},
+		// below options are probably useless for most of people.
+		{"keep-above", 'a', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bKeepAbove,
+			_("Keep the dock above other windows whatever."), NULL},
+		{"no-sticky", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bNoSticky,
+			_("Don't make the dock appear on all desktops."), NULL},
+		{"capuccino", 'C', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bCappuccino,
+			_("Cairo-Dock makes anything, including coffee !"), NULL},
+		{"modules-dir", 'M', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING,
+			&cUserDefinedModuleDir,
+			_("Ask the dock to load additionnal modules contained in this directory (though it is unsafe for your dock to load unnofficial modules)."), NULL},
+		{"testing", 'T', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&bTesting,
+			_("For debugging purpose only. The crash manager will not be started to hunt down the bugs."), NULL},
+		{"easter-eggs", 'E', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
+			&g_bEasterEggs,
+			_("For debugging purpose only. Some hidden and still unstable options will be activated."), NULL},
 		{NULL, 0, 0, 0,
 			NULL,
 			NULL, NULL}
 	};
 
 	GOptionContext *context = g_option_context_new ("Cairo-Dock");
-	g_option_context_add_main_entries (context, TableDesOptions, NULL);
+	g_option_context_add_main_entries (context, pOptionsTable, NULL);
 	g_option_context_parse (context, &argc, &argv, &erreur);
 	if (erreur != NULL)
 	{
-		g_print ("ERROR in options : %s\n", erreur->message);
+		cd_error ("ERROR in options: %s", erreur->message);
 		return 1;
 	}
 	
@@ -542,6 +407,9 @@ int main (int argc, char** argv)
 		g_free (cVerbosity);
 	}
 	
+	if (bForceColors)
+		cd_log_force_use_color ();
+	
 	CairoDockDesktopEnv iDesktopEnv = CAIRO_DOCK_UNKNOWN_ENV;
 	if (cEnvironment != NULL)
 	{
@@ -558,7 +426,7 @@ int main (int argc, char** argv)
 		g_free (cEnvironment);
 	}
 #ifdef HAVE_GLITZ
-	g_print ("Compiled with Glitz (hardware acceleration support for cairo)\n");
+	cd_warning ("Compiled with Glitz (hardware acceleration support for cairo)");
 #endif
 	
 	if (bCappuccino)
@@ -570,16 +438,23 @@ int main (int argc, char** argv)
 	//\___________________ get global config.
 	gboolean bFirstLaunch = FALSE;
 	gchar *cRootDataDirPath;
+	// if the user has specified the '-d' parameter.
 	if (cUserDefinedDataDir != NULL)
 	{
-		cRootDataDirPath = cUserDefinedDataDir;
+		// if 'cRootDataDirPath' is not a full path, we will have a few problems with image in the config panel without a full path (e.g. 'bg.svg' in the default theme)
+		if (*cUserDefinedDataDir == '/')
+			cRootDataDirPath = cUserDefinedDataDir;
+		else if (*cUserDefinedDataDir == '~')
+			cRootDataDirPath = g_strdup_printf ("%s%s", getenv("HOME"), cUserDefinedDataDir + 1);
+		else
+			cRootDataDirPath = g_strdup_printf ("%s/%s", g_get_current_dir(), cUserDefinedDataDir);
 		cUserDefinedDataDir = NULL;
 	}
 	else
 	{
 		cRootDataDirPath = g_strdup_printf ("%s/.config/%s", getenv("HOME"), CAIRO_DOCK_DATA_DIR);
-		bFirstLaunch = ! g_file_test (cRootDataDirPath, G_FILE_TEST_IS_DIR);
 	}
+	bFirstLaunch = ! g_file_test (cRootDataDirPath, G_FILE_TEST_IS_DIR);
 	_cairo_dock_get_global_config (cRootDataDirPath);
 	
 	//\___________________ internationalize the app.
@@ -590,10 +465,7 @@ int main (int argc, char** argv)
 	//\___________________ delay the startup if specified.
 	if (iDelay > 0)
 	{
-		GMainLoop *loop = g_main_loop_new (NULL, FALSE);
-		g_timeout_add_seconds (iDelay, (GSourceFunc)_wait, loop);
-		g_main_loop_run (loop);
-		g_main_loop_unref (loop);
+		sleep (iDelay);
 	}
 	
 	//\___________________ initialize libgldi.
@@ -641,12 +513,13 @@ int main (int argc, char** argv)
 			GtkWidget *pCheckBox = gtk_check_button_new ();
 			gtk_box_pack_end (GTK_BOX (pAskBox), pCheckBox, FALSE, FALSE, 0);
 			gtk_box_pack_end (GTK_BOX (pAskBox), label, FALSE, FALSE, 0);
-			g_signal_connect (G_OBJECT (pCheckBox), "toggled", G_CALLBACK(_toggle_remember_choice), dialog);
+			///g_signal_connect (G_OBJECT (pCheckBox), "toggled", G_CALLBACK(_toggle_remember_choice), dialog);
 			
 			gtk_widget_show_all (dialog);
 			
 			gint iAnswer = gtk_dialog_run (GTK_DIALOG (dialog));  // lance sa propre main loop, c'est pourquoi on peut le faire avant le gtk_main().
-			gboolean bRememberChoice = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "remember"));
+			///gboolean bRememberChoice = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dialog), "remember"));
+			gboolean bRememberChoice = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (pCheckBox));
 			gtk_widget_destroy (dialog);
 			if (iAnswer == GTK_RESPONSE_NO)
 			{
@@ -698,8 +571,7 @@ int main (int argc, char** argv)
 			cUserDefinedModuleDir = NULL;
 		}
 	}
-	
-	_register_help_module ();
+	cairo_dock_register_help_module ();  // this applet is made for Cairo-Dock, not gldi; therefore, it's not installed as a separate library, so we manually register it.
 	
 	//\___________________ define GUI backend.
 	cairo_dock_load_user_gui_backend (s_iGuiMode);
@@ -798,29 +670,13 @@ int main (int argc, char** argv)
 			G_CALLBACK (on_delete_maintenance_gui),
 			pBlockingLoop);
 		
-		g_print ("showing the maintenance mode ...\n");
+		cd_warning ("showing the maintenance mode ...");
 		g_main_loop_run (pBlockingLoop);  // pas besoin de GDK_THREADS_LEAVE/ENTER vu qu'on est pas encore dans la main loop de GTK. En fait cette boucle va jouer le role de la main loop GTK.
-		g_print ("end of the maintenance mode.\n");
+		cd_warning ("end of the maintenance mode.");
 		
 		g_main_loop_unref (pBlockingLoop);
 	}
 	
-	if (cExcludeModule != NULL)
-	{
-		//g_print ("on enleve %s de '%s'\n", cExcludeModule, s_cLaunchCommand);
-		gchar *str = g_strstr_len (s_cLaunchCommand, -1, " -x ");
-		if (str)
-		{
-			*str = '\0';  // enleve le module de la ligne de commande, ainsi que le le -m courant.
-			g_print ("s_cLaunchCommand <- '%s'\n", s_cLaunchCommand);
-		}
-		else
-		{
-			g_free (cExcludeModule);
-			cExcludeModule = NULL;
-		}
-	}
-	
 	//\___________________ load the current theme.
 	cd_message ("loading theme ...");
 	if (! g_file_test (g_cConfFile, G_FILE_TEST_EXISTS))  // no theme yet, copy the default theme first.
@@ -848,7 +704,7 @@ int main (int argc, char** argv)
 		return 0;
 	}
 	
-	//\___________________ On affiche un petit message de bienvenue ou de changelog ou d'erreur.
+	//\___________________ display the changelog in case of a new version.
 	gboolean bNewVersion = (s_cLastVersion == NULL || strcmp (s_cLastVersion, CAIRO_DOCK_VERSION) != 0);
 	if (bNewVersion)
 	{
@@ -859,15 +715,15 @@ int main (int argc, char** argv)
 		g_free (cConfFilePath);
 	}
 	
-	if (bFirstLaunch)  // tout premier lancement -> bienvenue !
+	//g_print ("bFirstLaunch: %d; bNewVersion: %d\n", bFirstLaunch, bNewVersion);
+	if (bFirstLaunch)  // first launch => set up config
 	{
-		cairo_dock_show_general_message (_("Welcome in Cairo-Dock2 !\nA default and simple theme has been loaded.\nYou can either familiarize yourself with the dock or choose another theme with right-click -> Cairo-Dock -> Manage themes.\nA useful help is available by right-click -> Cairo-Dock -> Help.\nIf you have any question/request/remark, please pay us a visit at http://glx-dock.org.\nHope you will enjoy this soft !\n  (you can now click on this dialog to close it)"), 0);
+		g_timeout_add_seconds (4, _cairo_dock_first_launch_setup, NULL);
 	}
 	else if (bNewVersion)  // nouvelle version -> changelog (si c'est le 1er lancement, inutile de dire ce qui est nouveau, et de plus on a deja le message de bienvenue).
 	{
 		gchar *cChangeLogFilePath = g_strdup_printf ("%s/ChangeLog.txt", CAIRO_DOCK_SHARE_DATA_DIR);
 		GKeyFile *pKeyFile = cairo_dock_open_key_file (cChangeLogFilePath);
-		g_key_file_load_from_file (pKeyFile, cChangeLogFilePath, 0, &erreur);  // pas de commentaire utile.
 		if (pKeyFile != NULL)
 		{
 			gchar *cKeyName = g_strdup_printf ("%d.%d.%d", g_iMajorVersion, g_iMinorVersion, g_iMicroVersion);  // version sans les "alpha", "beta", "rc", etc.
@@ -881,11 +737,18 @@ int main (int argc, char** argv)
 				myDialogsParam.dialogTextDescription.bUseMarkup = FALSE;
 				g_free (cChangeLogMessage);
 			}
+			g_key_file_free (pKeyFile);
 		}
+		// In case something has changed in Compiz/Gtk/others, we also run the script on a new version of the dock.
+		g_timeout_add_seconds (4, _cairo_dock_first_launch_setup, NULL);
 	}
 	else if (cExcludeModule != NULL && ! bMaintenance)
 	{
-		gchar *cMessage = g_strdup_printf (_("The module '%s' may have encountered a problem.\nIt has been restored successfully, but if it happens again, please report it at http://glx-dock.org"), cExcludeModule);
+		gchar *cMessage;
+		if (s_iNbCrashes < 2)
+			cMessage = g_strdup_printf (_("The module '%s' may have encountered a problem.\nIt has been restored successfully, but if it happens again, please report it at http://glx-dock.org"), cExcludeModule);
+		else
+			cMessage = g_strdup_printf ("The module '%s' has been deactivated because it may have caused some problems.\nYou can reactivate it, if it happens again thanks to report it at http://glx-dock.org", cExcludeModule);
 		
 		CairoDockModule *pModule = cairo_dock_find_module_from_name (cExcludeModule);
 		Icon *icon = cairo_dock_get_dialogless_icon ();
@@ -894,7 +757,17 @@ int main (int argc, char** argv)
 	}
 	
 	if (! bTesting)
-		g_timeout_add_seconds (5, _cairo_dock_successful_launch, NULL);
+		g_timeout_add_seconds (5, _cairo_dock_successful_launch, GINT_TO_POINTER (bFirstLaunch));
+	
+	/*g_print ("\n\nTODO (2.5):\n"
+	"- check for config panel (g_object_unref assertion)\n"
+	"- review Help hints\n"
+	"- find Kwin config tool for Composite-manager\n"
+	"- draw a preview of the dock in opengl\n"
+	"- display Help GUI in simple mode\n"
+	"- kde integration ++\n"
+	"- stack: enable iSubdockViewType\n"
+	"\n");*/
 	
 	gtk_main ();
 	
@@ -907,6 +780,7 @@ int main (int argc, char** argv)
 	
 	rsvg_term ();
 	xmlCleanupParser ();
+	g_string_free (s_pLaunchCommand, TRUE);
 	
 	cd_message ("Bye bye !");
 	g_print ("\033[0m\n");
