@@ -65,7 +65,6 @@ static Atom s_aNetClientList;  // z-order
 static Atom s_aNetClientListStacking;  // age-order
 static Atom s_aNetActiveWindow;
 static Atom s_aNetWmState;
-static Atom s_aNetWmSticky;
 static Atom s_aNetWmBelow;
 static Atom s_aNetWmAbove;
 static Atom s_aNetWmHidden;
@@ -114,7 +113,6 @@ Display *cairo_dock_initialize_X_desktop_support (void)
 	s_aNetWmFullScreen		= XInternAtom (s_XDisplay, "_NET_WM_STATE_FULLSCREEN", False);
 	s_aNetWmAbove			= XInternAtom (s_XDisplay, "_NET_WM_STATE_ABOVE", False);
 	s_aNetWmBelow			= XInternAtom (s_XDisplay, "_NET_WM_STATE_BELOW", False);
-	s_aNetWmSticky			= XInternAtom (s_XDisplay, "_NET_WM_STATE_STICKY", False);
 	s_aNetWmHidden			= XInternAtom (s_XDisplay, "_NET_WM_STATE_HIDDEN", False);
 	s_aNetWmSkipTaskbar 		= XInternAtom (s_XDisplay, "_NET_WM_STATE_SKIP_TASKBAR", False);
 	s_aNetWmMaximizedHoriz		= XInternAtom (s_XDisplay, "_NET_WM_STATE_MAXIMIZED_HORZ", False);
@@ -1082,36 +1080,8 @@ gboolean cairo_dock_xwindow_is_fullscreen_or_hidden_or_maximized (Window Xid, gb
 	
 	XFree (pXStateBuffer);
 	return bValid;
-}
+}  // Note: for stickyness, dont use _NET_WM_STATE_STICKY; prefer "cairo_dock_get_xwindow_desktop (Xid) == -1"
 
-gboolean cairo_dock_xwindow_is_sticky (Window Xid)
-{
-	g_return_val_if_fail (Xid > 0, FALSE);
-	Atom aReturnedType = 0;
-	int aReturnedFormat = 0;
-	unsigned long iLeftBytes, iBufferNbElements = 0;
-	gulong *pXStateBuffer = NULL;
-	XGetWindowProperty (s_XDisplay, Xid, s_aNetWmState, 0, G_MAXULONG, False, XA_ATOM, &aReturnedType, &aReturnedFormat, &iBufferNbElements, &iLeftBytes, (guchar **)&pXStateBuffer);
-	
-	gboolean bIsSticky = FALSE;
-	if (iBufferNbElements > 0)
-	{
-		guint i;
-		//g_print ("iBufferNbElements : %d (%d;%d)\n", iBufferNbElements, s_aNetWmAbove, s_aNetWmBelow);
-		for (i = 0; i < iBufferNbElements; i ++)
-		{
-			//g_print (" - %d\n", pXStateBuffer[i]);
-			if (pXStateBuffer[i] == s_aNetWmSticky)
-			{
-				bIsSticky = TRUE;
-				break;
-			}
-		}
-	}
-
-	XFree (pXStateBuffer);
-	return bIsSticky;
-}
 
 static inline gboolean _cairo_dock_window_has_type (int Xid, Atom iType)
 {
