@@ -68,11 +68,12 @@ void cairo_dock_set_icon_surface_with_reflect (cairo_t *pIconContext, cairo_surf
 
 /** Apply an image on the context of an icon, clearing it beforehand, and adding the reflect.
 *@param pIconContext the drawing context; is not altered by the function.
-*@param cImagePath path of an image to apply on the icon.
+*@param cImagePath name or path to an icon image.
 *@param pIcon the icon.
 *@param pContainer the container of the icon.
+*@return TRUE if everything went smoothly.
 */
-void cairo_dock_set_image_on_icon (cairo_t *pIconContext, const gchar *cImagePath, Icon *pIcon, CairoContainer *pContainer);
+gboolean cairo_dock_set_image_on_icon (cairo_t *pIconContext, const gchar *cIconName, Icon *pIcon, CairoContainer *pContainer);
 
 /** Apply an image on the context of an icon, clearing it beforehand, and adding the reflect. The image is searched in any possible locations, and the default image provided is used if the search was fruitless.
 *@param pIconContext the drawing context; is not altered by the function.
@@ -108,8 +109,6 @@ typedef enum {
 
 gchar *cairo_dock_get_theme_path_for_module (const gchar *cAppletConfFilePath, GKeyFile *pKeyFile, const gchar *cGroupName, const gchar *cKeyName, gboolean *bFlushConfFileNeeded, const gchar *cDefaultThemeName, const gchar *cShareThemesDir, const gchar *cExtraDirName);
 
-GtkWidget *cairo_dock_create_sub_menu (const gchar *cLabel, GtkWidget *pMenu, const gchar *cImage);
-
 
 /** Play a sound, through Alsa or PulseAudio.
 *@param cSoundPath path to an audio file.
@@ -328,7 +327,7 @@ cairo_dock_get_integer_list_key_value (pKeyFile, cGroupName, cKeyName, &bFlushCo
 /** Create and add the default sub-menu of an applet to the main menu. This sub-menu is named according to the name of the applet, and is represented by the default icon of the applet.
 *@return the sub-menu, newly created and attached to the main menu.
 */
-#define CD_APPLET_CREATE_MY_SUB_MENU(...) (myDocksParam.bLockAll ? CD_APPLET_MY_MENU : CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_ (myApplet->pModule->pVisitCard->cTitle), CD_APPLET_MY_MENU, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE))
+#define CD_APPLET_CREATE_MY_SUB_MENU(...) (myDocksParam.bLockAll ? CD_APPLET_MY_MENU : CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (myApplet->pModule->pVisitCard->cTitle, CD_APPLET_MY_MENU, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE))
 
 /** Create and add an entry to a menu, with an icon.
 *@param cLabel name of the entry.
@@ -530,31 +529,23 @@ cairo_dock_get_integer_list_key_value (pKeyFile, cGroupName, cKeyName, &bFlushCo
 	cairo_dock_redraw_icon (myIcon, myContainer); } while (0)
 
 /** Apply an image on the applet's icon. The image is resized at the same size as the icon. Does not trigger the icon refresh.
-*@param cImagePath path to an image.
+*@param cIconName name of an icon or path to an image.
 */
-#define CD_APPLET_SET_IMAGE_ON_MY_ICON(cImagePath)  \
-	cairo_dock_set_image_on_icon (myDrawContext, cImagePath, myIcon, myContainer)
-
-/** Apply an image, taken inside the installation folder of the applet, on the applet's icon. The image is resized at the same size as the icon. Does not trigger the icon refresh.
-*@param cImageName name of an image 
-*/
-#define CD_APPLET_SET_LOCAL_IMAGE_ON_MY_ICON(cImageName) do { \
-	gchar *_cImageFilePath = g_strconcat (MY_APPLET_SHARE_DATA_DIR, "/", cImageName, NULL); \
-	CD_APPLET_SET_IMAGE_ON_MY_ICON (_cImageFilePath); \
-	g_free (_cImageFilePath); } while (0)
+#define CD_APPLET_SET_IMAGE_ON_MY_ICON(cIconName) \
+	cairo_dock_set_image_on_icon_with_default (myDrawContext, cIconName, myIcon, myContainer, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE)
 
 /** Apply an image on the applet's icon, clearing it beforehand, and adding the reflect. The image is searched in any possible locations, and the default image provided is used if the search was fruitless (taken in the installation folder of the applet).
-*@param cImageName name of an image.
+*@param cIconName name of an icon or path to an image.
 *@param cDefaultLocalImageName name of an image to use as a fallback (taken in the applet's installation folder).
 */
-#define CD_APPLET_SET_USER_IMAGE_ON_MY_ICON(cImageName, cDefaultLocalImageName) \
-	cairo_dock_set_image_on_icon_with_default (myDrawContext, cImageName, myIcon, myContainer, MY_APPLET_SHARE_DATA_DIR"/"cDefaultLocalImageName)
+#define CD_APPLET_SET_USER_IMAGE_ON_MY_ICON(cIconName, cDefaultLocalImageName) \
+	cairo_dock_set_image_on_icon_with_default (myDrawContext, cIconName, myIcon, myContainer, MY_APPLET_SHARE_DATA_DIR"/"cDefaultLocalImageName)
 
 /** Apply the default icon on the applet's icon if there is no image yet.
 */
 #define CD_APPLET_SET_DEFAULT_IMAGE_ON_MY_ICON_IF_NONE do { \
 	if (myIcon->cFileName == NULL) { \
-		CD_APPLET_SET_IMAGE_ON_MY_ICON (MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE); } } while (0)
+		cairo_dock_set_image_on_icon (myDrawContext, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE, myIcon, myContainer); } } while (0)
 
 
   ///////////
@@ -651,7 +642,7 @@ cairo_dock_get_integer_list_key_value (pKeyFile, cGroupName, cKeyName, &bFlushCo
 *@param iWidthPtr pointer to the width.
 *@param iHeightPtr pointer to the height.
 */
-#define CD_APPLET_GET_MY_ICON_EXTENT(iWidthPtr, iHeightPtr) cairo_dock_get_icon_extent (myIcon, myContainer, iWidthPtr, iHeightPtr)
+#define CD_APPLET_GET_MY_ICON_EXTENT(iWidthPtr, iHeightPtr) cairo_dock_get_icon_extent (myIcon, iWidthPtr, iHeightPtr)
 
 /** Initiate an OpenGL drawing session on the applet's icon.
 */
@@ -668,11 +659,25 @@ cairo_dock_get_integer_list_key_value (pKeyFile, cGroupName, cKeyName, &bFlushCo
 */
 #define CD_APPLET_FINISH_DRAWING_MY_ICON cairo_dock_end_draw_icon (myIcon, myContainer)
 
+
+/** Add an overlay from an image on the applet's icon.
+ *@param cImageFile an image (if it's not a path, it is searched amongst the current theme's images)
+ *@param iPosition position where to display the overlay
+ *@return TRUE if the overlay has been successfuly added.
+ */
+#define CD_APPLET_ADD_OVERLAY(cImageFile, iPosition) cairo_dock_add_overlay_from_image (myIcon, cImageFile, iPosition)
+
+/** Remove an overlay the applet's icon, given its position (there is only one overlay at a given position).
+ *@param iPosition position of the overlay
+ */
+#define CD_APPLET_REMOVE_OVERLAY(iPosition) cairo_dock_remove_overlay_at_position (iPosition)
+
+
 /** Make an emblem from an image. If the image is given by its sole name, it is looked up inside the root theme folder. Free it with cairo_dock_free_emblem.
 *@param cImageFile name of an image file.
 *@return a newly allocated CairoEmblem.
 */
-#define CD_APPLET_MAKE_EMBLEM(cImageFile) cairo_dock_make_emblem (cImageFile, myIcon, myContainer)
+#define CD_APPLET_MAKE_EMBLEM(cImageFile) cairo_dock_make_emblem (cImageFile, myIcon)
 
 /** Draw an emblem on the applet's icon. The emblem is drawn directly on the icon, and is erased if the icon is redrawn.
 *@param pEmblem an emblem.
@@ -680,11 +685,12 @@ cairo_dock_get_integer_list_key_value (pKeyFile, cGroupName, cKeyName, &bFlushCo
 #define CD_APPLET_DRAW_EMBLEM_ON_MY_ICON(pEmblem) cairo_dock_draw_emblem_on_icon (pEmblem, myIcon, myContainer)
 
 #define CD_APPLET_SET_EMBLEM_ON_MY_ICON(cImageFile, iPosition) do {\
-	CairoEmblem *pEmblem = cairo_dock_make_emblem (cImageFile, myIcon, myContainer);\
+	CairoEmblem *pEmblem = cairo_dock_make_emblem (cImageFile, myIcon);\
 	cairo_dock_set_emblem_position (pEmblem, iPosition);\
 	cairo_dock_draw_emblem_on_icon (pEmblem, myIcon, myContainer);\
 	cairo_dock_free_emblem (pEmblem); } while (0)
 
+
 /** Add a Data Renderer the applet's icon.
 *@param pAttr the attributes of the Data Renderer. They allow you to define its properties.
 */
