@@ -92,7 +92,7 @@ static gboolean s_bIconDragged = FALSE;
 
 static gboolean _check_mouse_outside (CairoDock *pDock);
 
-static inline gboolean _mouse_is_really_outside (CairoDock *pDock)
+static gboolean _mouse_is_really_outside (CairoDock *pDock)
 {
 	/**return (pDock->container.iMouseX <= 0
 		|| pDock->container.iMouseX >= pDock->container.iWidth
@@ -109,13 +109,15 @@ static inline gboolean _mouse_is_really_outside (CairoDock *pDock)
 		x2 = pDock->container.iWidth;
 		if (pDock->container.bDirectionUp)
 		{
-			y1 = (pDock->fMagnitudeMax != 0 ? 0 : pDock->container.iHeight - pDock->iMinDockHeight);
+			///y1 = (pDock->fMagnitudeMax != 0 ? 0 : pDock->container.iHeight - pDock->iMinDockHeight);
+			y1 = pDock->container.iHeight - pDock->iActiveHeight;
 			y2 = pDock->container.iHeight;
 		}
 		else
 		{
 			y1 = 0;
-			y2 = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
+			///y2 = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
+			y2 = pDock->iActiveHeight;
 		}
 	}
 	else if (pDock->iInputState == CAIRO_DOCK_INPUT_AT_REST)
@@ -133,8 +135,8 @@ static inline gboolean _mouse_is_really_outside (CairoDock *pDock)
 			y2 = pDock->iMinDockHeight;
 		}		
 	}
-	else
-		return FALSE;
+	else  // hidden
+		return TRUE;
 	if (pDock->container.iMouseX <= x1
 	|| pDock->container.iMouseX >= x2)
 		return TRUE;
@@ -181,6 +183,7 @@ gboolean cairo_dock_on_expose (GtkWidget *pWidget,
 	CairoDock *pDock)
 {
 	//g_print ("%s ((%d;%d) %dx%d)\n", __func__, pExpose->area.x, pExpose->area.y, pExpose->area.width, pExpose->area.height);
+	//\________________ OpenGL rendering
 	if (g_bUseOpenGL && pDock->pRenderer->render_opengl != NULL)
 	{
 		GdkGLContext *pGlContext = gtk_widget_get_gl_context (pDock->container.pWidget);
@@ -224,9 +227,10 @@ gboolean cairo_dock_on_expose (GtkWidget *pWidget,
 		return FALSE ;
 	}
 	
+	//\________________ Cairo optimized rendering
 	if (pExpose->area.x + pExpose->area.y != 0)  // x et/ou y sont > 0.
 	{
-		//if (! cairo_dock_is_hidden (pDock) || (g_pHidingBackend != NULL && g_pHidingBackend->bCanDisplayHiddenDock))
+		if (! cairo_dock_is_hidden (pDock) || (g_pHidingBackend != NULL && g_pHidingBackend->bCanDisplayHiddenDock))  // if the dock is invisible, we don't use the optimized rendering (for always-visible icons for instance)
 		{
 			cairo_t *pCairoContext = cairo_dock_create_drawing_context_on_area (CAIRO_CONTAINER (pDock), &pExpose->area, NULL);
 			
@@ -251,11 +255,12 @@ gboolean cairo_dock_on_expose (GtkWidget *pWidget,
 			cairo_dock_notify_on_object (pDock, NOTIFICATION_RENDER_DOCK, pDock, pCairoContext);
 			
 			cairo_destroy (pCairoContext);
+			return FALSE;
 		}
-		return FALSE;
+		
 	}
 	
-	
+	//\________________ Cairo rendering
 	cairo_t *pCairoContext = cairo_dock_create_drawing_context_on_container (CAIRO_CONTAINER (pDock));
 	
 	if (cairo_dock_is_loading ())  // transparent pendant le chargement.
@@ -573,7 +578,7 @@ gboolean cairo_dock_on_motion_notify (GtkWidget* pWidget,
 		gtk_widget_queue_draw (pWidget);
 		
 		pDock->fAvoidingMouseMargin = .25;  // on peut dropper entre 2 icones ...
-		pDock->iAvoidingMouseIconType = CAIRO_DOCK_LAUNCHER;  // ... seulement entre 2 lanceurs.
+		pDock->iAvoidingMouseIconType = CAIRO_DOCK_LAUNCHER;  // ... seulement entre 2 icones du groupe "lanceurs".
 	}
 	
 	//\_______________ On gere le changement d'icone.
@@ -629,7 +634,7 @@ gboolean cairo_dock_on_leave_dock_notification2 (gpointer data, CairoDock *pDock
 			cairo_dock_update_dock_size (pOriginDock);
 			cairo_dock_stop_icon_glide (pOriginDock);
 			
-			s_pFlyingContainer = cairo_dock_create_flying_container (s_pIconClicked, pOriginDock, TRUE);
+			s_pFlyingContainer = cairo_dock_create_flying_container (s_pIconClicked, pOriginDock);
 			//g_print ("- s_pIconClicked <- NULL\n");
 			s_pIconClicked = NULL;
 			if (pDock->iRefCount > 0 || pDock->bAutoHide)  // pour garder le dock visible.
@@ -677,7 +682,7 @@ gboolean cairo_dock_on_leave_dock_notification (gpointer data, CairoDock *pDock,
 	if (s_pIconClicked != NULL
 	&& (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (s_pIconClicked)
 		|| CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (s_pIconClicked)
-		|| (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (s_pIconClicked) && s_pIconClicked->cDesktopFileName)
+		|| (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (s_pIconClicked) && s_pIconClicked->cDesktopFileName && pDock->fMagnitudeMax != 0)
 		|| CAIRO_DOCK_IS_DETACHABLE_APPLET (s_pIconClicked))
 	&& s_pFlyingContainer == NULL
 	&& ! myDocksParam.bLockIcons
@@ -702,7 +707,7 @@ gboolean cairo_dock_on_leave_dock_notification (gpointer data, CairoDock *pDock,
 			cairo_dock_update_dock_size (pOriginDock);
 			cairo_dock_stop_icon_glide (pOriginDock);
 			
-			s_pFlyingContainer = cairo_dock_create_flying_container (s_pIconClicked, pOriginDock, TRUE);
+			s_pFlyingContainer = cairo_dock_create_flying_container (s_pIconClicked, pOriginDock);
 			//g_print ("- s_pIconClicked <- NULL\n");
 			s_pIconClicked = NULL;
 			if (pDock->iRefCount > 0 || pDock->bAutoHide)  // pour garder le dock visible.
@@ -820,22 +825,6 @@ gboolean cairo_dock_on_leave_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 		pDock->iSidTestMouseOutside = 0;
 	}
 	
-	//\_______________ On enregistre la position de la souris.
-	if (pEvent != NULL)
-	{
-		if (pDock->container.bIsHorizontal)
-		{
-			pDock->container.iMouseX = pEvent->x;
-			pDock->container.iMouseY = pEvent->y;
-		}
-		else
-		{
-			pDock->container.iMouseX = pEvent->y;
-			pDock->container.iMouseY = pEvent->x;
-		}
-	}
-	//g_print (" notify leave...\n");
-	
 	gboolean bStartAnimation = FALSE;
 	cairo_dock_notify_on_object (&myDocksMgr, NOTIFICATION_LEAVE_DOCK, pDock, &bStartAnimation);
 	cairo_dock_notify_on_object (pDock, NOTIFICATION_LEAVE_DOCK, pDock, &bStartAnimation);
@@ -914,7 +903,7 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 	pDock->iInputState = CAIRO_DOCK_INPUT_ACTIVE;
 	
 	// si on etait deja dedans, ou qu'on etait cense l'etre, on relance juste le grossissement.
-	if (pDock->container.bInside || pDock->bIsHiding)
+	/**if (pDock->container.bInside || pDock->bIsHiding)
 	{
 		pDock->container.bInside = TRUE;
 		cairo_dock_start_growing (pDock);
@@ -924,7 +913,7 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 			cairo_dock_start_showing (pDock);
 		}
 		return FALSE;
-	}
+	}*/
 	
 	pDock->container.bInside = TRUE;
 	// animation d'entree.
@@ -971,7 +960,7 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 		cairo_dock_pop_up (pDock);
 	}
 	
-	// si on etait en auto-hide, on commence a monter.
+	// si on etait cache (entierement ou partiellement), on montre.
 	if (pDock->fHideOffset != 0 && pDock->iRefCount == 0)
 	{
 		//g_print ("  on commence a monter\n");
@@ -1160,7 +1149,7 @@ gboolean cairo_dock_on_button_press (GtkWidget* pWidget, GdkEventButton* pButton
 
 						if (! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (s_pIconClicked))
 						{
-							cairo_dock_request_icon_animation (s_pIconClicked, pDock, "bounce", 2);
+							cairo_dock_request_icon_animation (s_pIconClicked, CAIRO_CONTAINER (pDock), "bounce", 2);
 						}
 						gtk_widget_queue_draw (pDock->container.pWidget);
 					}
@@ -1319,6 +1308,11 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 			//g_print ("+++ input shape at rest on configure\n");
 			cairo_dock_set_input_shape_at_rest (pDock);
 		}
+		else if (pDock->iInputState == CAIRO_DOCK_INPUT_ACTIVE)
+		{
+			//g_print ("+++ input shape active on configure\n");
+			cairo_dock_set_input_shape_active (pDock);
+		}
 		
 		if (g_bUseOpenGL)
 		{
@@ -1418,6 +1412,7 @@ gboolean cairo_dock_on_configure (GtkWidget* pWidget, GdkEventConfigure* pEvent,
 
 
 static gboolean s_bWaitForData = FALSE;
+static gboolean s_bCouldDrop = FALSE;
 
 void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint time, CairoDock *pDock)
 {
@@ -1460,10 +1455,61 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 	}
 	
 	//\_________________ On calcule la position a laquelle on l'a lache.
-	cd_message (">>> cReceivedData : '%s'", cReceivedData);
-	int iDropX = (pDock->container.bIsHorizontal ? x : y);
-	double fOrder = CAIRO_DOCK_LAST_ORDER;
-	Icon *pPointedIcon = NULL, *pNeighboorIcon = NULL;
+	cd_debug (">>> cReceivedData : '%s' (%d/%d)", cReceivedData, s_bCouldDrop, pDock->bCanDrop);
+	/* icon => drop on icon
+	no icon => if order undefined: drop on dock; else: drop between 2 icons.*/
+	Icon *pPointedIcon = NULL;
+	double fOrder;
+	if (s_bCouldDrop/**pDock->bCanDrop*/ || g_str_has_suffix (cReceivedData, ".desktop"))  // can drop on the dock (.desktop are always added, not .sh)
+	{
+		cd_debug ("drop between icons");
+		if (myDocksParam.bLockIcons || myDocksParam.bLockAll)  // locked, can't add anything.
+		{
+			gtk_drag_finish (dc, FALSE, FALSE, time);
+			return ;
+		}
+		
+		pPointedIcon = NULL;
+		fOrder = 0;
+		
+		// try to guess where we dropped.
+		int iDropX = (pDock->container.bIsHorizontal ? x : y);
+		Icon *pNeighboorIcon;
+		Icon *icon;
+		GList *ic;
+		for (ic = pDock->icons; ic != NULL; ic = ic->next)
+		{
+			icon = ic->data;
+			if (icon->bPointed)
+			{
+				if (iDropX < icon->fDrawX + icon->fWidth * icon->fScale/2)  // on the left side of the icon
+				{
+					pNeighboorIcon = (ic->prev != NULL ? ic->prev->data : NULL);
+					fOrder = (pNeighboorIcon != NULL ? (icon->fOrder + pNeighboorIcon->fOrder) / 2 : icon->fOrder - 1);
+				}
+				else  // on the right side of the icon
+				{
+					pNeighboorIcon = (ic->next != NULL ? ic->next->data : NULL);
+					fOrder = (pNeighboorIcon != NULL ? (icon->fOrder + pNeighboorIcon->fOrder) / 2 : icon->fOrder + 1);
+				}
+				break;
+			}
+		}
+	}
+	else  // drop on an icon or nowhere.
+	{
+		pPointedIcon = cairo_dock_get_pointed_icon (pDock->icons);
+		fOrder = CAIRO_DOCK_LAST_ORDER;
+		if (pPointedIcon == NULL)  // no icon => abort
+		{
+			cd_debug ("drop nowhere");
+			gtk_drag_finish (dc, FALSE, FALSE, time);
+			return;
+		}
+	}
+	cd_debug ("drop on %s (%.2f)", pPointedIcon?pPointedIcon->cName:"dock", fOrder);
+	/**int iDropX = (pDock->container.bIsHorizontal ? x : y);
+	Icon *pNeighboorIcon = NULL;
 	Icon *icon;
 	GList *ic;
 	for (ic = pDock->icons; ic != NULL; ic = ic->next)
@@ -1474,19 +1520,20 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 			//g_print ("On pointe sur %s\n", icon->cName);
 			pPointedIcon = icon;
 			double fMargin;  /// deviendra obsolete si le drag-received fonctionne.
-			if (g_str_has_suffix (cReceivedData, ".desktop")/** || g_str_has_suffix (cReceivedData, ".sh")*/)  // si c'est un .desktop, on l'ajoute.
+			if (g_str_has_suffix (cReceivedData, ".desktop"))  // si c'est un .desktop, on l'ajoute.
 			{
 				if (myDocksParam.bLockIcons || myDocksParam.bLockAll)
 				{
 					gtk_drag_finish (dc, FALSE, FALSE, time);
 					return ;
 				}
-				///fMargin = 0.5;  // on ne sera jamais dessus.
-				fMargin = 0.25;
+				fMargin = 0.5;  // on ne sera jamais dessus.
+				///fMargin = 0.25;
 			}
 			else  // sinon on le lance si on est sur l'icone, et on l'ajoute autrement.
 				fMargin = 0.25;
-
+			cd_debug ("%d > %.2f", iDropX, icon->fX + icon->fWidth * icon->fScale * (1 - fMargin));
+			cd_debug ("%d < %.2f", iDropX, icon->fX + icon->fWidth * icon->fScale * fMargin);
 			if (iDropX > icon->fX + icon->fWidth * icon->fScale * (1 - fMargin))  // on est apres.
 			{
 				if (myDocksParam.bLockIcons || myDocksParam.bLockAll)
@@ -1512,7 +1559,7 @@ void cairo_dock_on_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, g
 				fOrder = CAIRO_DOCK_LAST_ORDER;
 			}
 		}
-	}
+	}*/
 	
 	cairo_dock_notify_drop_data (cReceivedData, pPointedIcon, fOrder, CAIRO_CONTAINER (pDock));
 	
@@ -1624,6 +1671,7 @@ void cairo_dock_on_drag_leave (GtkWidget *pWidget, GdkDragContext *dc, guint tim
 	//g_print ("stop dragging 2\n");
 	s_bWaitForData = FALSE;
 	pDock->bIsDragging = FALSE;
+	s_bCouldDrop = pDock->bCanDrop;
 	pDock->bCanDrop = FALSE;
 	//cairo_dock_stop_marking_icons (pDock);
 	pDock->iAvoidingMouseIconType = -1;
