@@ -37,6 +37,7 @@
 #include "cairo-dock-module-factory.h"  // cairo_dock_search_container_from_icon
 #include "cairo-dock-dock-manager.h"  // cairo_dock_search_dock_from_name
 #include "cairo-dock-desklet-factory.h"  // cairo_dock_search_container_from_icon
+#include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-opengl.h"
@@ -269,7 +270,9 @@ void cairo_dock_redraw_icon (Icon *icon, CairoContainer *pContainer)
 	GdkRectangle rect;
 	cairo_dock_compute_icon_area (icon, pContainer, &rect);
 	
-	if (CAIRO_DOCK_IS_DOCK (pContainer) && (cairo_dock_is_hidden (CAIRO_DOCK (pContainer)) && ! icon->bIsDemandingAttention && ! icon->bAlwaysVisible) || (CAIRO_DOCK (pContainer)->iRefCount != 0 && ! GTK_WIDGET_VISIBLE (pContainer->pWidget)))  // inutile de redessiner.
+	if (CAIRO_DOCK_IS_DOCK (pContainer) &&
+		( (cairo_dock_is_hidden (CAIRO_DOCK (pContainer)) && ! icon->bIsDemandingAttention && ! icon->bAlwaysVisible)
+		|| (CAIRO_DOCK (pContainer)->iRefCount != 0 && ! GTK_WIDGET_VISIBLE (pContainer->pWidget)) ) )  // inutile de redessiner.
 		return ;
 	_redraw_container_area (pContainer, &rect);
 }
@@ -421,6 +424,7 @@ gboolean cairo_dock_emit_signal_on_container (CairoContainer *pContainer, const
 }
 gboolean cairo_dock_emit_leave_signal (CairoContainer *pContainer)
 {
+	// actualize the coordinates of the pointer, since they are most probably out-dated (because the mouse has left the dock, or because a right-click generates an event with (0;0) coordinates)
 	if (pContainer->bIsHorizontal)
 		gdk_window_get_pointer (pContainer->pWidget->window, &pContainer->iMouseX, &pContainer->iMouseY, NULL);
 	else
@@ -438,9 +442,7 @@ static void _cairo_dock_delete_menu (GtkMenuShell *menu, CairoDock *pDock)
 	g_return_if_fail (CAIRO_DOCK_IS_DOCK (pDock));
 	pDock->bMenuVisible = FALSE;
 	
-	//g_print ("on force a quitter\n");
-	pDock->container.bInside = TRUE;
-	// on recupere la position de la souris avant le leave, car le clic droit a genere precedemment un leave-event avec des coordonnees nulles (0;0), donc le dock a perdu la position de la souris; du coup, lors du leave qu'on s'apprete a envoyer, il ne verra pas si la souris est encore dedans, et donc se cachera/retrecira, ce qu'on ne veut pas.
+	///pDock->container.bInside = TRUE;
 	cairo_dock_emit_leave_signal (CAIRO_CONTAINER (pDock));
 }
 static void _place_menu_on_icon (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer *data)
@@ -537,6 +539,9 @@ GtkWidget *cairo_dock_add_in_menu_with_stock_and_data (const gchar *cLabel, cons
 		{
 			image = gtk_image_new_from_stock (gtkStock, GTK_ICON_SIZE_MENU);
 		}
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
+#endif
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
 	}
 	gtk_menu_shell_append  (GTK_MENU_SHELL (pMenu), pMenuItem);
@@ -545,6 +550,36 @@ GtkWidget *cairo_dock_add_in_menu_with_stock_and_data (const gchar *cLabel, cons
 	return pMenuItem;
 }
 
+GtkWidget *cairo_dock_create_sub_menu (const gchar *cLabel, GtkWidget *pMenu, const gchar *cImage)
+{
+	GtkWidget *pMenuItem, *image, *pSubMenu = gtk_menu_new ();
+	if (cImage == NULL)
+	{
+		pMenuItem = gtk_menu_item_new_with_label (cLabel);
+	}
+	else
+	{
+		pMenuItem = gtk_image_menu_item_new_with_label (cLabel);
+		if (*cImage == '/')
+		{
+			GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size (cImage, 24, 24, NULL);
+			image = gtk_image_new_from_pixbuf (pixbuf);
+			g_object_unref (pixbuf);
+		}
+		else
+		{
+			image = gtk_image_new_from_stock (cImage, GTK_ICON_SIZE_MENU);
+		}
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
+		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (pMenuItem), TRUE);
+#endif
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (pMenuItem), image);
+	}
+	gtk_menu_shell_append (GTK_MENU_SHELL (pMenu), pMenuItem); 
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (pMenuItem), pSubMenu);
+	return pSubMenu; 
+}
+
 
 static GtkWidget *s_pMenu = NULL;
 static gboolean _on_destroy_menu (GtkWidget *widget, GdkEvent  *event, gpointer   user_data)
@@ -672,10 +707,10 @@ void gldi_register_containers_manager (void)
 	myContainersMgr.mgr.get_config 	= (GldiManagerGetConfigFunc)get_config;
 	myContainersMgr.mgr.reset_config = (GldiManagerResetConfigFunc)NULL;
 	// Config
-	myContainersMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myContainersParam;
+	myContainersMgr.mgr.pConfig = (GldiManagerConfigPtr)&myContainersParam;
 	myContainersMgr.mgr.iSizeOfConfig = sizeof (CairoContainersParam);
 	// data
-	myContainersMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myContainersMgr.mgr.pData = (GldiManagerDataPtr)NULL;
 	myContainersMgr.mgr.iSizeOfData = 0;
 	// signals
 	cairo_dock_install_notifications_on_object (&myContainersMgr, NB_NOTIFICATIONS_CONTAINER);
