@@ -1,26 +1,27 @@
 /*
-** Login : <ctaf42@gmail.com>
-** Started on  Sun Jan 27 18:35:38 2008 Cedric GESTES
-** $Id$
-**
-** Author(s)
-**  - Cedric GESTES <ctaf42@gmail.com>
-**  - Fabrice REY
-**
-** Copyright (C) 2008 Cedric GESTES
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 3 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+* This file is a part of the Cairo-Dock project
+* Login : <ctaf42@gmail.com>
+* Started on  Sun Jan 27 18:35:38 2008 Cedric GESTES
+* $Id$
+*
+* Author(s)
+*  - Cedric GESTES <ctaf42@gmail.com>
+*  - Fabrice REY
+*
+* Copyright : (C) 2008 Cedric GESTES
+* E-mail    : see the 'copyright' file.
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License
+* as published by the Free Software Foundation; either version 3
+* of the License, or (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+* You should have received a copy of the GNU General Public License
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef __CAIRO_DESKLET_FACTORY_H__
@@ -282,6 +283,8 @@ void cairo_dock_set_desklet_accessibility (CairoDesklet *pDesklet, CairoDeskletV
 */
 void cairo_dock_set_desklet_sticky (CairoDesklet *pDesklet, gboolean bSticky);
 
+gboolean cairo_dock_desklet_is_sticky (CairoDesklet *pDesklet);
+
 /** Lock the position of a desklet. This makes the desklet impossible to rotate, drag with the mouse, or retach to the dock. The new state is saved in conf.
 *@param pDesklet the desklet.
 *@param bPositionLocked whether the position should be locked or not.
