@@ -60,7 +60,7 @@ extern CairoDockHidingEffect *g_pHidingBackend;  // cairo_dock_is_hidden
 static void _cairo_dock_compute_dialog_sizes (CairoDialog *pDialog)
 {
 	pDialog->iMessageWidth = pDialog->iIconSize + _drawn_text_width (pDialog) + (pDialog->iTextWidth != 0 ? 2 : 0) * CAIRO_DIALOG_TEXT_MARGIN - pDialog->iIconOffsetX;  // icone + marge + texte + marge.
-	pDialog->iMessageHeight = MAX (pDialog->iIconSize, pDialog->iTextHeight) + (pDialog->pInteractiveWidget != NULL ? CAIRO_DIALOG_VGAP : 0);  // (icone/texte + marge) + widget + (marge + boutons) + pointe.
+	pDialog->iMessageHeight = MAX (pDialog->iIconSize - pDialog->iIconOffsetY, pDialog->iTextHeight) + (pDialog->pInteractiveWidget != NULL ? CAIRO_DIALOG_VGAP : 0);  // (icone/texte + marge) + widget + (marge + boutons) + pointe.
 	
 	if (pDialog->pButtons != NULL)
 	{
@@ -345,7 +345,7 @@ static cairo_surface_t *_cairo_dock_create_dialog_icon_surface (const gchar *cIm
 			if (pContainer == NULL)
 				pContainer = cairo_dock_search_container_from_icon (pIcon);
 			int iWidth, iHeight;
-			cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 			pIconBuffer = cairo_dock_duplicate_surface (pIcon->pIconBuffer,
 				iWidth, iHeight,
 				iDesiredSize, iDesiredSize);
@@ -494,6 +494,10 @@ CairoDialog *cairo_dock_new_dialog (CairoDialogAttribute *pAttribute, Icon *pIco
 	if ((pDialog->pInteractiveWidget || pDialog->pButtons || pAttribute->iTimeLength == 0) && ! pDialog->bNoInput)
 	{
 		gtk_window_set_modal (GTK_WINDOW (pDialog->container.pWidget), TRUE);
+		if (CAIRO_DOCK_IS_DOCK (pContainer))
+		{
+			cairo_dock_emit_enter_signal (pContainer);  // to prevent the dock from hiding. We want to see it until the dialog is visible (a leave event will be emited when it disappears).
+		}
 	}
 	pDialog->bHideOnClick = pAttribute->bHideOnClick;
 	
@@ -660,8 +664,8 @@ void cairo_dock_free_dialog (CairoDialog *pDialog)
 
 static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContainer *pContainer, int *iX, int *iY, gboolean *bRight, gboolean *bIsHorizontal, gboolean *bDirectionUp, double fAlign)
 {
-	g_return_if_fail (pIcon != NULL && pContainer != NULL);
-	//g_print ("%s (%.2f, %.2f)\n", __func__, pIcon->fXAtRest, pIcon->fDrawX);
+	g_return_if_fail (/*pIcon != NULL && */pContainer != NULL);
+	//g_print ("%s (%.2f, %.2f)\n", __func__, pIcon?pIcon->fXAtRest:0, pIcon?pIcon->fDrawX:0);
 	if (CAIRO_DOCK_IS_DOCK (pContainer))
 	{
 		CairoDock *pDock = CAIRO_DOCK (pContainer);
@@ -671,12 +675,12 @@ static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContaine
 			Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, &pParentDock);
 			_cairo_dock_dialog_calculate_aimed_point (pPointingIcon, CAIRO_CONTAINER (pParentDock), iX, iY, bRight, bIsHorizontal, bDirectionUp, fAlign);
 		}
-		else  // dock principal ou sous-dock wisible.
+		else  // dock principal ou sous-dock visible.
 		{
 			*bIsHorizontal = (pContainer->bIsHorizontal == CAIRO_DOCK_HORIZONTAL);
 			int dy;
 			if (pDock->iInputState == CAIRO_DOCK_INPUT_ACTIVE)
-				dy = 0;
+				dy = pContainer->iHeight - pDock->iActiveHeight;
 			else if (cairo_dock_is_hidden (pDock))
 				dy = pContainer->iHeight-1;  // on laisse 1 pixels pour pouvoir sortir du dialogue avant de toucher le bord de l'ecran, et ainsi le faire se replacer, lorsqu'on fait apparaitre un dock en auto-hide.
 			else
@@ -737,7 +741,7 @@ static void _cairo_dock_dialog_calculate_aimed_point (Icon *pIcon, CairoContaine
 
 void cairo_dock_set_dialog_orientation (CairoDialog *pDialog, CairoContainer *pContainer)
 {
-	if (pContainer != NULL && pDialog->pIcon != NULL)
+	if (pContainer != NULL/* && pDialog->pIcon != NULL*/)
 	{
 		_cairo_dock_dialog_calculate_aimed_point (pDialog->pIcon, pContainer, &pDialog->iAimedX, &pDialog->iAimedY, &pDialog->bRight, &pDialog->bTopBottomDialog, &pDialog->container.bDirectionUp, pDialog->fAlign);
 	}
@@ -785,6 +789,24 @@ GtkWidget *cairo_dock_steal_interactive_widget_from_dialog (CairoDialog *pDialog
 	return pInteractiveWidget;
 }
 
+void cairo_dock_set_dialog_widget_text_color (GtkWidget *pWidget)
+{
+	static GdkColor color;
+	color.red = myDialogsParam.dialogTextDescription.fColorStart[0] * 65535;
+	color.green = myDialogsParam.dialogTextDescription.fColorStart[1] * 65535;
+	color.blue = myDialogsParam.dialogTextDescription.fColorStart[2] * 65535;
+	gtk_widget_modify_fg (pWidget, GTK_STATE_NORMAL, &color);
+}
+
+void cairo_dock_set_dialog_widget_bg_color (GtkWidget *pWidget)
+{
+	static GdkColor color;
+	color.red = myDialogsParam.fDialogColor[0] * 65535;
+	color.green = myDialogsParam.fDialogColor[1] * 65535;
+	color.blue = myDialogsParam.fDialogColor[2] * 65535;
+	gtk_widget_modify_bg (pWidget, GTK_STATE_NORMAL, &color);
+}
+
 void cairo_dock_set_new_dialog_text_surface (CairoDialog *pDialog, cairo_surface_t *pNewTextSurface, int iNewTextWidth, int iNewTextHeight)
 {
 	int iPrevMessageWidth = pDialog->iMessageWidth;
@@ -805,6 +827,11 @@ void cairo_dock_set_new_dialog_text_surface (CairoDialog *pDialog, cairo_surface
 		gtk_widget_set (pDialog->pMessageWidget, "width-request", pDialog->iMessageWidth, "height-request", pDialog->iMessageHeight, NULL);  // inutile de replacer le dialogue puisque sa gravite fera le boulot.
 		
 		gtk_widget_queue_draw (pDialog->container.pWidget);
+		
+		gboolean bInside = pDialog->container.bInside;
+		pDialog->container.bInside = FALSE;  // unfortunately the gravity is really badly handled by many WMs, so we have to replace he dialog ourselves :-/
+		cairo_dock_replace_all_dialogs ();
+		pDialog->container.bInside = bInside;
 	}
 	else
 	{
