@@ -99,16 +99,16 @@ static inline cairo_surface_t *_cairo_dock_load_button_icon (const gchar *cButto
 		iTexture = cairo_dock_create_texture_from_surface (pSurface);\
 	else\
 		iTexture = 0; } while (0)
-void cairo_dock_load_dialog_buttons (gchar *cButtonOkImage, gchar *cButtonCancelImage)
+static void cairo_dock_load_dialog_buttons (gchar *cButtonOkImage, gchar *cButtonCancelImage)
 {
 	//g_print ("%s (%s ; %s)\n", __func__, cButtonOkImage, cButtonCancelImage);
 	if (s_pButtonOkSurface != NULL)
 		cairo_surface_destroy (s_pButtonOkSurface);
-	s_pButtonOkSurface = _cairo_dock_load_button_icon (cButtonOkImage, GLDI_SHARE_DATA_DIR"/cairo-dock-ok.svg");
+	s_pButtonOkSurface = _cairo_dock_load_button_icon (cButtonOkImage, GLDI_SHARE_DATA_DIR"/icons/cairo-dock-ok.svg");
 
 	if (s_pButtonCancelSurface != NULL)
 		cairo_surface_destroy (s_pButtonCancelSurface);
-	s_pButtonCancelSurface = _cairo_dock_load_button_icon (cButtonCancelImage, GLDI_SHARE_DATA_DIR"/cairo-dock-cancel.svg");
+	s_pButtonCancelSurface = _cairo_dock_load_button_icon (cButtonCancelImage, GLDI_SHARE_DATA_DIR"/icons/cairo-dock-cancel.svg");
 	
 	if (0 && g_bUseOpenGL)
 	{
@@ -117,7 +117,7 @@ void cairo_dock_load_dialog_buttons (gchar *cButtonOkImage, gchar *cButtonCancel
 	}
 }
 
-void cairo_dock_unload_dialog_buttons (void)
+static void cairo_dock_unload_dialog_buttons (void)
 {
 	if (s_pButtonOkSurface != NULL)
 	{
@@ -197,7 +197,7 @@ static int _cairo_dock_find_clicked_button_in_dialog (GdkEventButton* pButton, C
 	iButtonY = (pDialog->container.bDirectionUp ?
 		pDialog->iTopMargin + pDialog->iMessageHeight + pDialog->iInteractiveHeight + CAIRO_DIALOG_VGAP :
 		pDialog->container.iHeight - (pDialog->iTopMargin + pDialog->iButtonsHeight));
-	int iMinButtonX = .5 * (pDialog->container.iWidth - (n - 1) * CAIRO_DIALOG_BUTTON_GAP - n * myDialogsParam.iDialogButtonWidth);
+	int iMinButtonX = .5 * ((pDialog->container.iWidth - pDialog->iLeftMargin - pDialog->iRightMargin) - (n - 1) * CAIRO_DIALOG_BUTTON_GAP - n * myDialogsParam.iDialogButtonWidth) + pDialog->iLeftMargin;
 	for (i = 0; i < pDialog->iNbButtons; i++)
 	{
 		iButtonX = iMinButtonX + i * (CAIRO_DIALOG_BUTTON_GAP + myDialogsParam.iDialogButtonWidth);
@@ -342,7 +342,7 @@ static void _cairo_dock_draw_inside_dialog_opengl (CairoDialog *pDialog, double
 		int iButtonX, iButtonY;
 		int i, n = pDialog->iNbButtons;
 		iButtonY = (pDialog->container.bDirectionUp ? pDialog->iTopMargin + pDialog->iMessageHeight + pDialog->iInteractiveHeight + CAIRO_DIALOG_VGAP : pDialog->container.iHeight - pDialog->iTopMargin - pDialog->iButtonsHeight - CAIRO_DIALOG_VGAP);
-		int iMinButtonX = .5 * (pDialog->container.iWidth - (n - 1) * CAIRO_DIALOG_BUTTON_GAP - n * myDialogsParam.iDialogButtonWidth);
+		int iMinButtonX = .5 * ((pDialog->container.iWidth - pDialog->iLeftMargin - pDialog->iRightMargin) - (n - 1) * CAIRO_DIALOG_BUTTON_GAP - n * myDialogsParam.iDialogButtonWidth) + pDialog->iLeftMargin;
 		for (i = 0; i < pDialog->iNbButtons; i++)
 		{
 			iButtonX = iMinButtonX + i * (CAIRO_DIALOG_BUTTON_GAP + myDialogsParam.iDialogButtonWidth);
@@ -518,6 +518,13 @@ gboolean cairo_dock_dialog_unreference (CairoDialog *pDialog)
 				//g_print ("leave from container %x\n", pContainer);
 				if (pContainer)
 					cairo_dock_emit_leave_signal (pContainer);
+				
+				if (pIcon->iHideLabel > 0)
+				{
+					pIcon->iHideLabel --;
+					if (pIcon->iHideLabel == 0 && pContainer)
+						gtk_widget_queue_draw (pContainer->pWidget);
+				}
 			}
 			cairo_dock_free_dialog (pDialog);
 			s_pDialogList = g_slist_remove (s_pDialogList, pDialog);
@@ -591,6 +598,12 @@ CairoDialog *cairo_dock_build_dialog (CairoDialogAttribute *pAttribute, Icon *pI
 	CairoDialog *pDialog = cairo_dock_new_dialog (pAttribute, pIcon, pContainer);
 	if (pIcon && pIcon->pSubDock)  // un sous-dock par-dessus le dialogue est tres genant.
 		cairo_dock_emit_leave_signal (CAIRO_CONTAINER (pIcon->pSubDock));
+	if (pIcon && CAIRO_DOCK_IS_DOCK (pContainer) && CAIRO_DOCK (pContainer)->fMagnitudeMax == 0)  // view without zoom, the dialog is stuck to the icon, and therefore is under the label, so hide this one.
+	{
+		if (pIcon->iHideLabel == 0 && pContainer)
+			gtk_widget_queue_draw (pContainer->pWidget);
+		pIcon->iHideLabel ++;
+	}
 	s_pDialogList = g_slist_prepend (s_pDialogList, pDialog);
 	if (pDialog->iNbButtons != 0 && (s_pButtonOkSurface == NULL || s_pButtonCancelSurface == NULL))
 		cairo_dock_load_dialog_buttons (myDialogsParam.cButtonOkImage, myDialogsParam.cButtonCancelImage);
@@ -655,7 +668,7 @@ static void _cairo_dock_dialog_find_optimal_placement (CairoDialog *pDialog)
 			continue ;
 		if (pDialogOnOurWay != pDialog)  // check if this dialog can overlap us.
 		{
-			if (GTK_WIDGET_VISIBLE (pDialogOnOurWay->container.pWidget) && pDialogOnOurWay->pIcon != NULL)
+			if (pDialogOnOurWay->container.pWidget && GTK_WIDGET_VISIBLE (pDialogOnOurWay->container.pWidget) && pDialogOnOurWay->pIcon != NULL)
 			{
 				iTopY = pDialogOnOurWay->container.iWindowPositionY;
 				iBottomY = pDialogOnOurWay->container.iWindowPositionY + pDialogOnOurWay->container.iHeight;
@@ -702,12 +715,12 @@ static void _cairo_dock_dialog_find_optimal_placement (CairoDialog *pDialog)
 static void cairo_dock_place_dialog (CairoDialog *pDialog, CairoContainer *pContainer)
 {
 	//g_print ("%s (%x;%d, %s)\n", __func__, pDialog->pIcon, pContainer, pDialog->pIcon?pDialog->pIcon->cParentDockName:"none");
-	if (pDialog->container.bInside)
+	if (pDialog->container.bInside && ! (pDialog->pInteractiveWidget || pDialog->action_on_answer))  // in the case of a modal dialog, the dialog takes the dock's events, including the "enter-event" one. So we are inside the dialog as soon as we enter the dock, and consequently, the dialog is not replaced when the dock unhides itself.
 		return;
 	
 	int w, h;
 	GdkGravity iGravity;
-	if (pContainer != NULL && pDialog->pIcon != NULL)
+	if (pContainer != NULL/* && pDialog->pIcon != NULL*/)
 	{
 		cairo_dock_set_dialog_orientation (pDialog, pContainer);
 		
@@ -866,8 +879,8 @@ CairoDialog *cairo_dock_show_temporary_dialog_with_default_icon (const gchar *cT
 {
 	g_return_val_if_fail (cText != NULL, NULL);
 	
-	gchar *cIconPath = g_strdup_printf ("%s/%s", GLDI_SHARE_DATA_DIR, CAIRO_DOCK_ICON);
-	cIconPath = g_strdup_printf ("%s/%s", GLDI_SHARE_DATA_DIR, "cairo-dock-animated.xpm");
+	//const gchar *cIconPath = GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_ICON;
+	const gchar *cIconPath = GLDI_SHARE_DATA_DIR"/icons/cairo-dock-animated.xpm"; // it's animated
 	
 	CairoDialogAttribute attr;
 	memset (&attr, 0, sizeof (CairoDialogAttribute));
@@ -878,7 +891,6 @@ CairoDialog *cairo_dock_show_temporary_dialog_with_default_icon (const gchar *cT
 	attr.iTimeLength = (int) fTimeLength;
 	CairoDialog *pDialog = cairo_dock_build_dialog (&attr, pIcon, pContainer);
 	
-	g_free (cIconPath);
 	return pDialog;
 }
 
@@ -900,6 +912,7 @@ static inline GtkWidget *_cairo_dock_make_hscale_for_dialog (double fValueForHSc
 	gtk_range_set_value (GTK_RANGE (pWidget), fValueForHScale);
 
 	gtk_widget_set (pWidget, "width-request", CAIRO_DIALOG_MIN_SCALE_WIDTH, NULL);
+	cairo_dock_set_dialog_widget_text_color (pWidget);
 	return pWidget;
 }
 
@@ -969,6 +982,10 @@ int cairo_dock_show_dialog_and_wait (const gchar *cText, Icon *pIcon, CairoConta
 	{
 		pDialog->fAppearanceCounter = 1.;
 		gtk_window_set_modal (GTK_WINDOW (pDialog->container.pWidget), TRUE);
+		if (CAIRO_DOCK_IS_DOCK (pContainer))
+		{
+			cairo_dock_emit_enter_signal (pContainer);  // to prevent the dock from hiding. We want to see it until the dialog is visible (a leave event will be emited when it disappears).
+		}
 		g_signal_connect (pDialog->container.pWidget,
 			"delete-event",
 			G_CALLBACK (_cairo_dock_dialog_destroyed),
@@ -1062,11 +1079,15 @@ Icon *cairo_dock_get_dialogless_icon_full (CairoDock *pDock)
 	if (pDock == NULL || pDock->icons == NULL)
 		return NULL;
 
-	Icon *pIcon = cairo_dock_get_first_icon_of_type (pDock->icons, CAIRO_DOCK_SEPARATOR12);
+	Icon *pIcon = cairo_dock_get_first_icon_of_group (pDock->icons, CAIRO_DOCK_SEPARATOR12);
 	if (pIcon != NULL && ! cairo_dock_icon_has_dialog (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
 		return pIcon;
 	
-	pIcon = cairo_dock_get_first_icon_of_type (pDock->icons, CAIRO_DOCK_SEPARATOR23);
+	pIcon = cairo_dock_get_first_icon_of_group (pDock->icons, CAIRO_DOCK_SEPARATOR23);
+	if (pIcon != NULL && ! cairo_dock_icon_has_dialog (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
+		return pIcon;
+	
+	pIcon = cairo_dock_get_first_icon_of_true_type (pDock->icons, CAIRO_DOCK_ICON_TYPE_SEPARATOR);
 	if (pIcon != NULL && ! cairo_dock_icon_has_dialog (pIcon) && pIcon->cParentDockName != NULL && ! cairo_dock_icon_is_being_removed (pIcon))
 		return pIcon;
 	
@@ -1118,6 +1139,13 @@ void cairo_dock_hide_dialog (CairoDialog *pDialog)
 			//g_print ("leave from container %x\n", pContainer);
 			if (pContainer)
 				cairo_dock_emit_leave_signal (pContainer);
+			
+			if (pIcon->iHideLabel > 0)
+			{
+				pIcon->iHideLabel --;
+				if (pIcon->iHideLabel == 0 && pContainer)
+					gtk_widget_queue_draw (pContainer->pWidget);
+			}
 		}
 	}
 }
@@ -1134,6 +1162,13 @@ void cairo_dock_unhide_dialog (CairoDialog *pDialog)
 		{
 			CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
 			cairo_dock_place_dialog (pDialog, pContainer);
+			
+			if (CAIRO_DOCK_IS_DOCK (pContainer) && CAIRO_DOCK (pContainer)->fMagnitudeMax == 0)
+			{
+				if (pIcon->iHideLabel == 0 && pContainer)
+					gtk_widget_queue_draw (pContainer->pWidget);
+				pIcon->iHideLabel ++;
+			}
 		}
 	}
 	pDialog->bPositionForced = FALSE;
@@ -1288,11 +1323,11 @@ void gldi_register_dialogs_manager (void)
 	myDialogsMgr.mgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
 	// Config
 	memset (&myDialogsParam, 0, sizeof (CairoDialogsParam));
-	myDialogsMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myDialogsParam;
+	myDialogsMgr.mgr.pConfig = (GldiManagerConfigPtr)&myDialogsParam;
 	myDialogsMgr.mgr.iSizeOfConfig = sizeof (CairoDialogsParam);
 	// data
 	myDialogsMgr.mgr.iSizeOfData = 0;
-	myDialogsMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myDialogsMgr.mgr.pData = (GldiManagerDataPtr)NULL;
 	// signals
 	cairo_dock_install_notifications_on_object (&myDialogsMgr, NB_NOTIFICATIONS_DIALOG);
 	// register
