@@ -86,9 +86,6 @@ typedef enum {
 	} CairoDialogNotifications;
 	
 
-void cairo_dock_load_dialog_buttons (gchar *cButtonOkImage, gchar *cButtonCancelImage);
-void cairo_dock_unload_dialog_buttons (void);
-
 /** Increase by 1 the reference of a dialog. Use #cairo_dock_dialog_unreference when you're done, so that the dialog can be destroyed.
 *@param pDialog the dialog.
 *@return TRUE if the reference was not nul, otherwise you must not use it.
