@@ -113,7 +113,13 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 			pDock->iMaxIconHeight = 10;
 		pDock->container.fRatio = 1.;
 	}
+	
+	pDock->iActiveWidth = pDock->iActiveHeight = 0;
 	pDock->pRenderer->compute_size (pDock);
+	if (pDock->iActiveWidth == 0)
+		pDock->iActiveWidth = pDock->iMaxDockWidth;
+	if (pDock->iActiveHeight == 0)
+		pDock->iActiveHeight = pDock->iMaxDockHeight;
 	
 	double hmax = pDock->iMaxIconHeight;
 	int iMaxAuthorizedWidth = cairo_dock_get_max_authorized_dock_width (pDock);
@@ -158,7 +164,12 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 			}
 			hmax *= pDock->container.fRatio / fPrevRatio;
 			
+			pDock->iActiveWidth = pDock->iActiveHeight = 0;
 			pDock->pRenderer->compute_size (pDock);
+			if (pDock->iActiveWidth == 0)
+				pDock->iActiveWidth = pDock->iMaxDockWidth;
+			if (pDock->iActiveHeight == 0)
+				pDock->iActiveHeight = pDock->iMaxDockHeight;
 		}
 		
 		//g_print ("*** ratio : %.3f -> %.3f\n", fPrevRatio, pDock->container.fRatio);
@@ -416,6 +427,11 @@ void cairo_dock_update_input_shape (CairoDock *pDock)
 		g_object_unref ((gpointer) pDock->pHiddenShapeBitmap);
 		pDock->pHiddenShapeBitmap = NULL;
 	}
+	if (pDock->pActiveShapeBitmap != NULL)
+	{
+		g_object_unref ((gpointer) pDock->pActiveShapeBitmap);
+		pDock->pActiveShapeBitmap = NULL;
+	}
 	
 	//\_______________ on definit les tailles des zones.
 	int W = pDock->iMaxDockWidth;
@@ -430,6 +446,8 @@ void cairo_dock_update_input_shape (CairoDock *pDock)
 	//\_______________ on verifie que les conditions sont toujours remplies.
 	if (w == 0 || h == 0 || pDock->iRefCount > 0 || W == 0 || H == 0)
 	{
+		if (pDock->iActiveWidth != pDock->iMaxDockWidth || pDock->iActiveHeight != pDock->iMaxDockHeight)  // else all the dock is active when the mouse is inside, so we can just set a NULL shape.
+			pDock->pActiveShapeBitmap = _cairo_dock_create_input_shape (pDock, pDock->iActiveWidth, pDock->iActiveHeight);
 		if (pDock->iInputState != CAIRO_DOCK_INPUT_ACTIVE)
 		{
 			//g_print ("+++ input shape active on update input shape\n");
@@ -443,6 +461,9 @@ void cairo_dock_update_input_shape (CairoDock *pDock)
 	pDock->pShapeBitmap = _cairo_dock_create_input_shape (pDock, w, h);
 	
 	pDock->pHiddenShapeBitmap = _cairo_dock_create_input_shape (pDock, w_, h_);
+	
+	if (pDock->iActiveWidth != pDock->iMaxDockWidth || pDock->iActiveHeight != pDock->iMaxDockHeight)  // else all the dock is active when the mouse is inside, so we can just set a NULL shape.
+		pDock->pActiveShapeBitmap = _cairo_dock_create_input_shape (pDock, pDock->iActiveWidth, pDock->iActiveHeight);
 }
 
 
@@ -737,7 +758,8 @@ void cairo_dock_check_if_mouse_inside_linear (CairoDock *pDock)
 {
 	CairoDockMousePositionType iMousePositionType;
 	int iWidth = pDock->container.iWidth;
-	int iHeight = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
+	///int iHeight = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
+	int iHeight = pDock->iActiveHeight;
 	///int iExtraHeight = (pDock->bAtBottom ? 0 : myIconsParam.iLabelSize);
 	int iExtraHeight = 0;  /// il faudrait voir si on a un sous-dock ou un dialogue au dessus :-/
 	int iMouseX = pDock->container.iMouseX;
@@ -754,17 +776,21 @@ void cairo_dock_check_if_mouse_inside_linear (CairoDock *pDock)
 		if (/*cairo_dock_is_extended_dock (pDock) && */pDock->bAutoHide)  // c'est penible de sortir du dock trop facilement avec l'auto-hide.
 		{
 			if (iMouseY >= 0 && iMouseY < iHeight)
-				iMousePositionType = CAIRO_DOCK_MOUSE_INSIDE;
+				iMousePositionType = CAIRO_DOCK_MOUSE_ON_THE_EDGE;
 			else
 				iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
 		}
 		else
 		{
-			double fSideMargin = fabs (pDock->fAlign - .5) * (iWidth - pDock->fFlatDockWidth);
+			/**double fSideMargin = fabs (pDock->fAlign - .5) * (iWidth - pDock->fFlatDockWidth);
 			if (x_abs < - fSideMargin || x_abs > pDock->fFlatDockWidth + fSideMargin)
 				iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
 			else
+				iMousePositionType = CAIRO_DOCK_MOUSE_ON_THE_EDGE;*/
+			if (iMouseY >= 0 && iMouseY < iHeight)
 				iMousePositionType = CAIRO_DOCK_MOUSE_ON_THE_EDGE;
+			else
+				iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
 		}
 	}
 	else if (iMouseY >= 0 && iMouseY < iHeight)  // et en plus on est dedans en y.  //  && pPointedIcon != NULL
@@ -775,7 +801,7 @@ void cairo_dock_check_if_mouse_inside_linear (CairoDock *pDock)
 	}
 	else
 		iMousePositionType = CAIRO_DOCK_MOUSE_OUTSIDE;
-
+	
 	pDock->iMousePositionType = iMousePositionType;
 }
 
@@ -822,7 +848,7 @@ void cairo_dock_manage_mouse_position (CairoDock *pDock)
 				if (pDock->iRefCount > 0)
 				{
 					Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, NULL);
-					if (pPointingIcon && pPointingIcon->bPointed)  // sous-dock pointe, n le laisse en position haute.
+					if (pPointingIcon && pPointingIcon->bPointed)  // sous-dock pointe, on le laisse en position haute.
 						return;
 				}
 				//g_print ("on force a quitter (iRefCount:%d; bIsGrowingUp:%d; iMagnitudeIndex:%d)\n", pDock->iRefCount, pDock->bIsGrowingUp, pDock->iMagnitudeIndex);
@@ -832,30 +858,31 @@ void cairo_dock_manage_mouse_position (CairoDock *pDock)
 	}
 }
 
-#define make_icon_avoid_mouse(icon) \
+#define make_icon_avoid_mouse(icon, sens) do { \
 	cairo_dock_mark_icon_as_avoiding_mouse (icon);\
 	icon->fAlpha = 0.75;\
 	if (myIconsParam.fAmplitude != 0)\
-		icon->fDrawX += icon->fWidth / 2 * (icon->fScale - 1) / myIconsParam.fAmplitude * (icon->fPhase < G_PI/2 ? -1 : 1);
-
-static gboolean _cairo_dock_check_can_drop_linear (CairoDock *pDock, CairoDockIconGroup iGroup, double fMargin)
+		icon->fDrawX += icon->fWidth * icon->fScale / 4 * sens; } while (0)
+static inline gboolean _cairo_dock_check_can_drop_linear (CairoDock *pDock, CairoDockIconGroup iGroup, double fMargin)
 {
 	gboolean bCanDrop = FALSE;
 	Icon *icon;
-	GList *pFirstDrawnElement = (pDock->pFirstDrawnElement != NULL ? pDock->pFirstDrawnElement : pDock->icons);
-	GList *ic = pFirstDrawnElement;
-	do
+	GList *ic;
+	for (ic = pDock->icons; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		if (icon->bPointed)  // && icon->iAnimationState != CAIRO_DOCK_FOLLOW_MOUSE
+		if (icon->bPointed)
 		{
+			cd_debug ("icon->fWidth: %d, %.2f", (int)icon->fWidth, icon->fScale);
+			cd_debug ("x: %d / %d", pDock->container.iMouseX, (int)icon->fDrawX);
 			if (pDock->container.iMouseX < icon->fDrawX + icon->fWidth * icon->fScale * fMargin)  // on est a gauche.  // fDrawXAtRest
 			{
 				Icon *prev_icon = cairo_dock_get_previous_element (ic, pDock->icons) -> data;
-				if ((cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (iGroup) || cairo_dock_get_icon_order (prev_icon) == cairo_dock_get_group_order (iGroup)))  // && prev_icon->iAnimationType != CAIRO_DOCK_FOLLOW_MOUSE
+				if ((cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (iGroup) || cairo_dock_get_icon_order (prev_icon) == cairo_dock_get_group_order (iGroup)))
 				{
-					make_icon_avoid_mouse (icon);
-					make_icon_avoid_mouse (prev_icon);
+					make_icon_avoid_mouse (icon, 1);
+					if (prev_icon)
+						make_icon_avoid_mouse (prev_icon, -1);
 					//g_print ("%s> <%s\n", prev_icon->cName, icon->cName);
 					bCanDrop = TRUE;
 				}
@@ -863,23 +890,22 @@ static gboolean _cairo_dock_check_can_drop_linear (CairoDock *pDock, CairoDockIc
 			else if (pDock->container.iMouseX > icon->fDrawX + icon->fWidth * icon->fScale * (1 - fMargin))  // on est a droite.  // fDrawXAtRest
 			{
 				Icon *next_icon = cairo_dock_get_next_element (ic, pDock->icons) -> data;
-				if ((icon->iGroup == iGroup || next_icon->iGroup == iGroup))  // && next_icon->iAnimationType != CAIRO_DOCK_FOLLOW_MOUSE
+				if ((cairo_dock_get_icon_order (icon) == cairo_dock_get_group_order (iGroup) || cairo_dock_get_icon_order (next_icon) == cairo_dock_get_group_order (iGroup)))
 				{
-					make_icon_avoid_mouse (icon);
-					make_icon_avoid_mouse (next_icon);
+					make_icon_avoid_mouse (icon, -1);
+					if (next_icon)
+						make_icon_avoid_mouse (next_icon, 1);
 					//g_print ("%s> <%s\n", icon->cName, next_icon->cName);
 					bCanDrop = TRUE;
 				}
-				ic = cairo_dock_get_next_element (ic, pDock->icons);  // on la saute.
-				if (ic == pFirstDrawnElement)
-					break ;
+				ic = ic->next;  // on la saute.
+				if (ic == NULL)
+					break;
 			}  // else on est dessus.
 		}
 		else
 			cairo_dock_stop_marking_icon_as_avoiding_mouse (icon);
-		
-		ic = cairo_dock_get_next_element (ic, pDock->icons);
-	} while (ic != pFirstDrawnElement);
+	}
 	
 	return bCanDrop;
 }
@@ -887,13 +913,18 @@ static gboolean _cairo_dock_check_can_drop_linear (CairoDock *pDock, CairoDockIc
 
 void cairo_dock_check_can_drop_linear (CairoDock *pDock)
 {
-	if (pDock->icons == NULL)
-		return;
-	
-	if (pDock->bIsDragging)
-		pDock->bCanDrop = _cairo_dock_check_can_drop_linear (pDock, pDock->iAvoidingMouseIconType, pDock->fAvoidingMouseMargin);
-	else
+	if (! pDock->bIsDragging)  // not dragging, so no drop possible.
+	{
 		pDock->bCanDrop = FALSE;
+	}
+	else if (pDock->icons == NULL)  // dragging but no icons, so drop always possible.
+	{
+		pDock->bCanDrop = TRUE;
+	}
+	else  // dragging and some icons.
+	{
+		pDock->bCanDrop = _cairo_dock_check_can_drop_linear (pDock, pDock->iAvoidingMouseIconType, pDock->fAvoidingMouseMargin);
+	}
 }
 
 void cairo_dock_stop_marking_icons (CairoDock *pDock)
@@ -920,12 +951,12 @@ void cairo_dock_set_subdock_position_linear (Icon *pPointedIcon, CairoDock *pDoc
 	{
 		pSubDock->fAlign = 0.5;
 		pSubDock->iGapX = iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] / 2;  // ici les sous-dock ont un alignement egal a 0.5
-		pSubDock->iGapY = pDock->iGapY + pDock->iMaxDockHeight;
+		pSubDock->iGapY = pDock->iGapY + pDock->iActiveHeight;
 	}
 	else
 	{
 		pSubDock->fAlign = (pDock->container.bDirectionUp ? 1 : 0);
-		pSubDock->iGapX = (pDock->iGapY + pDock->iMaxDockHeight) * (pDock->container.bDirectionUp ? -1 : 1);
+		pSubDock->iGapX = (pDock->iGapY + pDock->iActiveHeight) * (pDock->container.bDirectionUp ? -1 : 1);
 		if (pDock->container.bDirectionUp)
 			pSubDock->iGapY = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - (iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY)) - pSubDock->iMaxDockHeight / 2;  // les sous-dock ont un alignement egal a 1.
 		else
@@ -970,8 +1001,8 @@ void cairo_dock_show_subdock (Icon *pPointedIcon, CairoDock *pParentDock)
 	}
 	
 	pSubDock->pRenderer->set_subdock_position (pPointedIcon, pParentDock);
-	if (pParentDock->fMagnitudeMax == 0)  // son input shape n'est pas la taille max mais iMinDockHeight.
-		pSubDock->iGapY -= (pParentDock->container.iHeight - pParentDock->iMinDockHeight);
+	///if (pParentDock->fMagnitudeMax == 0)  // son input shape n'est pas la taille max mais iMinDockHeight.
+	///	pSubDock->iGapY -= (pParentDock->container.iHeight - pParentDock->iMinDockHeight);
 	
 	if (pSubDock->icons != NULL)
 	{
