@@ -82,7 +82,7 @@ extern gboolean g_bUseGlitz;
 #endif
 
 
-static void _cairo_dock_set_icon_size (CairoDock *pDock, Icon *icon)
+static void _cairo_dock_set_icon_size (CairoContainer *pDock, Icon *icon)
 {
 	CairoDockIconGroup iType = cairo_dock_get_icon_type (icon);
 	if (CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon))  // une applet peut definir la taille de son icone elle-meme.
@@ -115,7 +115,7 @@ CairoDock *cairo_dock_new_dock (const gchar *cRendererName)
 	pDock->fPostHideOffset = 1.;
 	pDock->iInputState = CAIRO_DOCK_INPUT_AT_REST;  // le dock est cree au repos. La zone d'input sera mis en place lors du configure.
 	
-	pDock->container.iface.set_icon_size = _cairo_dock_set_icon_size;
+	pDock->container.iface.set_icon_size = _cairo_dock_set_icon_size; // warning: assignment from incompatible pointer type
 	
 	//\__________________ On cree la fenetre GTK.
 	GtkWidget *pWindow = cairo_dock_init_container (CAIRO_CONTAINER (pDock));
@@ -265,6 +265,12 @@ void cairo_dock_free_dock (CairoDock *pDock)
 	if (pDock->pShapeBitmap != NULL)
 		g_object_unref ((gpointer) pDock->pShapeBitmap);
 	
+	if (pDock->pHiddenShapeBitmap != NULL)
+		g_object_unref ((gpointer) pDock->pHiddenShapeBitmap);
+	
+	if (pDock->pActiveShapeBitmap != NULL)
+		g_object_unref ((gpointer) pDock->pActiveShapeBitmap);
+	
 	if (pDock->pRenderer != NULL && pDock->pRenderer->free_data != NULL)
 	{
 		pDock->pRenderer->free_data (pDock);
@@ -339,8 +345,8 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	if (g_list_find (pDock->icons, icon) != NULL)  // elle est deja dans ce dock.
 		return ;
 
-	int iPreviousMinWidth = pDock->fFlatDockWidth;
-	int iPreviousMaxIconHeight = pDock->iMaxIconHeight;
+	///int iPreviousMinWidth = pDock->fFlatDockWidth;
+	///int iPreviousMaxIconHeight = pDock->iMaxIconHeight;
 
 	//\______________ On regarde si on doit inserer un separateur.
 	gboolean bSeparatorNeeded = FALSE;
@@ -422,8 +428,8 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	if (bUpdateSize)
 		cairo_dock_update_dock_size (pDock);
 	
-	if (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE && bUpdateSize && ! pDock->bAutoHide && (pDock->fFlatDockWidth != iPreviousMinWidth || pDock->iMaxIconHeight != iPreviousMaxIconHeight))
-		cairo_dock_reserve_space_for_dock (pDock, TRUE);
+	///if (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE && bUpdateSize && ! pDock->bAutoHide && (pDock->fFlatDockWidth != iPreviousMinWidth || pDock->iMaxIconHeight != iPreviousMaxIconHeight))
+	///	cairo_dock_reserve_space_for_dock (pDock, TRUE);
 	
 	if (pDock->iRefCount != 0 && ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))  // on prevoit le redessin de l'icone pointant sur le sous-dock.
 	{
@@ -635,11 +641,6 @@ void cairo_dock_insert_separators_in_dock (CairoDock *pDock)
 Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFileURI, CairoDockDesktopFileType iType, CairoDock *pReceivingDock, double fOrder, CairoDockIconGroup iGroup)
 {
 	//\_________________ On ajoute un fichier desktop dans le repertoire des lanceurs du theme courant.
-	gchar *cPath = NULL;
-	if (cExternDesktopFileURI && strncmp (cExternDesktopFileURI, "file://", 7) == 0)
-	{
-		cPath = g_filename_from_uri (cExternDesktopFileURI, NULL, NULL);
-	}
 	GError *erreur = NULL;
 	const gchar *cDockName = cairo_dock_search_dock_name (pReceivingDock);
 	if (fOrder == CAIRO_DOCK_LAST_ORDER && pReceivingDock != NULL)
@@ -652,10 +653,9 @@ Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFil
 	}
 	gchar *cNewDesktopFileName;
 	if (cExternDesktopFileURI != NULL)
-		cNewDesktopFileName = cairo_dock_add_desktop_file_from_uri (cPath ? cPath : cExternDesktopFileURI, cDockName, fOrder, iGroup, &erreur);
+		cNewDesktopFileName = cairo_dock_add_desktop_file_from_uri (cExternDesktopFileURI, cDockName, fOrder, iGroup, &erreur);
 	else
 		cNewDesktopFileName = cairo_dock_add_desktop_file_from_type (iType, cDockName, fOrder, iGroup, &erreur);
-	g_free (cPath);
 	if (erreur != NULL)
 	{
 		cd_warning (erreur->message);
