@@ -53,6 +53,7 @@
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-keyfile-utilities.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-draw.h"
@@ -321,7 +322,10 @@ gchar *cairo_dock_get_readable_name_for_fock (CairoDock *pDock)
 	{
 		int i = 0;
 		gpointer data[3] = {pDock, &i, NULL};
-		cairo_dock_foreach_root_docks ((GFunc)_find_similar_root_dock, data);
+		///cairo_dock_foreach_root_docks ((GFunc)_find_similar_root_dock, data);
+		GList *d = g_list_last (s_pRootDockList);
+		for (;d != NULL; d = d->prev)  // parse the list from the end to get the main dock first (docks are prepended).
+			_find_similar_root_dock (d->data, data);
 		const gchar *cPosition;
 		if (pDock->container.bIsHorizontal)
 		{
@@ -519,8 +523,6 @@ gboolean cairo_dock_hide_child_docks (CairoDock *pDock)
 			if (icon->pSubDock->container.bInside)
 			{
 				//cd_debug ("on est dans le sous-dock, donc on ne le cache pas");
-				pDock->container.bInside = FALSE;
-				//pDock->bAtTop = FALSE;
 				return FALSE;
 			}
 			else if (icon->pSubDock->iSidLeaveDemand == 0)  // si on sort du dock sans passer par le sous-dock, par exemple en sortant par le bas.
@@ -556,10 +558,10 @@ static void _cairo_dock_draw_one_subdock_icon (const gchar *cDockName, CairoDock
 	{
 		icon = ic->data;
 		if (icon->pSubDock != NULL
-		&& (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) || CAIRO_DOCK_IS_MULTI_APPLI (icon))
+		&& (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) || CAIRO_DOCK_IS_MULTI_APPLI (icon) || CAIRO_DOCK_IS_APPLET (icon))
 		&& (icon->iSubdockViewType != 0
 			|| (CAIRO_DOCK_IS_MULTI_APPLI (icon) && !myIndicatorsParam.bUseClassIndic))
-		&& icon->iSidRedrawSubdockContent == 0)  // icone de sous-dock ou de classe; les applets font ce qu'elles veulent.
+		&& icon->iSidRedrawSubdockContent == 0)  // icone de sous-dock ou de classe ou d'applets.
 		{
 			cairo_dock_trigger_redraw_subdock_content_on_icon (icon);
 		}
@@ -622,9 +624,10 @@ void cairo_dock_write_root_dock_gaps (CairoDock *pDock)
 		gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
 		if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
 		{
-			gchar *cCommand = g_strdup_printf ("cp '%s/%s' '%s'", GLDI_SHARE_DATA_DIR, CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+			cairo_dock_copy_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+			/**gchar *cCommand = g_strdup_printf ("cp '%s/%s' '%s'", GLDI_SHARE_DATA_DIR, CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
 			int r = system (cCommand);
-			g_free (cCommand);
+			g_free (cCommand);*/
 		}
 		
 		cairo_dock_update_conf_file (cConfFilePath,
@@ -721,14 +724,16 @@ static gboolean cairo_dock_read_root_dock_config (const gchar *cDockName, CairoD
 		cairo_dock_get_double_list_key_value (pKeyFile, "Appearance", "stripes color bright", &bFlushConfFileNeeded, pDock->fBgColorBright, 4, couleur2, NULL, NULL);
 	}
 	
+	pDock->bExtendedMode = cairo_dock_get_boolean_key_value (pKeyFile, "Appearance", "extended", &bFlushConfFileNeeded, FALSE, NULL, NULL);
 	
 	//\______________ On met a jour le fichier de conf.
 	if (! bFlushConfFileNeeded)
 		bFlushConfFileNeeded = cairo_dock_conf_file_needs_update (pKeyFile, GLDI_VERSION);
 	if (bFlushConfFileNeeded)
 	{
-		cd_debug ("update %s conf file", cDockName);
-		cairo_dock_flush_conf_file (pKeyFile, cConfFilePath, GLDI_SHARE_DATA_DIR, CAIRO_DOCK_MAIN_DOCK_CONF_FILE);
+		//g_print ("update %s conf file\n", cDockName);
+		///cairo_dock_flush_conf_file (pKeyFile, cConfFilePath, GLDI_SHARE_DATA_DIR, CAIRO_DOCK_MAIN_DOCK_CONF_FILE);
+		cairo_dock_upgrade_conf_file (cConfFilePath, pKeyFile, GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE);
 	}
 	
 	g_key_file_free (pKeyFile);
@@ -753,9 +758,10 @@ void cairo_dock_add_root_dock_config_for_name (const gchar *cDockName)
 	// on cree le fichier de conf a partir du template.
 	cd_debug ("%s (%s)", __func__, cDockName);
 	gchar *cConfFilePath = g_strdup_printf ("%s/%s.conf", g_cCurrentThemePath, cDockName);
-	gchar *cCommand = g_strdup_printf ("cp '%s' '%s'", GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+	cairo_dock_copy_file (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
+	/**gchar *cCommand = g_strdup_printf ("cp '%s' '%s'", GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_MAIN_DOCK_CONF_FILE, cConfFilePath);
 	int r = system (cCommand);
-	g_free (cCommand);
+	g_free (cCommand);*/
 	
 	// on placera le nouveau dock a l'oppose du main dock, meme ecran et meme visibilite.
 	cairo_dock_update_conf_file (cConfFilePath,
@@ -829,6 +835,7 @@ static void _cairo_dock_reposition_one_root_dock (const gchar *cDockName, CairoD
 		cairo_dock_move_resize_dock (pDock);
 		gtk_widget_show (pDock->container.pWidget);
 		gtk_widget_queue_draw (pDock->container.pWidget);
+		cairo_dock_synchronize_sub_docks_orientation (pDock, FALSE);
 	}
 }
 void cairo_dock_reposition_root_docks (gboolean bExceptMainDock)
@@ -992,6 +999,7 @@ static gboolean _cairo_dock_hide_back_dock (CairoDock *pDock)
 }
 static gboolean _cairo_dock_unhide_dock_delayed (CairoDock *pDock)
 {
+	//g_print ("%s (%d, %d)\n", __func__, pDock->container.bInside, pDock->iInputState);
 	if (pDock->container.bInside && pDock->iInputState != CAIRO_DOCK_INPUT_HIDDEN && !pDock->bIsBelow)  // already inside and reachable (caution) => no need to show it again.
 	{
 		pDock->iSidUnhideDelayed = 0;
@@ -1302,6 +1310,8 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 		pBackground->fStripesAngle = cairo_dock_get_double_key_value (pKeyFile, "Background", "stripes angle", &bFlushConfFileNeeded, 90., NULL, NULL);
 	}
 	
+	pAccessibility->bExtendedMode = cairo_dock_get_boolean_key_value (pKeyFile, "Background", "extended", &bFlushConfFileNeeded, FALSE, "Accessibility", NULL);
+	
 	// position
 	pPosition->iGapX = cairo_dock_get_integer_key_value (pKeyFile, "Position", "x gap", &bFlushConfFileNeeded, 0, NULL, NULL);
 	pPosition->iGapY = cairo_dock_get_integer_key_value (pKeyFile, "Position", "y gap", &bFlushConfFileNeeded, 0, NULL, NULL);
@@ -1427,7 +1437,6 @@ static gboolean get_config (GKeyFile *pKeyFile, CairoDocksParam *pDocksParam)
 	
 	//\____________________ Autres parametres.
 	pAccessibility->iMaxAuthorizedWidth = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "max_authorized_width", &bFlushConfFileNeeded, 0, "Position", NULL);  // obsolete, cache en conf.
-	pAccessibility->bExtendedMode = cairo_dock_get_boolean_key_value (pKeyFile, "Accessibility", "extended", &bFlushConfFileNeeded, FALSE, NULL, NULL);
 	
 	pAccessibility->iUnhideDockDelay = cairo_dock_get_integer_key_value (pKeyFile, "Accessibility", "unhide delay", &bFlushConfFileNeeded, 0, NULL, NULL);
 	
@@ -1516,6 +1525,7 @@ static void load (void)
 			g_pMainDock->iNumScreen = myDocksParam.iNumScreen;
 			cairo_dock_get_screen_offsets (myDocksParam.iNumScreen, &g_pMainDock->iScreenOffsetX, &g_pMainDock->iScreenOffsetY);
 		}
+		g_pMainDock->bExtendedMode = myDocksParam.bExtendedMode;
 		
 		cairo_dock_set_dock_orientation (g_pMainDock, myDocksParam.iScreenBorder);
 		cairo_dock_move_resize_dock (g_pMainDock);
@@ -1595,6 +1605,7 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	{
 		cairo_dock_set_dock_orientation (pDock, pPosition->iScreenBorder);
 	}
+	pDock->bExtendedMode = pBackground->bExtendedMode;
 	cairo_dock_update_dock_size (pDock);  // si l'ecran ou l'orientation a change, la taille max a change aussi.
 	
 	pDock->iGapX = pPosition->iGapX;
@@ -1634,11 +1645,11 @@ static void reload (CairoDocksParam *pPrevDocksParam, CairoDocksParam *pDocksPar
 	}
 	
 	//\_______________ Max Size.
-	if (pAccessibility->iMaxAuthorizedWidth != pPrevAccessibility->iMaxAuthorizedWidth ||
+	/**if (pAccessibility->iMaxAuthorizedWidth != pPrevAccessibility->iMaxAuthorizedWidth ||
 		pAccessibility->bExtendedMode != pPrevAccessibility->bExtendedMode)
 	{
 		cairo_dock_set_all_views_to_default (1);  // 1 <=> tous les docks racines. met a jour la taille et reserve l'espace.
-	}
+	}*/
 	
 	//\_______________ Hiding effect.
 	if (cairo_dock_strings_differ (pAccessibility->cHideEffect, pPrevAccessibility->cHideEffect))
@@ -1733,11 +1744,11 @@ void gldi_register_docks_manager (void)
 	myDocksMgr.mgr.reset_config = (GldiManagerResetConfigFunc)reset_config;
 	// Config
 	memset (&myDocksParam, 0, sizeof (CairoDocksParam));
-	myDocksMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myDocksParam;
+	myDocksMgr.mgr.pConfig = (GldiManagerConfigPtr)&myDocksParam;
 	myDocksMgr.mgr.iSizeOfConfig = sizeof (CairoDocksParam);
 	// data
 	memset (&g_pVisibleZoneBuffer, 0, sizeof (CairoDockImageBuffer));
-	myDocksMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myDocksMgr.mgr.pData = (GldiManagerDataPtr)NULL;
 	myDocksMgr.mgr.iSizeOfData = 0;
 	// signals
 	cairo_dock_install_notifications_on_object (&myDocksMgr, NB_NOTIFICATIONS_DOCKS);
