@@ -52,6 +52,8 @@
 #include "cairo-dock-applications-manager.h"  // myTaskbarParam.fVisibleAppliAlpha
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-animations.h"
+#include "cairo-dock-overlay.h"
+#include "cairo-dock-opengl-path.h"
 #include "cairo-dock-draw-opengl.h"
 
 #include "texture-gradation.h"
@@ -362,7 +364,6 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 			glTranslatef ((!pDock->container.bDirectionUp ? icon->fHeight * (- icon->fScale + 1)/2 : icon->fHeight * (icon->fScale - 1)/2), 0., 0.);
 		}
 	}
-	glTranslatef (0., 0., - icon->fHeight * (1+myIconsParam.fAmplitude));
 	if (icon->fOrientation != 0)
 	{
 		glTranslatef (-icon->fWidth * icon->fScale/2, icon->fHeight * icon->fScale/2, 0.);
@@ -380,7 +381,9 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 		}
 		else
 		{
+			glMatrixMode(GL_TEXTURE);
 			glRotatef (-90., 0., 0., 1.);
+			glMatrixMode (GL_MODELVIEW);
 			if (pDock->container.bDirectionUp)
 				glScalef (1., -1., 1.);
 		}
@@ -397,6 +400,13 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 	
 	glPopMatrix ();  // retour juste apres la translation au milieu de l'icone.
 	
+	if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && myIconsParam.bRevolveSeparator && !pDock->container.bIsHorizontal)
+	{
+		glMatrixMode(GL_TEXTURE);
+		glLoadIdentity ();
+		glMatrixMode (GL_MODELVIEW);
+	}
+	
 	//\_____________________ On dessine les infos additionnelles.
 	if (icon->iQuickInfoTexture != 0)
 	{
@@ -412,54 +422,92 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 		glPopMatrix ();
 	}
 	
+	cairo_dock_draw_icon_overlays_opengl (icon, fRatio);
+	
 	//\_____________________ On dessine les etiquettes, avec un alpha proportionnel au facteur d'echelle de leur icone.
 	glPopMatrix ();  // retour au debut de la fonction.
-	if (bUseText && icon->iLabelTexture != 0 &&
+	if (bUseText && icon->iLabelTexture != 0 && icon->iHideLabel == 0 &&
 		( (icon->fScale > 1.01 && (! myIconsParam.bLabelForPointedIconOnly || icon->bPointed)) ||
 		((myIconsParam.fAmplitude < 0.001 || pDock->fMagnitudeMax < 0.001) && icon->bPointed) ))  // 1.01 car sin(pi) = 1+epsilon :-/  //  && icon->iAnimationState < CAIRO_DOCK_STATE_CLICKED
 	{
 		glPushMatrix ();
-		if (pDock->container.bIsHorizontal)
-			glTranslatef (floor (fX), floor (fY - icon->fHeight * icon->fScale * (1 - icon->fGlideScale/2)), - icon->fHeight * (1+myIconsParam.fAmplitude));
-		else
-			glTranslatef (floor (fY + icon->fHeight * icon->fScale * (1 - icon->fGlideScale/2)), floor (fX), - icon->fHeight * (1+myIconsParam.fAmplitude));
-		
-		double fOffsetX = 0.;
-		if (icon->fDrawX + icon->fWidth * icon->fScale/2 - icon->iTextWidth/2 < 0)  // l'etiquette deborde a gauche.
-			fOffsetX = icon->iTextWidth/2 - (icon->fDrawX + icon->fWidth * icon->fScale/2);
-		else if (icon->fDrawX + icon->fWidth * icon->fScale/2 + icon->iTextWidth/2 > pDock->container.iWidth)  // l'etiquette deborde a droite.
-			fOffsetX = pDock->container.iWidth - (icon->fDrawX + icon->fWidth * icon->fScale/2 + icon->iTextWidth/2);
-		if (icon->fOrientation != 0 && ! myIconsParam.bTextAlwaysHorizontal)
-		{
-			glTranslatef (-icon->fWidth * icon->fScale/2, icon->fHeight * icon->fScale/2, 0.);
-			glRotatef (-icon->fOrientation/G_PI*180., 0., 0., 1.);
-			glTranslatef (icon->fWidth * icon->fScale/2, -icon->fHeight * icon->fScale/2, 0.);
-		}
+		glLoadIdentity ();
 		
 		double dx = .5 * (icon->iTextWidth & 1);  // on decale la texture pour la coller sur la grille des coordonnees entieres.
 		double dy = .5 * (icon->iTextHeight & 1);
-		if (pDock->container.bIsHorizontal)
+		
+		if (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal)
 		{
-			glTranslatef (floor (fOffsetX) + dx,
-				floor ((pDock->container.bDirectionUp ? 1:-1) * (icon->fHeight * icon->fScale/2 + myIconsParam.iLabelSize - icon->iTextHeight / 2)) + dy,
-				0.);
-		}
-		else if (myIconsParam.bTextAlwaysHorizontal)
-		{
-			fOffsetX = MIN (0, icon->fDrawY + icon->fWidth * icon->fScale/2 - icon->iTextWidth/2);
-			double y = (icon->fWidth * icon->fScale + icon->iTextHeight) / 2;
-			if (fX + y + icon->iTextHeight/2 > pDock->container.iWidth)  // le teste deborde par le haut.
-				y = pDock->container.iWidth - fX - icon->iTextHeight/2;
-			glTranslatef (ceil (- fOffsetX) + dx,
-				floor (y) + dy,
-				0.);
+			if (fX + icon->iTextWidth/2 > pDock->container.iWidth)  // l'etiquette deborde a droite.
+				fX = pDock->container.iWidth - icon->iTextWidth/2;
+			if (fX - icon->iTextWidth/2 < 0)  // l'etiquette deborde a gauche.
+				fX = icon->iTextWidth/2;
+			
+			if (pDock->container.bIsHorizontal)
+				glTranslatef (floor (fX) + dx,
+					pDock->container.bDirectionUp ? 
+						floor (fY + myIconsParam.iLabelSize - icon->iTextHeight / 2) - dy:
+						floor (fY - icon->fHeight * icon->fScale - myIconsParam.iLabelSize + icon->iTextHeight / 2) + dy,
+					0.);
+			else
+			{
+				glTranslatef (pDock->container.bDirectionUp ? 
+						floor (fY - myIconsParam.iLabelSize + icon->iTextHeight / 2) - dy:
+						floor (fY + icon->fHeight * icon->fScale + myIconsParam.iLabelSize - icon->iTextHeight / 2) + dy,
+					floor (fX) + dx,
+					0.);
+				glRotatef (pDock->container.bDirectionUp ? 90 : -90, 0., 0., 1.);
+			}
+			if (icon->fOrientation != 0 && ! myIconsParam.bTextAlwaysHorizontal)
+			{
+				glTranslatef (-icon->fWidth * icon->fScale/2, icon->fHeight * icon->fScale/2, 0.);
+				glRotatef (-icon->fOrientation/G_PI*180., 0., 0., 1.);
+				glTranslatef (icon->fWidth * icon->fScale/2, -icon->fHeight * icon->fScale/2, 0.);
+			}
+			/*if (pDock->container.bIsHorizontal)
+				glTranslatef (floor (fX), floor (fY - icon->fHeight * icon->fScale * (1 - icon->fGlideScale/2)), 0.);
+			else
+				glTranslatef (floor (fY + icon->fHeight * icon->fScale * (1 - icon->fGlideScale/2)), floor (fX), 0.);
+			
+			double fOffsetX = 0.;
+			if (icon->fDrawX + icon->fWidth * icon->fScale/2 - icon->iTextWidth/2 < 0)  // l'etiquette deborde a gauche.
+				fOffsetX = icon->iTextWidth/2 - (icon->fDrawX + icon->fWidth * icon->fScale/2);
+			else if (icon->fDrawX + icon->fWidth * icon->fScale/2 + icon->iTextWidth/2 > pDock->container.iWidth)  // l'etiquette deborde a droite.
+				fOffsetX = pDock->container.iWidth - (icon->fDrawX + icon->fWidth * icon->fScale/2 + icon->iTextWidth/2);
+			if (icon->fOrientation != 0 && ! myIconsParam.bTextAlwaysHorizontal)
+			{
+				glTranslatef (-icon->fWidth * icon->fScale/2, icon->fHeight * icon->fScale/2, 0.);
+				glRotatef (-icon->fOrientation/G_PI*180., 0., 0., 1.);
+				glTranslatef (icon->fWidth * icon->fScale/2, -icon->fHeight * icon->fScale/2, 0.);
+			}
+			
+			if (pDock->container.bIsHorizontal)
+			{
+				glTranslatef (floor (fOffsetX) + dx,
+					floor ((pDock->container.bDirectionUp ? 1:-1) * (icon->fHeight * icon->fScale/2 + myIconsParam.iLabelSize - icon->iTextHeight / 2)) + dy,
+					0.);
+			}
+			else
+			{
+				glTranslatef (floor ((pDock->container.bDirectionUp ? -.5:.5) * (icon->fHeight * icon->fScale + icon->iTextHeight)) + dx,
+					- floor (fOffsetX) + dy,
+					0.);
+				glRotatef (pDock->container.bDirectionUp ? 90 : -90, 0., 0., 1.);
+			}*/
 		}
 		else
 		{
-			glTranslatef (floor ((pDock->container.bDirectionUp ? -.5:.5) * (icon->fHeight * icon->fScale + icon->iTextHeight)) + dx,
-				- floor (fOffsetX) + dy,
-				0.);
-			glRotatef (pDock->container.bDirectionUp ? 90 : -90, 0., 0., 1.);
+			fY += icon->fHeight * icon->fScale/2;  // middle of the icon
+			
+			if (fY + icon->iTextWidth/2 > pDock->container.iHeight)  // out from the right
+				fY = pDock->container.iHeight - icon->iTextWidth/2;
+			if (fY - icon->iTextWidth/2 < 0)  // out from the left.
+				fY = icon->iTextWidth/2;
+			
+			double y = (icon->fWidth * icon->fScale + icon->iTextHeight) / 2;
+			if (fX + y + icon->iTextHeight/2 > pDock->container.iWidth)  // le texte deborde par le haut.
+				y = pDock->container.iWidth - fX - icon->iTextHeight/2;
+			glTranslatef (floor (fY) + dx, floor (fX) + floor (y) + dy, 0.);
 		}
 		
 		double fMagnitude;
@@ -537,6 +585,9 @@ void cairo_dock_render_hidden_dock_opengl (CairoDock *pDock)
 	double y;
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
+	double pHiddenBgColor[4];
+	double r = 3;
+	_cairo_dock_set_blend_alpha ();
 	do
 	{
 		icon = ic->data;
@@ -545,6 +596,29 @@ void cairo_dock_render_hidden_dock_opengl (CairoDock *pDock)
 			//g_print ("%s : %d (%d)\n", icon->cName, icon->bIsDemandingAttention, icon->Xid);
 			y = icon->fDrawY;
 			icon->fDrawY = (pDock->container.bDirectionUp ? pDock->container.iHeight - icon->fHeight * icon->fScale : 0.);
+			
+			if (icon->pHiddenBgColor)
+			{
+				glPushMatrix ();
+				memcpy (pHiddenBgColor, icon->pHiddenBgColor, 4*sizeof (gdouble));
+				pHiddenBgColor[3] *= pDock->fPostHideOffset;
+				if (pDock->container.bIsHorizontal)
+				{
+					glTranslatef (icon->fDrawX + icon->fWidth/2,
+						pDock->container.iHeight - icon->fDrawY - icon->fHeight/2,
+						0.);
+					cairo_dock_draw_rounded_rectangle_opengl (icon->fWidth - 2*r, icon->fHeight, r, 0, pHiddenBgColor);
+				}
+				else
+				{
+					glTranslatef (icon->fDrawY + icon->fHeight/2,
+						pDock->container.iWidth - icon->fDrawX - icon->fWidth/2,
+						0.);
+					cairo_dock_draw_rounded_rectangle_opengl (icon->fHeight - 2*r, icon->fWidth, r, 0, pHiddenBgColor);
+				}
+				glPopMatrix ();
+			}
+			
 			glPushMatrix ();
 			icon->fAlpha = pDock->fPostHideOffset * pDock->fPostHideOffset;
 			cairo_dock_render_one_icon_opengl (icon, pDock, fDockMagnitude, TRUE);
@@ -784,7 +858,8 @@ void cairo_dock_draw_texture_with_alpha (GLuint iTexture, int iWidth, int iHeigh
 	//~ if (fAlpha == 1)
 		//~ _cairo_dock_set_blend_over ();
 	//~ else
-		_cairo_dock_set_blend_alpha ();
+		///_cairo_dock_set_blend_alpha ();
+		_cairo_dock_set_blend_over ();
 	
 	_cairo_dock_apply_texture_at_size_with_alpha (iTexture, iWidth, iHeight, fAlpha);
 	
@@ -820,7 +895,7 @@ static inline void  _draw_icon_bent_backwards (Icon *pIcon, CairoContainer *pCon
 	cairo_dock_set_perspective_view_for_icon (pIcon, pContainer);
 	
 	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 	glScalef (1., -1., 1.);
 	glTranslatef (0., -iHeight/2, 0.);  // rotation de 50° sur l'axe des X a la base de l'icone.
 	glRotatef (-50.*f, 1., 0., 0.);
@@ -868,7 +943,7 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 		cairo_dock_remove_transition_on_icon (pIcon);
 		
 		int iWidth, iHeight;
-		cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 		
 		GLuint iOriginalTexture;
 		if (pIcon->bIsHidden)
