@@ -43,7 +43,9 @@
 #include "cairo-dock-backends-manager.h"
 #include "cairo-dock-container.h"
 #include "cairo-dock-image-buffer.h"
+#include "cairo-dock-X-manager.h"
 #include "cairo-dock-draw-opengl.h"  // pour cairo_dock_render_one_icon
+#include "cairo-dock-overlay.h"
 #include "cairo-dock-draw.h"
 
 extern CairoDockImageBuffer g_pIconBackgroundImageBuffer;
@@ -559,12 +561,15 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 	cairo_restore (pCairoContext);  // retour juste apres la translation (fDrawX, fDrawY).
 	
 	//\_____________________ On dessine les etiquettes, avec un alpha proportionnel au facteur d'echelle de leur icone.
-	if (bUseText && icon->pTextBuffer != NULL &&
+	if (bUseText && icon->pTextBuffer != NULL && icon->iHideLabel == 0 &&
 		( (icon->fScale > 1.01 && (! myIconsParam.bLabelForPointedIconOnly || icon->bPointed)) ||
 		((myIconsParam.fAmplitude < 0.001 || pDock->fMagnitudeMax < 0.001) && icon->bPointed) ))  // 1.01 car sin(pi) = 1+epsilon :-/  //  && icon->iAnimationState < CAIRO_DOCK_STATE_CLICKED
 	{
 		cairo_save (pCairoContext);
 		
+		//int iLabelSize = icon->iTextHeight;
+		int iLabelSize = myIconsParam.iLabelSize;
+		//g_print ("%d / %d\n", icon->iTextHeight, myIconsParam.iLabelSize),
 		cairo_identity_matrix (pCairoContext);  // on positionne les etiquettes sur un pixels entier, sinon ca floute.
 		if (bIsHorizontal)
 			cairo_translate (pCairoContext, floor (icon->fDrawX + icon->fGlideOffset * icon->fWidth * icon->fScale * (icon->fGlideOffset < 0 ? fGlideScale : 1)), floor (icon->fDrawY));
@@ -585,11 +590,13 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 			cairo_set_source_surface (pCairoContext,
 				icon->pTextBuffer,
 				floor (fOffsetX),
-				floor (bDirectionUp ? -myIconsParam.iLabelSize : icon->fHeight * icon->fScale));
+				floor (bDirectionUp ? -iLabelSize : icon->fHeight * icon->fScale));
 		}
 		else if (myIconsParam.bTextAlwaysHorizontal)
 		{
-			if (fOffsetX < - icon->fDrawY)
+			if (icon->fDrawY + fOffsetX + icon->iTextWidth > pDock->container.iHeight)
+				fOffsetX = pDock->container.iHeight - icon->fDrawY - icon->iTextWidth;
+			if (icon->fDrawY + fOffsetX < 0)
 				fOffsetX = - icon->fDrawY;
 			cairo_set_source_surface (pCairoContext,
 				icon->pTextBuffer,
@@ -602,7 +609,7 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 			cairo_set_source_surface (pCairoContext,
 				icon->pTextBuffer,
 				floor (bDirectionUp ? fOffsetX - icon->fWidth * icon->fScale : fOffsetX),
-				-floor (bDirectionUp ? myIconsParam.iLabelSize : icon->fHeight * icon->fScale + myIconsParam.iLabelSize));
+				-floor (bDirectionUp ? iLabelSize : icon->fHeight * icon->fScale + iLabelSize));
 		}
 		double fMagnitude;
 		if (myIconsParam.bLabelForPointedIconOnly || pDock->fMagnitudeMax == 0.)
@@ -640,6 +647,8 @@ void cairo_dock_render_one_icon (Icon *icon, CairoDock *pDock, cairo_t *pCairoCo
 		else
 			cairo_paint_with_alpha (pCairoContext, icon->fAlpha);
 	}
+	
+	cairo_dock_draw_icon_overlays_cairo (icon, fRatio, pCairoContext);
 }
 
 
@@ -963,6 +972,8 @@ void cairo_dock_render_hidden_dock (cairo_t *pCairoContext, CairoDock *pDock)
 	double y;
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
+	double pHiddenBgColor[4];
+	double r = 3;
 	do
 	{
 		icon = ic->data;
@@ -970,6 +981,25 @@ void cairo_dock_render_hidden_dock (cairo_t *pCairoContext, CairoDock *pDock)
 		{
 			y = icon->fDrawY;
 			icon->fDrawY = (pDock->container.bDirectionUp ? pDock->container.iHeight - icon->fHeight * icon->fScale : 0.);
+			
+			if (icon->pHiddenBgColor)
+			{
+				cairo_save (pCairoContext);
+				cairo_set_source_rgba (pCairoContext, icon->pHiddenBgColor[0], icon->pHiddenBgColor[1], icon->pHiddenBgColor[2], icon->pHiddenBgColor[3] * pDock->fPostHideOffset);
+				if (pDock->container.bIsHorizontal)
+				{
+					cairo_translate (pCairoContext, icon->fDrawX, icon->fDrawY);
+					cairo_dock_draw_rounded_rectangle (pCairoContext, r, 0, icon->fWidth - 2*r, icon->fHeight);
+				}
+				else
+				{
+					cairo_translate (pCairoContext, icon->fDrawY, icon->fDrawX);
+					cairo_dock_draw_rounded_rectangle (pCairoContext, r, 0, icon->fHeight - 2*r, icon->fWidth);
+				}
+				cairo_fill (pCairoContext);
+				cairo_restore (pCairoContext);
+			}
+			
 			cairo_save (pCairoContext);
 			icon->fAlpha = pDock->fPostHideOffset;
 			cairo_dock_render_one_icon (icon, pDock, pCairoContext, fDockMagnitude, TRUE);
