@@ -31,7 +31,7 @@
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-desktop-file-factory.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command_sync
+#include "cairo-dock-launcher-manager.h"  // cairo_dock_launch_command_syncl
 #include "cairo-dock-X-utilities.h"  // cairo_dock_property_is_present_on_root
 #define _MANAGER_DEF_
 #include "cairo-dock-file-manager.h"
@@ -200,21 +200,6 @@ gboolean cairo_dock_fm_unmount_full (const gchar *cURI, int iVolumeID, CairoDock
 		return FALSE;
 }
 
-
-static void _cairo_dock_fm_action_after_mounting (gboolean bMounting, gboolean bSuccess, const gchar *cName, const gchar *cUri, gpointer *data)
-{
-	Icon *icon = data[0];
-	CairoContainer *pContainer = data[1];
-	cd_message ("%s (%s) : %d", __func__, (bMounting ? "mount" : "unmount"), bSuccess);  // en cas de demontage effectif, l'icone n'est plus valide !
-	if ((! bSuccess && pContainer != NULL) || icon == NULL)  // dans l'autre cas (succes), l'icone peut ne plus etre valide ! mais on s'en fout, puisqu'en cas de succes, il y'aura rechargement de l'icone, et donc on pourra balancer le message a ce moment-la.
-	{
-		///if (icon != NULL)
-			cairo_dock_show_temporary_dialog_with_icon_printf (bMounting ? _("failed to mount %s") : _("Failed to unmount %s"), icon, pContainer, 4000, "same icon", cName);
-		///else
-		///	cairo_dock_show_general_message (cMessage, 4000);
-	}
-}
-
 gchar *cairo_dock_fm_is_mounted (const gchar *cURI, gboolean *bIsMounted)
 {
 	if (s_pEnvBackend != NULL && s_pEnvBackend->is_mounted != NULL)
@@ -325,6 +310,9 @@ gboolean cairo_dock_fm_logout (void)
 {
 	if (s_pEnvBackend != NULL && s_pEnvBackend->logout!= NULL)
 	{
+		const gchar *sm = g_getenv ("SESSION_MANAGER");
+		if (sm == NULL || *sm == '\0')  // if there is no session-manager, the desktop methods are useless.
+			return FALSE;
 		s_pEnvBackend->logout ();
 		return TRUE;
 	}
@@ -336,6 +324,9 @@ gboolean cairo_dock_fm_shutdown (void)
 {
 	if (s_pEnvBackend != NULL && s_pEnvBackend->shutdown!= NULL)
 	{
+		const gchar *sm = g_getenv ("SESSION_MANAGER");
+		if (sm == NULL || *sm == '\0')  // idem
+			return FALSE;
 		s_pEnvBackend->shutdown ();
 		return TRUE;
 	}
@@ -354,6 +345,11 @@ gboolean cairo_dock_fm_lock_screen (void)
 		return FALSE;
 }
 
+gboolean cairo_dock_fm_can_setup_time (void)
+{
+	return (s_pEnvBackend != NULL && s_pEnvBackend->setup_time!= NULL);
+}
+
 gboolean cairo_dock_fm_setup_time (void)
 {
 	if (s_pEnvBackend != NULL && s_pEnvBackend->setup_time!= NULL)
@@ -455,6 +451,44 @@ int cairo_dock_get_file_size (const gchar *cFilePath)
 		return 0;
 }
 
+gboolean cairo_dock_copy_file (const gchar *cFilePath, const gchar *cDestPath)
+{
+	GError *error = NULL;
+	gchar *cContent = NULL;
+	gsize length = 0;
+	g_file_get_contents (cFilePath,
+		&cContent,
+		&length,
+		&error);
+	if (error != NULL)
+	{
+		cd_warning ("couldn't copy file '%s' (%s)", cFilePath, error->message);
+		g_error_free (error);
+		return FALSE;
+	}
+	
+	gchar *cDestFilePath = NULL;
+	if (g_file_test (cDestPath, G_FILE_TEST_IS_DIR))
+	{
+		gchar *cFileName = g_path_get_basename (cFilePath);
+		cDestFilePath = g_strdup_printf ("%s/%s", cDestPath, cFileName);
+		g_free (cFileName);
+	}
+	
+	g_file_set_contents (cDestFilePath?cDestFilePath:cDestPath,
+		cContent,
+		length,
+		&error);
+	g_free (cDestFilePath);
+	g_free (cContent);
+	if (error != NULL)
+	{
+		cd_warning ("couldn't copy file '%s' (%s)", cFilePath, error->message);
+		g_error_free (error);
+		return FALSE;
+	}
+	return TRUE;
+}
 
   ////////////
  /// INIT ///
@@ -510,10 +544,10 @@ void gldi_register_desktop_environment_manager (void)
 	myDesktopEnvMgr.mgr.get_config 		= (GldiManagerGetConfigFunc)NULL;
 	myDesktopEnvMgr.mgr.reset_config	 = (GldiManagerResetConfigFunc)NULL;
 	// Config
-	myDesktopEnvMgr.mgr.pConfig = (GldiManagerConfigPtr*)NULL;
+	myDesktopEnvMgr.mgr.pConfig = (GldiManagerConfigPtr)NULL;
 	myDesktopEnvMgr.mgr.iSizeOfConfig = 0;
 	// data
-	myDesktopEnvMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myDesktopEnvMgr.mgr.pData = (GldiManagerDataPtr)NULL;
 	myDesktopEnvMgr.mgr.iSizeOfData = 0;
 	// signals
 	cairo_dock_install_notifications_on_object (&myDesktopEnvMgr, NB_NOTIFICATIONS_DESKTOP_ENV);
