@@ -238,6 +238,8 @@ gboolean cairo_dock_fm_shutdown (void);
 */
 gboolean cairo_dock_fm_lock_screen (void);
 
+gboolean cairo_dock_fm_can_setup_time (void);
+
 /** Raise the panel to configure the time.
 */
 gboolean cairo_dock_fm_setup_time (void);
@@ -260,6 +262,8 @@ gboolean cairo_dock_fm_move_into_directory (const gchar *cURI, Icon *icon, Cairo
 */
 int cairo_dock_get_file_size (const gchar *cFilePath);
 
+gboolean cairo_dock_copy_file (const gchar *cFilePath, const gchar *cDestPath);
+
 
 void gldi_register_desktop_environment_manager (void);
 
