@@ -33,6 +33,7 @@
 #include <cairo-glitz.h>
 #endif
 
+#include "cairo-dock-struct.h"
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-dock-facility.h"
 #include "cairo-dock-dock-manager.h"
@@ -40,9 +41,11 @@
 #include "cairo-dock-config.h"
 #include "cairo-dock-log.h"
 #include "cairo-dock-gui-manager.h"  // cairo_dock_trigger_refresh_launcher_gui
+#include "cairo-dock-animations.h"  // CairoDockHidingEffect
 #include "cairo-dock-icon-facility.h"
 
 extern gchar *g_cCurrentLaunchersPath;
+extern CairoDockHidingEffect *g_pHidingBackend;
 
 
 CairoDockIconGroup cairo_dock_get_icon_type (Icon *icon)
@@ -264,6 +267,18 @@ Icon* cairo_dock_get_last_icon_until_order (GList *pIconList, CairoDockIconGroup
 	}
 	return icon;
 }
+Icon* cairo_dock_get_first_icon_of_true_type (GList *pIconList, CairoDockIconTrueType iType)
+{
+	GList* ic;
+	Icon *icon;
+	for (ic = pIconList; ic != NULL; ic = ic->next)
+	{
+		icon = ic->data;
+		if (icon->iTrueType == iType)
+			return icon;
+	}
+	return NULL;
+}
 
 Icon* cairo_dock_get_pointed_icon (GList *pIconList)
 {
@@ -385,20 +400,8 @@ Icon *cairo_dock_get_icon_with_module (GList *pIconList, CairoDockModule *pModul
 	return NULL;
 }
 
-void cairo_dock_get_icon_extent (Icon *pIcon, CairoContainer *pContainer, int *iWidth, int *iHeight)
+void cairo_dock_get_icon_extent (Icon *pIcon, int *iWidth, int *iHeight)
 {
-	/**double fMaxScale = cairo_dock_get_max_scale (pContainer);
-	double fRatio = (CAIRO_DOCK_IS_DOCK (pContainer) ? pContainer->fRatio : 1.);  // on ne tient pas compte de l'effet de zoom initial du desklet.
-	if (!pContainer || pContainer->bIsHorizontal)
-	{
-		*iWidth = (int) (pIcon->fWidth / fRatio * fMaxScale);
-		*iHeight = (int) (pIcon->fHeight / fRatio * fMaxScale);
-	}
-	else
-	{
-		*iHeight = (int) (pIcon->fWidth / fRatio * fMaxScale);
-		*iWidth = (int) (pIcon->fHeight / fRatio * fMaxScale);
-	}*/
 	*iWidth = pIcon->iImageWidth;
 	*iHeight = pIcon->iImageHeight;
 }
@@ -447,6 +450,14 @@ void cairo_dock_compute_icon_area (Icon *icon, CairoContainer *pContainer, GdkRe
 	fX += icon->fWidth * icon->fScale * (1 - fabs (icon->fWidthFactor))/2 + icon->fGlideOffset * icon->fWidth * icon->fScale;
 	
 	double fY = icon->fDrawY;
+	if (CAIRO_DOCK_IS_DOCK (pContainer))
+	{
+		CairoDock *pDock = CAIRO_DOCK (pContainer);
+		if (cairo_dock_is_hidden (pDock) && (g_pHidingBackend == NULL || !g_pHidingBackend->bCanDisplayHiddenDock))
+		{
+			fY = (pDock->container.bDirectionUp ? pDock->container.iHeight - icon->fHeight * icon->fScale : 0.);
+		}
+	}
 	fY += (pContainer->bDirectionUp ? icon->fHeight * icon->fScale * (1 - icon->fHeightFactor)/2 : - fReflectSize);
 	if (fY < 0)
 		fY = 0;
