@@ -143,6 +143,8 @@ Icon* cairo_dock_get_last_icon_of_order (GList *pIconList, CairoDockIconGroup iG
 
 Icon* cairo_dock_get_last_icon_until_order (GList *pIconList, CairoDockIconGroup iGroup);
 
+Icon* cairo_dock_get_first_icon_of_true_type (GList *pIconList, CairoDockIconTrueType iType);
+
 /** Get the currently pointed icon in a list of icons.
 *@param pIconList a list of icons.
 *@return the icon whose field 'bPointed' is TRUE, or NULL if none is pointed.
@@ -219,11 +221,10 @@ Icon *cairo_dock_get_icon_with_module (GList *pIconList, CairoDockModule *pModul
 
 /** Get the dimension allocated to the surface/texture of an icon.
 @param pIcon the icon.
-@param pContainer its container.
 @param iWidth pointer to the width.
 @param iHeight pointer to the height.
 */
-void cairo_dock_get_icon_extent (Icon *pIcon, CairoContainer *pContainer, int *iWidth, int *iHeight);
+void cairo_dock_get_icon_extent (Icon *pIcon, int *iWidth, int *iHeight);
 
 /** Get the current size of an icon as it is seen on the screen (taking into account the zoom and the ratio).
 @param pIcon the icon
