@@ -41,6 +41,7 @@
 #include "cairo-dock-dock-manager.h"  // cairo_dock_synchronize_one_sub_dock_orientation
 #include "cairo-dock-backends-manager.h"  // cairo_dock_get_icon_container_renderer
 #include "cairo-dock-icon-facility.h"
+#include "cairo-dock-overlay.h"
 #include "cairo-dock-icon-factory.h"
 
 CairoDockImageBuffer g_pIconBackgroundBuffer;
@@ -74,8 +75,10 @@ void cairo_dock_free_icon_buffers (Icon *icon)
 	g_free (icon->cBaseURI);
 	g_free (icon->cParentDockName);  // on ne liberera pas le sous-dock ici sous peine de se mordre la queue, donc il faut l'avoir fait avant.
 	g_free (icon->cClass);
+	g_free (icon->cWmClass);
 	g_free (icon->cQuickInfo);
 	g_free (icon->cLastAttentionDemand);
+	g_free (icon->pHiddenBgColor);
 	if (icon->pMimeTypes)
 		g_strfreev (icon->pMimeTypes);
 	
@@ -90,121 +93,13 @@ void cairo_dock_free_icon_buffers (Icon *icon)
 		_cairo_dock_delete_texture (icon->iLabelTexture);
 	if (icon->iQuickInfoTexture != 0)
 		_cairo_dock_delete_texture (icon->iQuickInfoTexture);
+	cairo_dock_destroy_icon_overlays (icon);
 }
 
   //////////////
  /// LOADER ///
 //////////////
 
-gchar *cairo_dock_search_icon_s_path (const gchar *cFileName)
-{
-	g_return_val_if_fail (cFileName != NULL, NULL);
-	
-	//\_______________________ cas faciles : l'entree est deja un chemin.
-	if (*cFileName == '~')
-	{
-		return g_strdup_printf ("%s%s", g_getenv ("HOME"), cFileName+1);
-	}
-	
-	if (*cFileName == '/')
-	{
-		return g_strdup (cFileName);
-	}
-	
-	//\_______________________ On determine si le suffixe et une version sont presents ou non.
-	g_return_val_if_fail (myIconsParam.pDefaultIconDirectory != NULL, NULL);
-	
-	GString *sIconPath = g_string_new ("");
-	const gchar *cSuffixTab[4] = {".svg", ".png", ".xpm", NULL};
-	gboolean bAddSuffix=FALSE, bFileFound=FALSE, bHasVersion=FALSE;
-	GtkIconInfo* pIconInfo = NULL;
-	int i, j;
-	gchar *str = strrchr (cFileName, '.');
-	bAddSuffix = (str == NULL || ! g_ascii_isalpha (*(str+1)));  // exemple : firefox-3.0
-	bHasVersion = (str != NULL && g_ascii_isdigit (*(str+1)) && g_ascii_isdigit (*(str-1)) && str-1 != cFileName);  // doit finir par x.y, x et y ayant autant de chiffres que l'on veut.
-	
-	//\_______________________ On parcourt les themes disponibles, en testant tous les suffixes connus.
-	for (i = 0; i < myIconsParam.iNbIconPlaces && ! bFileFound; i ++)
-	{
-		if (myIconsParam.pDefaultIconDirectory[2*i] != NULL)  // repertoire.
-		{
-			//g_print ("on recherche %s dans le repertoire %s\n", sIconPath->str, myIconsParam.pDefaultIconDirectory[2*i]);
-			j = 0;
-			while (! bFileFound && (cSuffixTab[j] != NULL || ! bAddSuffix))
-			{
-				g_string_printf (sIconPath, "%s/%s", (gchar *)myIconsParam.pDefaultIconDirectory[2*i], cFileName);
-				if (bAddSuffix)
-					g_string_append_printf (sIconPath, "%s", cSuffixTab[j]);
-				//g_print ("  -> %s\n", sIconPath->str);
-				if ( g_file_test (sIconPath->str, G_FILE_TEST_EXISTS) )
-					bFileFound = TRUE;
-				j ++;
-				if (! bAddSuffix)
-					break;
-			}
-		}
-		else  // theme d'icones.
-		{
-			g_string_assign (sIconPath, cFileName);
-			if (! bAddSuffix)  // on vire le suffixe pour chercher tous les formats dans le theme d'icones.
-			{
-				gchar *str = strrchr (sIconPath->str, '.');
-				if (str != NULL)
-					*str = '\0';
-			}
-			//g_print ("on recherche %s dans le theme d'icones\n", sIconPath->str);
-			GtkIconTheme *pIconTheme;
-			if (myIconsParam.pDefaultIconDirectory[2*i+1] != NULL)
-				pIconTheme = myIconsParam.pDefaultIconDirectory[2*i+1];
-			else
-				pIconTheme = gtk_icon_theme_get_default ();
-			pIconInfo = gtk_icon_theme_lookup_icon  (GTK_ICON_THEME (pIconTheme),
-				sIconPath->str,
-				128,
-				GTK_ICON_LOOKUP_FORCE_SVG);
-			if (pIconInfo != NULL)
-			{
-				g_string_assign (sIconPath, gtk_icon_info_get_filename (pIconInfo));
-				bFileFound = TRUE;
-				gtk_icon_info_free (pIconInfo);
-			}
-		}
-	}
-	
-	//\_______________________ si rien trouve, on cherche sans le numero de version.
-	if (! bFileFound && bHasVersion)
-	{
-		cd_debug ("on cherche sans le numero de version...");
-		g_string_assign (sIconPath, cFileName);
-		gchar *str = strrchr (sIconPath->str, '.');
-		str --;  // on sait que c'est un digit.
-		str --;
-		while ((g_ascii_isdigit (*str) || *str == '.' || *str == '-') && (str != sIconPath->str))
-			str --;
-		if (str != sIconPath->str)
-		{
-			*(str+1) = '\0';
-			cd_debug (" on cherche '%s'...\n", sIconPath->str);
-			gchar *cPath = cairo_dock_search_icon_s_path (sIconPath->str);
-			if (cPath != NULL)
-			{
-				bFileFound = TRUE;
-				g_string_assign (sIconPath, cPath);
-				g_free (cPath);
-			}
-		}
-	}
-	
-	if (! bFileFound)
-	{
-		g_string_free (sIconPath, TRUE);
-		return NULL;
-	}
-	
-	gchar *cIconPath = sIconPath->str;
-	g_string_free (sIconPath, FALSE);
-	return cIconPath;
-}
 
 static void _set_icon_size_generic (CairoContainer *pContainer, Icon *icon)
 {
@@ -227,12 +122,26 @@ void cairo_dock_set_icon_size (CairoContainer *pContainer, Icon *icon)
 		_set_icon_size_generic (pContainer, icon);
 	// la taille que devra avoir la texture s'en deduit.
 	double fMaxScale = cairo_dock_get_max_scale (pContainer);
-	icon->iImageWidth = (pContainer->bIsHorizontal ? icon->fWidth : icon->fHeight) * fMaxScale;
-	icon->iImageHeight = (pContainer->bIsHorizontal ? icon->fHeight : icon->fWidth) * fMaxScale;
+	if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && myIconsParam.bRevolveSeparator)
+	{
+		icon->iImageWidth = icon->fWidth * fMaxScale;
+		icon->iImageHeight = icon->fHeight * fMaxScale;
+	}
+	else
+	{
+		icon->iImageWidth = (pContainer->bIsHorizontal ? icon->fWidth : icon->fHeight) * fMaxScale;
+		icon->iImageHeight = (pContainer->bIsHorizontal ? icon->fHeight : icon->fWidth) * fMaxScale;
+	}
 }
 
 void cairo_dock_load_icon_image (Icon *icon, CairoContainer *pContainer)
 {
+	CairoDockModuleInstance *pInstance = icon->pModuleInstance;  // this is the only function where we destroy/create the icon's surface, so we must handle the cairo-context here.
+	if (pInstance && pInstance->pDrawContext != NULL)
+	{
+		cairo_destroy (pInstance->pDrawContext);
+		pInstance->pDrawContext = NULL;
+	}
 	if (icon->fWidth < 0 || icon->fHeight < 0)  // on ne veut pas de surface.
 	{
 		if (icon->pIconBuffer != NULL)
@@ -274,7 +183,7 @@ void cairo_dock_load_icon_image (Icon *icon, CairoContainer *pContainer)
 		gchar *cIconPath = cairo_dock_search_image_s_path (CAIRO_DOCK_DEFAULT_ICON_NAME);
 		if (cIconPath == NULL)  // fichier non trouve.
 		{
-			cIconPath = g_strdup (GLDI_SHARE_DATA_DIR"/"CAIRO_DOCK_DEFAULT_ICON_NAME);
+			cIconPath = g_strdup (GLDI_SHARE_DATA_DIR"/icons/"CAIRO_DOCK_DEFAULT_ICON_NAME);
 		}
 		icon->pIconBuffer = cairo_dock_create_surface_from_image_simple (cIconPath,
 			icon->iImageWidth,
@@ -323,6 +232,15 @@ void cairo_dock_load_icon_image (Icon *icon, CairoContainer *pContainer)
 	if (iPrevTexture != 0)
 		_cairo_dock_delete_texture (iPrevTexture);
 	
+	if (pInstance && icon->pIconBuffer != NULL)
+	{
+		pInstance->pDrawContext = cairo_create (icon->pIconBuffer);
+		if (!pInstance->pDrawContext || cairo_status (pInstance->pDrawContext) != CAIRO_STATUS_SUCCESS)
+		{
+			cd_warning ("couldn't initialize drawing context, applet won't be able to draw itself !");
+			pInstance->pDrawContext = NULL;
+		}
+	}
 }
 
 void cairo_dock_load_icon_text (Icon *icon, CairoDockLabelDescription *pTextDescription)
@@ -414,9 +332,8 @@ static gboolean _load_icon_buffer_idle (Icon *pIcon)
 		cairo_dock_load_icon_quickinfo (pIcon, &myIconsParam.quickInfoTextDescription, fMaxScale);
 		
 		cairo_dock_redraw_icon (pIcon, pContainer);
-		/*while (gtk_events_pending ())
-			gtk_main_iteration ();*/
-		///gtk_main_iteration_do (FALSE);  /// check the consequences...	
+		//g_print ("icon-factory: do 1 main loop iteration\n");
+		//gtk_main_iteration_do (FALSE);  /// check the consequences...	
 	}
 	return FALSE;
 }
@@ -505,7 +422,7 @@ void cairo_dock_add_reflection_to_icon (Icon *pIcon, CairoContainer *pContainer)
 		return;
 	
 	int iWidth, iHeight;
-	cairo_dock_get_icon_extent (pIcon, pContainer, &iWidth, &iHeight);
+	cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 	pIcon->pReflectionBuffer = cairo_dock_create_reflection_surface (pIcon->pIconBuffer,
 		iWidth,
 		iHeight,
@@ -530,7 +447,7 @@ void cairo_dock_draw_subdock_content_on_icon (Icon *pIcon, CairoDock *pDock)
 	cd_debug ("%s (%s)", __func__, pIcon->cName);
 	
 	int w, h;
-	cairo_dock_get_icon_extent (pIcon, CAIRO_CONTAINER (pDock), &w, &h);
+	cairo_dock_get_icon_extent (pIcon, &w, &h);
 	
 	cairo_t *pCairoContext = NULL;
 	if (pIcon->iIconTexture != 0 && pRenderer->render_opengl)  // dessin opengl
