@@ -42,7 +42,6 @@
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-themes-manager.h"  // cairo_dock_mark_current_theme_as_modified
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
-///#include "cairo-dock-gui-manager.h"  // cairo_dock_trigger_refresh_launcher_gui
 #include "cairo-dock-animations.h"  // cairo_dock_launch_animation
 #include "cairo-dock-launcher-factory.h"  // cairo_dock_new_launcher_icon
 #include "cairo-dock-separator-manager.h"  // cairo_dock_create_separator_surface
@@ -146,22 +145,10 @@ static void _load_user_separator (Icon *icon)
 	}
 }
 
-static gboolean _delete_user_separator (Icon *icon)
-{
-	if (icon->cDesktopFileName != NULL)
-	{
-		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
-		g_remove (cDesktopFilePath);
-		g_free (cDesktopFilePath);
-		return TRUE;
-	}
-	return FALSE;
-}
-
 static gboolean _delete_launcher (Icon *icon)
 {
 	gboolean r = FALSE;
-	if (icon->cDesktopFileName != NULL)
+	if (icon->cDesktopFileName != NULL && icon->cDesktopFileName[0] != '/')
 	{
 		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
 		g_remove (cDesktopFilePath);
@@ -169,7 +156,7 @@ static gboolean _delete_launcher (Icon *icon)
 		r = TRUE;
 	}
 	
-	if (icon->pSubDock != NULL && icon->cClass == NULL)
+	if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon) && icon->pSubDock != NULL)  /// really useful ?...
 	{
 		Icon *pSubIcon;
 		GList *ic;
@@ -198,19 +185,19 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	//\____________ On cree l'icone.
 	gchar *cRendererName = NULL;
 	Icon *icon = cairo_dock_new_launcher_icon (cDesktopFileName, &cRendererName);
-	g_return_val_if_fail (icon != NULL, NULL);
+	if (icon == NULL)  // couldn't load the icon (unreadable desktop file, unvalid or does not correspond to any installed program)
+		return NULL;
 	
 	if (icon->iTrueType == CAIRO_DOCK_ICON_TYPE_SEPARATOR)
 	{
 		icon->iface.load_image = _load_user_separator;
-		icon->iface.on_delete = _delete_user_separator;
 	}
 	else
 	{
 		icon->iface.load_image = _load_launcher;
-		icon->iface.on_delete = _delete_launcher;
 		icon->iface.action_on_drag_hover = _show_appli_for_drop;
 	}
+	icon->iface.on_delete = _delete_launcher;
 	
 	//\____________ On gere son dock et sous-dock.
 	CairoDock *pParentDock = _cairo_dock_handle_container (icon, cRendererName);
@@ -219,6 +206,7 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	//\____________ On remplit ses buffers.
 	cairo_dock_trigger_load_icon_buffers (icon, CAIRO_CONTAINER (pParentDock));
 	
+	//\____________ On gere son role d'inhibiteur.
 	cd_message ("+ %s/%s", icon->cName, icon->cClass);
 	if (icon->cClass != NULL)
 	{
@@ -266,10 +254,12 @@ void cairo_dock_build_docks_tree_with_desktop_files (const gchar *cDirectory)
 		if (g_str_has_suffix (cFileName, ".desktop"))
 		{
 			icon = cairo_dock_create_icon_from_desktop_file (cFileName);
-			if (!icon || icon->cParentDockName == NULL)
+			if (icon == NULL)  // if the icon couldn't be loaded, remove it from the theme (it's useless to try and fail to load it each time).
 			{
-				cd_warning ("the desktop file '%s/%s' is invalid !\n you should probably remove it.", cDirectory, cFileName);
-				g_free (icon);
+				cd_warning ("Unable to load a valid icon from '%s/%s'; the file is either unreadable, unvalid or does not correspond to any installed program, and will be deleted", g_cCurrentLaunchersPath, cFileName);
+				gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, cFileName);
+				g_remove (cDesktopFilePath);
+				g_free (cDesktopFilePath);
 				continue;
 			}
 			
@@ -294,8 +284,8 @@ void cairo_dock_reload_launcher (Icon *icon)
 		return ;
 	}
 	
-	//\_____________ On assure la coherence du nouveau fichier de conf.
-	if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon) || CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))
+	//\_____________ Ensure sub-dock's name unicity.
+	if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))
 	{
 		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
 		GKeyFile* pKeyFile = cairo_dock_open_key_file (cDesktopFilePath);
@@ -321,17 +311,6 @@ void cairo_dock_reload_launcher (Icon *icon)
 			}
 			g_free (cName);
 		}
-		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (icon))  // pas vraiment utile mais bon.
-		{
-			gchar *cCommand = g_key_file_get_string (pKeyFile, "Desktop Entry", "Exec", NULL);
-			if (cCommand == NULL || *cCommand == '\0')
-			{
-				cCommand = g_strdup ("enter a command");
-				g_key_file_set_string (pKeyFile, "Desktop Entry", "Exec", cCommand);
-				cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
-			}
-			g_free (cCommand);
-		}
 		
 		g_key_file_free (pKeyFile);
 		g_free (cDesktopFilePath);
@@ -528,6 +507,8 @@ static gpointer _cairo_dock_launch_threaded (gchar *cCommand)
 {
 	int r;
 	r = system (cCommand);
+	if (r != 0)
+		cd_warning ("couldn't launch this command (%s)", cCommand);
 	g_free (cCommand);
 	return NULL;
 }
