@@ -23,6 +23,7 @@
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
+#include <dlfcn.h>
 
 #include <cairo.h>
 
@@ -32,6 +33,7 @@
 #include "cairo-dock-keyfile-utilities.h"  // cairo_dock_conf_file_needs_update
 #include "cairo-dock-log.h"
 #include "cairo-dock-applet-manager.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-X-manager.h"  // g_desktopGeometry
 #include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-animations.h"
@@ -83,8 +85,10 @@ static gchar *_cairo_dock_extract_default_module_name_from_path (gchar *cSoFileP
 
 static void _cairo_dock_close_module (CairoDockModule *module)
 {
-	if (module->pModule)
-		g_module_close (module->pModule);
+	/**if (module->pModule)
+		g_module_close (module->pModule);*/
+	if (module->handle)
+		dlclose (module->handle);
 	
 	g_free (module->pInterface);
 	module->pInterface = NULL;
@@ -99,19 +103,26 @@ static void _cairo_dock_close_module (CairoDockModule *module)
 static void _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GError **erreur)
 {
 	//\__________________ On ouvre le .so.
-	GModule *module = g_module_open (pCairoDockModule->cSoFilePath, G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
+	/**GModule *module = g_module_open (pCairoDockModule->cSoFilePath, G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
 	if (!module)
 	{
 		g_set_error (erreur, 1, 1, "while opening module '%s' : (%s)", pCairoDockModule->cSoFilePath, g_module_error ());
 		return ;
 	}
-	pCairoDockModule->pModule = module;
-
+	pCairoDockModule->pModule = module;*/
+	pCairoDockModule->handle = dlopen (pCairoDockModule->cSoFilePath, RTLD_LAZY | RTLD_LOCAL | RTLD_DEEPBIND);
+	if (! pCairoDockModule->handle)
+	{
+		g_set_error (erreur, 1, 1, "while opening module '%s' : (%s)", pCairoDockModule->cSoFilePath, dlerror ());
+		return ;
+	}
 	//\__________________ On identifie le module.
 	gboolean bSymbolFound;
 	CairoDockModulePreInit function_pre_init = NULL;
-	bSymbolFound = g_module_symbol (module, "pre_init", (gpointer) &function_pre_init);
-	if (bSymbolFound && function_pre_init != NULL)
+	function_pre_init = dlsym (pCairoDockModule->handle, "pre_init");
+	/**bSymbolFound = g_module_symbol (module, "pre_init", (gpointer) &function_pre_init);
+	if (bSymbolFound && function_pre_init != NULL)*/
+	if (function_pre_init != NULL)
 	{
 		pCairoDockModule->pVisitCard = g_new0 (CairoDockVisitCard, 1);
 		pCairoDockModule->pInterface = g_new0 (CairoDockModuleInterface, 1);
@@ -223,43 +234,6 @@ gchar *cairo_dock_check_module_conf_dir (CairoDockModule *pModule)
 	return cUserDataDirPath;
 }
 
-gchar *cairo_dock_check_module_conf_file (CairoDockVisitCard *pVisitCard)
-{
-	if (pVisitCard->cConfFileName == NULL)
-		return NULL;
-	
-	int r;
-	gchar *cUserDataDirPath = g_strdup_printf ("%s/plug-ins/%s", g_cCurrentThemePath, pVisitCard->cUserDataDir);
-	if (! g_file_test (cUserDataDirPath, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
-	{
-		cd_message ("directory %s doesn't exist, it will be added.", cUserDataDirPath);
-		
-		gchar *command = g_strdup_printf ("mkdir -p \"%s\"", cUserDataDirPath);
-		r = system (command);
-		g_free (command);
-	}
-	
-	gchar *cConfFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, pVisitCard->cConfFileName);
-	/*if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
-	{
-		cd_message ("no conf file %s, we will take the default one", cConfFilePath);
-		gchar *command = g_strdup_printf ("cp \"%s/%s\" \"%s\"", pVisitCard->cShareDataDir, pVisitCard->cConfFileName, cConfFilePath);
-		r = system (command);
-		g_free (command);
-	}
-	
-	if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // la copie ne s'est pas bien passee.
-	{
-		cd_warning ("couldn't copy %s/%s in %s; check permissions and file's existence", pVisitCard->cShareDataDir, pVisitCard->cConfFileName, cUserDataDirPath);
-		g_free (cUserDataDirPath);
-		g_free (cConfFilePath);
-		return NULL;
-	}*/
-	
-	g_free (cUserDataDirPath);
-	return cConfFilePath;
-}
-
 void cairo_dock_free_visit_card (CairoDockVisitCard *pVisitCard)
 {
 	g_free (pVisitCard);  // toutes les chaines sont statiques.
@@ -283,13 +257,17 @@ static void _cairo_dock_read_module_config (GKeyFile *pKeyFile, CairoDockModuleI
 		if (pVisitCard->iSizeOfConfig != 0)
 			memset (((gpointer)pInstance)+sizeof(CairoDockModuleInstance), 0, pVisitCard->iSizeOfConfig);
 		
-		bFlushConfFileNeeded = g_key_file_has_group (pKeyFile, "Desklet") && ! g_key_file_has_key (pKeyFile, "Desklet", "accessibility", NULL);  // petit hack des familles ^_^
-		bFlushConfFileNeeded |= pInterface->read_conf_file (pInstance, pKeyFile);
+		bFlushConfFileNeeded = pInterface->read_conf_file (pInstance, pKeyFile);
 	}
 	if (! bFlushConfFileNeeded)
 		bFlushConfFileNeeded = cairo_dock_conf_file_needs_update (pKeyFile, pVisitCard->cModuleVersion);
 	if (bFlushConfFileNeeded)
-		cairo_dock_flush_conf_file (pKeyFile, pInstance->cConfFilePath, pVisitCard->cShareDataDir, pVisitCard->cConfFileName);
+	{
+		///cairo_dock_flush_conf_file (pKeyFile, pInstance->cConfFilePath, pVisitCard->cShareDataDir, pVisitCard->cConfFileName);
+		gchar *cTemplate = g_strdup_printf ("%s/%s", pVisitCard->cShareDataDir, pVisitCard->cConfFileName);
+		cairo_dock_upgrade_conf_file_full (pInstance->cConfFilePath, pKeyFile, cTemplate, FALSE);  // keep private keys.
+		g_free (cTemplate);
+	}
 }
 
 GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *pInstance, CairoDockMinimalAppletConfig *pMinimalConfig)
@@ -325,6 +303,16 @@ GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *p
 			pMinimalConfig->iDesiredIconHeight = 48;
 		
 		pMinimalConfig->cLabel = cairo_dock_get_string_key_value (pKeyFile, "Icon", "name", NULL, NULL, NULL, NULL);
+		if (pMinimalConfig->cLabel == NULL && !pInstance->pModule->pVisitCard->bAllowEmptyTitle)
+		{
+			pMinimalConfig->cLabel = g_strdup (pInstance->pModule->pVisitCard->cTitle);
+		}
+		else if (pMinimalConfig->cLabel && strcmp (pMinimalConfig->cLabel, "none") == 0)
+		{
+			g_free (pMinimalConfig->cLabel);
+			pMinimalConfig->cLabel = NULL;
+		}
+		
 		pMinimalConfig->cIconFileName = cairo_dock_get_string_key_value (pKeyFile, "Icon", "icon", NULL, NULL, NULL, NULL);
 		pMinimalConfig->fOrder = cairo_dock_get_double_key_value (pKeyFile, "Icon", "order", NULL, CAIRO_DOCK_LAST_ORDER, NULL, NULL);
 		if (pMinimalConfig->fOrder == CAIRO_DOCK_LAST_ORDER)
@@ -340,6 +328,16 @@ GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *p
 		}
 		pMinimalConfig->cDockName = cairo_dock_get_string_key_value (pKeyFile, "Icon", "dock name", NULL, NULL, NULL, NULL);
 		pMinimalConfig->bAlwaysVisible = g_key_file_get_boolean (pKeyFile, "Icon", "always visi", NULL);
+		if (pMinimalConfig->bAlwaysVisible)
+		{
+			gsize length;
+			pMinimalConfig->pHiddenBgColor = g_key_file_get_double_list (pKeyFile, "Icon", "bg color", &length, NULL);
+			if (length < 4 || pMinimalConfig->pHiddenBgColor[3] == 0.)
+			{
+				g_free (pMinimalConfig->pHiddenBgColor);
+				pMinimalConfig->pHiddenBgColor = NULL;
+			}
+		}
 	}
 	
 	//\____________________ on recupere les parametres de son desklet.
@@ -410,6 +408,7 @@ void cairo_dock_free_minimal_config (CairoDockMinimalAppletConfig *pMinimalConfi
 	g_free (pMinimalConfig->cDockName);
 	g_free (pMinimalConfig->deskletAttribute.cDecorationTheme);
 	cairo_dock_free_desklet_decoration (pMinimalConfig->deskletAttribute.pUserDecoration);
+	g_free (pMinimalConfig->pHiddenBgColor);
 	g_free (pMinimalConfig);
 }
 
@@ -420,7 +419,7 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 	cd_message ("%s (%s)", __func__, cConfFilePath);
 	
 	//\____________________ On cree une instance du module.
-	CairoDockModuleInstance *pInstance = calloc (1, sizeof (CairoDockModuleInstance) + pModule->pVisitCard->iSizeOfConfig + pModule->pVisitCard->iSizeOfData);  // we allocate everything at once, since config and data will anyway live as long as the instance itself.
+	CairoDockModuleInstance *pInstance = g_malloc0 (sizeof (CairoDockModuleInstance) + pModule->pVisitCard->iSizeOfConfig + pModule->pVisitCard->iSizeOfData);  // we allocate everything at once, since config and data will anyway live as long as the instance itself.
 	pInstance->pModule = pModule;
 	pInstance->cConfFilePath = cConfFilePath;
 	if (pModule->pVisitCard->iSizeOfConfig > 0)
@@ -478,10 +477,9 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 		{
 			pDesklet->pIcon = pIcon;
 			gtk_window_set_title (GTK_WINDOW(pContainer->pWidget), pInstance->pModule->pVisitCard->cModuleName);
-			///gtk_widget_queue_draw (pContainer->pWidget);
 		}
-		cairo_dock_free_minimal_config (pMinimalConfig);
 	}
+	cairo_dock_free_minimal_config (pMinimalConfig);
 
 	//\____________________ On initialise l'instance.
 	if (pDock)  //  on met la taille qu'elle aura une fois dans le dock.
@@ -499,7 +497,7 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 		_cairo_dock_read_module_config (pKeyFile, pInstance);
 	
 	gboolean bCanInit = TRUE;
-	pInstance->pDrawContext = NULL;
+	/**pInstance->pDrawContext = NULL;
 	if (pDock && pIcon)  // applet dans un dock (dans un desklet, il faut attendre que l'applet ait mis une vue pour que l'icone soit chargee).
 	{
 		if (pIcon->pIconBuffer == NULL)
@@ -518,7 +516,7 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 				bCanInit = FALSE;
 			}
 		}
-	}
+	}*/
 	
 	if (bCanInit && pModule->pInterface->initModule)
 		pModule->pInterface->initModule (pInstance, pKeyFile);
@@ -631,6 +629,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 			if (pIcon != NULL)
 			{
 				cCurrentSubDockName = g_strdup (pIcon->cName);
+				
 				// on gere le changement de nom de son sous-dock.
 				if (pIcon->cName != NULL && pIcon->pSubDock != NULL && cairo_dock_strings_differ (pIcon->cName, pMinimalConfig->cLabel))
 				{
@@ -644,11 +643,13 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 				
 				g_free (pIcon->cName);
 				pIcon->cName = pMinimalConfig->cLabel;
-				pMinimalConfig->cLabel = NULL;  // astuce.
+				pMinimalConfig->cLabel = NULL;  // we won't need it any more, so skip a duplication.
 				g_free (pIcon->cFileName);
 				pIcon->cFileName = pMinimalConfig->cIconFileName;
-				pMinimalConfig->cIconFileName = NULL;
+				pMinimalConfig->cIconFileName = NULL;  // idem
 				pIcon->bAlwaysVisible = pMinimalConfig->bAlwaysVisible;
+				pIcon->pHiddenBgColor = pMinimalConfig->pHiddenBgColor;
+				pMinimalConfig->pHiddenBgColor = NULL;
 			}
 			
 			// on recupere son dock (cree au besoin).
@@ -744,7 +745,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 		_cairo_dock_read_module_config (pKeyFile, pInstance);
 	}
 	
-	if (pInstance->pDrawContext != NULL)
+	/**if (pInstance->pDrawContext != NULL)
 	{
 		cairo_destroy (pInstance->pDrawContext);
 		pInstance->pDrawContext = NULL;
@@ -758,7 +759,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 			bCanReload = FALSE;
 			pInstance->pDrawContext = NULL;
 		}
-	}
+	}*/
 
 	//\_______________________ On recharge l'instance.
 	if (bCanReload && module->pInterface->reloadModule != NULL)
@@ -825,7 +826,7 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 	
 	if (module->pVisitCard->cConfFileName != NULL)  // the module has a conf file -> create an instance for each of them.
 	{
-		// check that the module's config dir exists.
+		// check that the module's config dir exists or create it.
 		gchar *cUserDataDirPath = cairo_dock_check_module_conf_dir (module);
 		if (cUserDataDirPath == NULL)
 		{
@@ -833,8 +834,9 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 			return;
 		}
 		
+		// look for conf files inside this folder, and create an instance for each of them.
 		int n = 0;
-		if (module->pVisitCard->bMultiInstance)
+		if (module->pVisitCard->bMultiInstance)  // possibly several conf files.
 		{
 			// open it
 			GError *tmp_erreur = NULL;
@@ -863,7 +865,7 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 			}
 			g_dir_close (dir);
 		}
-		else
+		else  // only 1 conf file possible.
 		{
 			gchar *cConfFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, module->pVisitCard->cConfFileName);
 			if (g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
@@ -877,14 +879,16 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 			}
 		}
 		
-		if (n == 0)  // no conf file was present, let's copy the default one and instanciate the module with it.
+		// if no conf file was present, copy the default one and instanciate the module with it.
+		if (n == 0)  // no conf file was present.
 		{
 			gchar *cConfFilePath = g_strdup_printf ("%s/%s", cUserDataDirPath, module->pVisitCard->cConfFileName);
-			gchar *command = g_strdup_printf ("cp \"%s\" \"%s\"", module->cConfFilePath, cConfFilePath);
+			gboolean r = cairo_dock_copy_file (module->cConfFilePath, cConfFilePath);
+			/**gchar *command = g_strdup_printf ("cp \"%s\" \"%s\"", module->cConfFilePath, cConfFilePath);
 			int r = system (command);
-			g_free (command);
+			g_free (command);*/
 			
-			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))  // the copy failed.
+			if (! r)  // the copy failed.
 			{
 				g_set_error (erreur, 1, 1, "couldn't copy %s into %s; check permissions and file's existence", module->cConfFilePath, cUserDataDirPath);
 				g_free (cConfFilePath);
@@ -903,35 +907,7 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 	{
 		cairo_dock_instanciate_module (module, NULL);
 	}
-
-	/*g_free (module->cConfFilePath);
-	module->cConfFilePath = cairo_dock_check_module_conf_file (module->pVisitCard);
 	
-	gchar *cInstanceFilePath = NULL;
-	int j = 0;
-	do
-	{
-		if (j == 0)
-			cInstanceFilePath = g_strdup (module->cConfFilePath);  // NULL si cConfFilePath l'est.
-		else
-			cInstanceFilePath = g_strdup_printf ("%s-%d",  module->cConfFilePath, j);
-		
-		if (cInstanceFilePath != NULL && ! g_file_test (cInstanceFilePath, G_FILE_TEST_EXISTS))  // la 1ere condition est pour xxx-integration par exemple .
-		{
-			g_free (cInstanceFilePath);
-			break ;
-		}
-		
-		cairo_dock_instanciate_module (module, cInstanceFilePath);  // prend possession de 'cInstanceFilePath'.
-		
-		j ++;
-	} while (cInstanceFilePath != NULL);
-	
-	if (j == 0)
-	{
-		g_set_error (erreur, 1, 1, "%s () : no instance of module %s could be created", __func__, module->pVisitCard->cModuleName);
-		return ;
-	}*/
 	cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_ACTIVATED, module->pVisitCard->cModuleName, TRUE);
 }
 
