@@ -29,6 +29,7 @@
 #include "gldi-config.h"
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
 #include "cairo-dock-dock-manager.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-keyfile-utilities.h"  // cairo_dock_conf_file_needs_update
 #include "cairo-dock-log.h"
 #include "cairo-dock-applet-manager.h"
@@ -78,9 +79,7 @@ static int _sort_module_by_alphabetical_order (CairoDockModule *m1, CairoDockMod
 		return 1;
 	if (!m2 || !m2->pVisitCard || !m2->pVisitCard->cTitle)
 		return -1;
-	return g_ascii_strncasecmp (dgettext (m1->pVisitCard->cGettextDomain, m1->pVisitCard->cTitle),
-		dgettext (m2->pVisitCard->cGettextDomain, m2->pVisitCard->cTitle),
-		-1);
+	return g_ascii_strncasecmp (m1->pVisitCard->cTitle, m2->pVisitCard->cTitle, -1);
 }
 CairoDockModule *cairo_dock_foreach_module_in_alphabetical_order (GCompareFunc pCallback, gpointer user_data)
 {
@@ -423,9 +422,10 @@ gchar *cairo_dock_add_module_conf_file (CairoDockModule *pModule)
 		GList *last = g_list_last (pModule->pInstancesList);
 		pFirstInstance = last->data;  // instances are prepended.
 		
-		gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pFirstInstance->cConfFilePath, cConfFilePath);
+		cairo_dock_copy_file (pFirstInstance->cConfFilePath, cConfFilePath);
+		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pFirstInstance->cConfFilePath, cConfFilePath);
 		int r = system (cCommand);
-		g_free (cCommand);
+		g_free (cCommand);*/
 		
 		if (pFirstInstance->pDesklet)  // prevent desklets from overlapping.
 		{
@@ -446,9 +446,10 @@ gchar *cairo_dock_add_module_conf_file (CairoDockModule *pModule)
 	}
 	else  // no instance yet, just copy the default conf file.
 	{
-		gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pModule->cConfFilePath, cConfFilePath);
+		cairo_dock_copy_file (pModule->cConfFilePath, cConfFilePath);
+		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pModule->cConfFilePath, cConfFilePath);
 		int r = system (cCommand);
-		g_free (cCommand);
+		g_free (cCommand);*/
 	}
 	
 	g_free (cUserDataDirPath);
@@ -656,10 +657,10 @@ void gldi_register_modules_manager (void)
 	myModulesMgr.mgr.reset_config 	= (GldiManagerResetConfigFunc)reset_config;
 	// Config
 	memset (&myModulesParam, 0, sizeof (CairoModulesParam));
-	myModulesMgr.mgr.pConfig = (GldiManagerConfigPtr*)&myModulesParam;
+	myModulesMgr.mgr.pConfig = (GldiManagerConfigPtr)&myModulesParam;
 	myModulesMgr.mgr.iSizeOfConfig = sizeof (CairoModulesParam);
 	// data
-	myModulesMgr.mgr.pData = (GldiManagerDataPtr*)NULL;
+	myModulesMgr.mgr.pData = (GldiManagerDataPtr)NULL;
 	myModulesMgr.mgr.iSizeOfData = 0;
 	// signals
 	cairo_dock_install_notifications_on_object (&myModulesMgr, NB_NOTIFICATIONS_MODULES);
