@@ -41,7 +41,7 @@
 #include <GL/glxext.h>
 
 #include "cairo-dock-struct.h"
-#include "cairo-dock-icons.h"
+#include "cairo-dock-icon-facility.h"  // cairo_dock_generate_string_path_opengl
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-opengl-path.h"
 
@@ -271,7 +271,8 @@ const CairoDockGLPath *cairo_dock_generate_rectangle_path (double fFrameWidth, d
 	double h = fFrameHeight / 2;
 	double r = fRadius;
 	
-	int iNbPoins1Round = 90/DELTA_ROUND_DEGREE;
+	int ddeg = (fRadius < 5 ? 6 : 3);
+	int iNbPoins1Round = 90/15;
 	if (pPath == NULL)
 		pPath = cairo_dock_new_gl_path ((iNbPoins1Round+1)*4+1, w+r, h, fTotalWidth, fTotalHeight);  // on commence au coin haut droit pour avoir une bonne triangulation du polygone, et en raisonnant par rapport au centre du rectangle.
 	else
@@ -500,7 +501,7 @@ void cairo_dock_draw_rounded_rectangle_opengl (double fFrameWidth, double fFrame
 	else
 	{
 		glLineWidth (fLineWidth);
-		cairo_dock_stroke_gl_path (pPath, 0);
+		cairo_dock_stroke_gl_path (pPath, TRUE);
 	}
 }
 
@@ -511,6 +512,6 @@ void cairo_dock_draw_string_opengl (CairoDock *pDock, double fStringLineWidth, g
 		return;
 	
 	glLineWidth (fStringLineWidth);
-	///glColor4f (myIcons.fStringColor[0], myIcons.fStringColor[1], myIcons.fStringColor[2], myIcons.fStringColor[3]);
+	///glColor4f (myIconsParam.fStringColor[0], myIconsParam.fStringColor[1], myIconsParam.fStringColor[2], myIconsParam.fStringColor[3]);
 	cairo_dock_stroke_gl_path (pPath, FALSE);
 }
