@@ -30,6 +30,7 @@
 #include "gldi-config.h"
 #include "cairo-dock-config.h"
 #include "cairo-dock-keyfile-utilities.h"
+#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-backends-manager.h"
@@ -115,17 +116,19 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 		g_free (cQuestion);
 		if (answer == GTK_RESPONSE_YES)
 		{
-			//\___________________ On traite le fichier de conf (et ceux des docks principaux, on les recopiera sauvagement).
+			//\___________________ On traite le fichier de conf global et ceux des docks principaux.
 			gchar *cNewConfFilePath = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_CONF_FILE);
 			if (bSaveBehavior)
 			{
-				g_string_printf (sCommand, "/bin/cp \"%s\" \"%s\"", g_cConfFile, cNewConfFilePath);
+				cairo_dock_copy_file (g_cConfFile, cNewConfFilePath);
+				/**g_string_printf (sCommand, "/bin/cp \"%s\" \"%s\"", g_cConfFile, cNewConfFilePath);
 				cd_message ("%s", sCommand->str);
-				r = system (sCommand->str);
+				r = system (sCommand->str);*/
 			}
 			else
 			{
-				cairo_dock_replace_keys_by_identifier (cNewConfFilePath, g_cConfFile, '+');
+				///cairo_dock_replace_keys_by_identifier (cNewConfFilePath, g_cConfFile, '+');
+				cairo_dock_merge_conf_files (cNewConfFilePath, g_cConfFile, '+');
 			}
 			g_free (cNewConfFilePath);
 			
@@ -184,6 +187,34 @@ gboolean cairo_dock_export_current_theme (const gchar *cNewThemeName, gboolean b
 	g_string_printf (sCommand, "rm -f \"%s/last-modif\"", cNewThemePath);
 	r = system (sCommand->str);
 	
+	/// TODO: check vertical docks, and handle opengl ...
+	if (g_pMainDock && g_pMainDock->pRenderer)
+	{
+		cairo_surface_t *pSurface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+			g_pMainDock->iActiveWidth,
+			g_pMainDock->iActiveHeight);
+		cairo_t *pCairoContext = cairo_create (pSurface);
+		
+		if (!g_pMainDock->container.bIsHorizontal)
+		{
+			cairo_translate (pCairoContext, g_pMainDock->iMaxDockWidth/2, g_pMainDock->iMaxDockHeight/2);
+			cairo_rotate (pCairoContext, -G_PI/2);
+			
+			if (!g_pMainDock->container.bDirectionUp)
+			{
+				
+			}
+			cairo_translate (pCairoContext, -g_pMainDock->iMaxDockHeight/2, -g_pMainDock->iMaxDockWidth/2);
+		}
+		g_pMainDock->pRenderer->render (pCairoContext, g_pMainDock);
+		
+		gchar *cPreviewPath = g_strdup_printf ("%s/preview", cNewThemePath);
+		cairo_surface_write_to_png (pSurface, cPreviewPath);
+		g_free (cPreviewPath);
+		cairo_destroy (pCairoContext);
+		cairo_surface_destroy (pSurface);
+	}
+	
 	//\___________________ Le theme n'est plus en etat 'modifie'.
 	g_free (cNewThemePath);
 	if (bThemeSaved)
@@ -319,10 +350,10 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 	g_return_val_if_fail (cNewThemePath != NULL && g_file_test (cNewThemePath, G_FILE_TEST_EXISTS), FALSE);
 	//g_print ("cNewThemePath : %s ; cNewThemeName : %s\n", cNewThemePath, cNewThemeName);
 	
-	//\___________________ On charge les parametres de comportement.
+	//\___________________ On charge les parametres de comportement globaux et de chaque dock.
 	GString *sCommand = g_string_new ("");
 	int r;
-	cd_message ("Applying changes ...");
+	/**cd_message ("Applying changes ...");
 	if (g_pMainDock == NULL || bLoadBehavior)
 	{
 		g_string_printf (sCommand, "/bin/cp \"%s\"/%s \"%s\"", cNewThemePath, CAIRO_DOCK_CONF_FILE, g_cCurrentThemePath);
@@ -332,14 +363,47 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 	else
 	{
 		gchar *cNewConfFilePath = g_strdup_printf ("%s/%s", cNewThemePath, CAIRO_DOCK_CONF_FILE);
-		cairo_dock_replace_keys_by_identifier (g_cConfFile, cNewConfFilePath, '+');
+		///cairo_dock_replace_keys_by_identifier (g_cConfFile, cNewConfFilePath, '+');
+		cairo_dock_merge_conf_files (g_cConfFile, cNewConfFilePath, '+');
 		g_free (cNewConfFilePath);
 	}
 	
-	//\___________________ On charge les .conf des autres docks racines.
 	g_string_printf (sCommand, "find \"%s\" -mindepth 1 -maxdepth 1 -name '*.conf' ! -name '%s' -exec /bin/cp '{}' \"%s\" \\;", cNewThemePath, CAIRO_DOCK_CONF_FILE, g_cCurrentThemePath);
 	cd_debug ("%s", sCommand->str);
-	r = system (sCommand->str);
+	r = system (sCommand->str);*/
+	
+	cd_message ("Applying changes ...");
+	if (g_pMainDock == NULL || bLoadBehavior)
+	{
+		g_string_printf (sCommand, "cp \"%s\"/*.conf \"%s\"", cNewThemePath, g_cCurrentThemePath);
+		cd_debug ("%s", sCommand->str);
+		r = system (sCommand->str);
+	}
+	else
+	{
+		GDir *dir = g_dir_open (cNewThemePath, 0, NULL);
+		const gchar* cDockConfFile;
+		gchar *cThemeDockConfFile, *cUserDockConfFile;
+		while ((cDockConfFile = g_dir_read_name (dir)) != NULL)
+		{
+			if (g_str_has_suffix (cDockConfFile, ".conf"))
+			{
+				cThemeDockConfFile = g_strdup_printf ("%s/%s", cNewThemePath, cDockConfFile);
+				cUserDockConfFile = g_strdup_printf ("%s/%s", g_cCurrentThemePath, cDockConfFile);
+				if (g_file_test (cUserDockConfFile, G_FILE_TEST_EXISTS))
+				{
+					cairo_dock_merge_conf_files (cUserDockConfFile, cThemeDockConfFile, '+');
+				}
+				else
+				{
+					cairo_dock_copy_file (cThemeDockConfFile, cUserDockConfFile);
+				}
+				g_free (cUserDockConfFile);
+				g_free (cThemeDockConfFile);
+			}
+		}
+		g_dir_close (dir);
+	}
 	
 	//\___________________ On charge les icones.
 	if (bLoadLaunchers)
@@ -464,12 +528,14 @@ gboolean cairo_dock_import_theme (const gchar *cThemeName, gboolean bLoadBehavio
 			if (! g_file_test (cConfFilePath, G_FILE_TEST_EXISTS))
 			{
 				cd_debug ("    no conf file %s, we will take the theme's one", cConfFilePath);
-				g_string_printf (sCommand, "cp \"%s\" \"%s\"", cNewConfFilePath, cConfFilePath);
-				r = system (sCommand->str);
+				cairo_dock_copy_file (cNewConfFilePath, cConfFilePath);
+				/**g_string_printf (sCommand, "cp \"%s\" \"%s\"", cNewConfFilePath, cConfFilePath);
+				r = system (sCommand->str);*/
 			}
 			else
 			{
-				cairo_dock_replace_keys_by_identifier (cConfFilePath, cNewConfFilePath, '+');
+				///cairo_dock_replace_keys_by_identifier (cConfFilePath, cNewConfFilePath, '+');
+				cairo_dock_merge_conf_files (cConfFilePath, cNewConfFilePath, '+');
 			}
 			g_free (cNewConfFilePath);
 			g_free (cConfFilePath);
@@ -604,6 +670,6 @@ void cairo_dock_set_paths (gchar *cRootDataDirPath, gchar *cExtraDirPath, gchar
 	_check_dir (g_cCurrentPlugInsPath);
 	g_cConfFile = g_strdup_printf ("%s/%s", g_cCurrentThemePath, CAIRO_DOCK_CONF_FILE);
 	
-	//\___________________ On initialise le gestionnaire de paquets.
-	cairo_dock_init_package_manager (cThemeServerAdress);
+	//\___________________ On initialise l'adresse du serveur de themes.
+	cairo_dock_set_packages_server (cThemeServerAdress);
 }
