@@ -91,7 +91,7 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 		}
 	}
 	
-	pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio) + myIconsParam.iLabelSize + myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin;
+	pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio) + myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + (pDock->container.bIsHorizontal || !myIconsParam.bTextAlwaysHorizontal ? myIconsParam.iLabelSize : 0);
 	//g_print ("myIconsParam.iLabelSize : %d => %d\n", myIconsParam.iLabelSize, (int)pDock->iMaxDockHeight);
 
 	pDock->iDecorationsWidth = pDock->iMaxDockWidth;
@@ -129,6 +129,11 @@ static void cd_calculate_max_dock_size_default (CairoDock *pDock)
 	
 	if (g_bUseOpenGL && s_iFlatSeparatorTexture == 0 && myIconsParam.iSeparatorType == CAIRO_DOCK_FLAT_SEPARATOR)
 		s_iFlatSeparatorTexture = cairo_dock_load_texture_from_raw_data (blurTex, 32, 32);
+	
+	pDock->iActiveWidth = pDock->iMaxDockWidth;
+	pDock->iActiveHeight = pDock->iMaxDockHeight;
+	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
+		pDock->iMaxDockHeight += 6*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
 
@@ -675,7 +680,7 @@ void cairo_dock_register_default_renderer (void)
 {
 	CairoDockRenderer *pDefaultRenderer = g_new0 (CairoDockRenderer, 1);
 	pDefaultRenderer->cReadmeFilePath = g_strdup_printf ("%s/readme-default-view", GLDI_SHARE_DATA_DIR);
-	pDefaultRenderer->cPreviewFilePath = g_strdup_printf ("%s/preview-default.png", GLDI_SHARE_DATA_DIR);
+	pDefaultRenderer->cPreviewFilePath = g_strdup_printf ("%s/images/preview-default.png", GLDI_SHARE_DATA_DIR);
 	pDefaultRenderer->compute_size = cd_calculate_max_dock_size_default;
 	pDefaultRenderer->calculate_icons = cd_calculate_icons_default;
 	pDefaultRenderer->render = cd_render_default;
