@@ -30,10 +30,25 @@
 #include "cairo-dock-container.h"
 #include "cairo-dock-graph.h"
 
+typedef struct _Graph {
+	CairoDataRenderer dataRenderer;
+	CairoDockTypeGraph iType;
+	gdouble *fHighColor;  // iNbValues triplets (r,v,b).
+	gdouble *fLowColor;  // idem.
+	cairo_pattern_t **pGradationPatterns;  // iNbValues patterns.
+	gdouble fBackGroundColor[4];
+	cairo_surface_t *pBackgroundSurface;
+	GLuint iBackgroundTexture;
+	gint iRadius;
+	gint iMargin;
+	gboolean bMixGraphs;
+	} Graph;
+
+
 extern gboolean g_bUseOpenGL;
 
 
-void cairo_dock_render_graph (CairoDockGraph *pGraph, cairo_t *pCairoContext)
+static void render (Graph *pGraph, cairo_t *pCairoContext)
 {
 	g_return_if_fail (pGraph != NULL);
 	g_return_if_fail (pCairoContext != NULL && cairo_status (pCairoContext) == CAIRO_STATUS_SUCCESS);
@@ -52,13 +67,14 @@ void cairo_dock_render_graph (CairoDockGraph *pGraph, cairo_t *pCairoContext)
 	if (iNbDrawings == 0)
 		return;
 	
-	double fMargin = pGraph->fMargin;
-	double fWidth = pRenderer->iWidth - 2*fMargin;
-	double fHeight = pRenderer->iHeight - 2*fMargin;
-	fHeight /= iNbDrawings;
-
+	int iMargin = pGraph->iMargin;
+	int iWidth = pRenderer->iWidth - 2*iMargin;
+	int iHeight = pRenderer->iHeight - 2*iMargin;
+	iHeight /= iNbDrawings;
+	
 	double fValue;
 	cairo_pattern_t *pGradationPattern;
+	int t, n = MIN (pData->iMemorySize, iWidth);  // for iteration over the memorized values.
 	int i;
 	for (i = 0; i < iNbValues; i ++)
 	{
@@ -66,7 +82,7 @@ void cairo_dock_render_graph (CairoDockGraph *pGraph, cairo_t *pCairoContext)
 		if (! pGraph->bMixGraphs)
 			cairo_translate (pCairoContext,
 				0.,
-				i * fHeight);
+				i * iHeight);
 		pGradationPattern = pGraph->pGradationPatterns[i];
 		if (pGradationPattern != NULL)
 			cairo_set_source (pCairoContext, pGradationPattern);
@@ -76,83 +92,103 @@ void cairo_dock_render_graph (CairoDockGraph *pGraph, cairo_t *pCairoContext)
 				pGraph->fLowColor[3*i+1],
 				pGraph->fLowColor[3*i+2]);
 		
-		if (pGraph->iType == CAIRO_DOCK_GRAPH2_LINE || pGraph->iType == CAIRO_DOCK_GRAPH2_PLAIN)
+		switch (pGraph->iType)
 		{
-			cairo_set_line_width (pCairoContext, 1);
-			cairo_set_line_join (pCairoContext, CAIRO_LINE_JOIN_ROUND);
-			fValue = cairo_data_renderer_get_normalized_current_value (pRenderer, i);
-			cairo_move_to (pCairoContext, fMargin + fWidth, fMargin + (1 - fValue) * fHeight);
-			int t, n = pData->iMemorySize - 1;
-			for (t = 1; t < pData->iMemorySize; t ++)
-			{
-				fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
-				cairo_line_to (pCairoContext,
-					fMargin + (n - t) * fWidth / n,
-					fMargin + (1 - fValue) * fHeight);
-			}
-			if (pGraph->iType == CAIRO_DOCK_GRAPH2_PLAIN)
-			{
-				cairo_line_to (pCairoContext,
-					fMargin,
-					fMargin + fHeight);
-				cairo_line_to (pCairoContext,
-					fMargin + fWidth,
-					fMargin + fHeight);
-				cairo_close_path (pCairoContext);
-				cairo_fill_preserve (pCairoContext);
-			}
-			cairo_stroke (pCairoContext);
-		}
-		else if (pGraph->iType == CAIRO_DOCK_GRAPH2_BAR)
-		{
-			double fBarWidth = fWidth / pData->iMemorySize / 4;
-			cairo_set_line_width (pCairoContext, fBarWidth);
-			int t, n = pData->iMemorySize - 1;
-			for (t = 0; t < pData->iMemorySize; t ++)
-			{
-				fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
+			case CAIRO_DOCK_GRAPH_LINE:
+			case CAIRO_DOCK_GRAPH_PLAIN:
+			default :
+				cairo_set_line_width (pCairoContext, 1);
+				cairo_set_line_join (pCairoContext, CAIRO_LINE_JOIN_ROUND);
+				fValue = cairo_data_renderer_get_normalized_current_value (pRenderer, i);
+				if (fValue <= CAIRO_DATA_RENDERER_UNDEF_VALUE+1)  // undef value -> let's draw 0
+					fValue = 0;
 				cairo_move_to (pCairoContext,
-					fMargin + (n - t) * fWidth / n,
-					fMargin + fHeight);
-				cairo_rel_line_to (pCairoContext,
-					0.,
-					- fValue * fHeight);
+					iMargin + iWidth - .5,
+					iMargin + (1 - fValue) * iHeight - .5);
+				for (t = 1; t < n; t ++)
+				{
+					fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
+					if (fValue <= CAIRO_DATA_RENDERER_UNDEF_VALUE+1)  // undef value -> let's draw 0
+						fValue = 0;
+					cairo_line_to (pCairoContext,
+						iMargin + (n - t) * iWidth / n - .5,
+						iMargin + (1 - fValue) * iHeight - .5);
+				}
+				if (pGraph->iType == CAIRO_DOCK_GRAPH_PLAIN)
+				{
+					cairo_line_to (pCairoContext,
+						iMargin - .5,
+						iMargin + iHeight - .5);
+					cairo_rel_line_to (pCairoContext,
+						iWidth,
+						0.);
+					cairo_close_path (pCairoContext);
+					cairo_fill_preserve (pCairoContext);
+				}
 				cairo_stroke (pCairoContext);
-			}
-		}
-		else
-		{
-			cairo_set_line_width (pCairoContext, 1);
-			cairo_set_line_join (pCairoContext, CAIRO_LINE_JOIN_ROUND);
-			fValue = cairo_data_renderer_get_normalized_current_value (pRenderer, i);
-			double angle, radius = MIN (fWidth, fHeight)/2;
-			angle = -2*G_PI*(-.5/pData->iMemorySize);
-			cairo_move_to (pCairoContext,
-				fMargin + fWidth/2 + radius * (fValue * cos (angle)),
-				fMargin + fHeight/2 + radius * (fValue * sin (angle)));
-			angle = -2*G_PI*(.5/pData->iMemorySize);
-			cairo_line_to (pCairoContext,
-				fMargin + fWidth/2 + radius * (fValue * cos (angle)),
-				fMargin + fHeight/2 + radius * (fValue * sin (angle)));
-			int t;
-			for (t = 1; t < pData->iMemorySize; t ++)
+			break;
+			
+			case CAIRO_DOCK_GRAPH_BAR:
 			{
-				fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
-				angle = -2*G_PI*((t-.5)/pData->iMemorySize);
-				cairo_line_to (pCairoContext,
-					fMargin + fWidth/2 + radius * (fValue * cos (angle)),
-					fMargin + fHeight/2 + radius * (fValue * sin (angle)));
-				angle = -2*G_PI*((t+.5)/pData->iMemorySize);
-				cairo_line_to (pCairoContext,
-					fMargin + fWidth/2 + radius * (fValue * cos (angle)),
-					fMargin + fHeight/2 + radius * (fValue * sin (angle)));
+				///double fBarWidth = iWidth / pData->iMemorySize / 4;
+				double fBarWidth = 1;
+				cairo_set_line_width (pCairoContext, fBarWidth);
+				for (t = 1; t < n; t ++)
+				{
+					fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
+					if (fValue <= CAIRO_DATA_RENDERER_UNDEF_VALUE+1)  // undef value -> let's draw 0
+						fValue = 0;
+					if (fValue > 0)
+					{
+						cairo_move_to (pCairoContext,
+							iMargin + (n - t) * iWidth / n - .5,
+							iMargin + iHeight - .5);
+						cairo_rel_line_to (pCairoContext,
+							0.,
+							- fValue * iHeight);
+						cairo_stroke (pCairoContext);
+					}
+				}
 			}
-			if (pGraph->iType == CAIRO_DOCK_GRAPH2_CIRCLE_PLAIN)
-			{
-				cairo_close_path (pCairoContext);
-				cairo_fill_preserve (pCairoContext);
-			}
-			cairo_stroke (pCairoContext);
+			break;
+			
+			case CAIRO_DOCK_GRAPH_CIRCLE:
+			case CAIRO_DOCK_GRAPH_CIRCLE_PLAIN:
+				cairo_set_line_width (pCairoContext, 1);
+				cairo_set_line_join (pCairoContext, CAIRO_LINE_JOIN_ROUND);
+				fValue = cairo_data_renderer_get_normalized_current_value (pRenderer, i);
+				if (fValue <= CAIRO_DATA_RENDERER_UNDEF_VALUE+1)  // undef value -> let's draw 0
+					fValue = 0;
+				double angle, radius = MIN (iWidth, iHeight)/2;
+				angle = -2*G_PI*(-.5/pData->iMemorySize);
+				cairo_move_to (pCairoContext,
+					iMargin + iWidth/2 + radius * (fValue * cos (angle)),
+					iMargin + iHeight/2 + radius * (fValue * sin (angle)));
+				angle = -2*G_PI*(.5/pData->iMemorySize);
+				cairo_line_to (pCairoContext,
+					iMargin + iWidth/2 + radius * (fValue * cos (angle)),
+					iMargin + iHeight/2 + radius * (fValue * sin (angle)));
+				for (t = 1; t < n; t ++)
+				{
+					fValue = cairo_data_renderer_get_normalized_value (pRenderer, i, -t);
+					if (fValue <= CAIRO_DATA_RENDERER_UNDEF_VALUE+1)  // undef value -> let's draw 0
+						fValue = 0;
+					angle = -2*G_PI*((t-.5)/n);
+					cairo_line_to (pCairoContext,
+						iMargin + iWidth/2 + radius * (fValue * cos (angle)),
+						iMargin + iHeight/2 + radius * (fValue * sin (angle)));
+					angle = -2*G_PI*((t+.5)/n);
+					cairo_line_to (pCairoContext,
+						iMargin + iWidth/2 + radius * (fValue * cos (angle)),
+						iMargin + iHeight/2 + radius * (fValue * sin (angle)));
+				}
+				if (pGraph->iType == CAIRO_DOCK_GRAPH_CIRCLE_PLAIN)
+				{
+					cairo_close_path (pCairoContext);
+					cairo_fill_preserve (pCairoContext);
+				}
+				cairo_stroke (pCairoContext);
+			break;
 		}
 		cairo_restore (pCairoContext);
 		
@@ -160,7 +196,7 @@ void cairo_dock_render_graph (CairoDockGraph *pGraph, cairo_t *pCairoContext)
 	}
 }
 
-static void cairo_dock_render_graph_opengl (CairoDockGraph *pGraph)
+static void render_opengl (Graph *pGraph)
 {
 	g_return_if_fail (pGraph != NULL);
 	
@@ -180,7 +216,7 @@ static void cairo_dock_render_graph_opengl (CairoDockGraph *pGraph)
 }
 
 
-static inline cairo_surface_t *_cairo_dock_create_graph_background (double fWidth, double fHeight, int iRadius, double fMargin, gdouble *pBackGroundColor, CairoDockTypeGraph iType, int iNbDrawings)
+static inline cairo_surface_t *_cairo_dock_create_graph_background (double fWidth, double fHeight, int iRadius, int iMargin, gdouble *pBackGroundColor, CairoDockTypeGraph iType, int iNbDrawings)
 {
 	// on cree la surface.
 	cairo_surface_t *pBackgroundSurface = cairo_dock_create_blank_surface (
@@ -216,33 +252,35 @@ static inline cairo_surface_t *_cairo_dock_create_graph_background (double fWidt
 		myIconsParam.quickInfoTextDescription.fBackgroundColor[1],
 		myIconsParam.quickInfoTextDescription.fBackgroundColor[2]);  // meme couleur que le fond des info-rapides, mais opaque.
 	cairo_set_line_width (pCairoContext, 1.);
-	if (iType == CAIRO_DOCK_GRAPH2_CIRCLE || iType == CAIRO_DOCK_GRAPH2_CIRCLE_PLAIN)
+	if (iType == CAIRO_DOCK_GRAPH_CIRCLE || iType == CAIRO_DOCK_GRAPH_CIRCLE_PLAIN)
 	{
-		double r = .5 * MIN (fWidth - 2*fMargin, (fHeight - 2*fMargin) / iNbDrawings);
+		double r = .5 * MIN (fWidth - 2*iMargin, (fHeight - 2*iMargin) / iNbDrawings);
 		int i;
 		for (i = 0; i < iNbDrawings; i ++)
 		{
 			cairo_arc (pCairoContext,
 				fWidth/2,
-				fMargin + r * (2 * i + 1),
+				iMargin + r * (2 * i + 1),
 				r,
 				0.,
 				360.);
-			cairo_move_to (pCairoContext, fWidth/2, fMargin + r * (2 * i + 1));
+			cairo_move_to (pCairoContext, fWidth/2, iMargin + r * (2 * i + 1));
 			cairo_rel_line_to (pCairoContext, r, 0.);
 			cairo_stroke (pCairoContext);
 		}
 	}
 	else
 	{
-		cairo_move_to (pCairoContext, fMargin, fMargin);
-		cairo_rel_line_to (pCairoContext, 0., fHeight - 2*fMargin);
+		cairo_move_to (pCairoContext, iMargin-.5, iMargin-.5);
+		cairo_rel_line_to (pCairoContext, 0., fHeight - 2*iMargin);
 		cairo_stroke (pCairoContext);
 		int i;
 		for (i = 0; i < iNbDrawings; i ++)
 		{
-			cairo_move_to (pCairoContext, fMargin, (fHeight - 2 * fMargin) * (i + 1) / iNbDrawings + fMargin);
-			cairo_rel_line_to (pCairoContext, fWidth - 2*fMargin, 0.);
+			cairo_move_to (pCairoContext,
+				iMargin - .5,
+				floor ((fHeight - 2 * iMargin) * (i + 1) / iNbDrawings) + iMargin - .5);
+			cairo_rel_line_to (pCairoContext, fWidth - 2*iMargin, 0.);
 			cairo_stroke (pCairoContext);
 		}
 	}
@@ -250,31 +288,31 @@ static inline cairo_surface_t *_cairo_dock_create_graph_background (double fWidt
 	cairo_destroy (pCairoContext);
 	return  pBackgroundSurface;
 }
-static cairo_pattern_t *_cairo_dock_create_graph_pattern (CairoDockGraph *pGraph, gdouble *fLowColor, gdouble *fHighColor, double fOffsetY)
+static cairo_pattern_t *_cairo_dock_create_graph_pattern (Graph *pGraph, gdouble *fLowColor, gdouble *fHighColor, double fOffsetY)
 {
 	cairo_pattern_t *pGradationPattern = NULL;
 	if (fLowColor[0] != fHighColor[0] || fLowColor[1] != fHighColor[1] || fLowColor[2] != fHighColor[2])  // un degrade existe.
 	{
-		double fMargin = pGraph->fMargin;
-		double fWidth = pGraph->dataRenderer.iWidth - 2*fMargin;
-		double fHeight = pGraph->dataRenderer.iHeight - 2*fMargin;
+		int iMargin = pGraph->iMargin;
+		double fWidth = pGraph->dataRenderer.iWidth - 2*iMargin;
+		double fHeight = pGraph->dataRenderer.iHeight - 2*iMargin;
 		fHeight /= (pGraph->dataRenderer.data.iNbValues / pGraph->dataRenderer.iRank);
 		
-		if (pGraph->iType == CAIRO_DOCK_GRAPH2_CIRCLE || pGraph->iType == CAIRO_DOCK_GRAPH2_CIRCLE_PLAIN)
+		if (pGraph->iType == CAIRO_DOCK_GRAPH_CIRCLE || pGraph->iType == CAIRO_DOCK_GRAPH_CIRCLE_PLAIN)
 		{
-			double radius = MIN (fWidth, fHeight)/2;
+			double radius = MIN (fWidth, fHeight)/2.;
 			pGradationPattern = cairo_pattern_create_radial (fWidth/2,
-				fMargin + radius + fOffsetY,
+				iMargin + radius + fOffsetY,
 				0.,
 				fWidth/2,
-				fMargin + radius + fOffsetY,
+				iMargin + radius + fOffsetY,
 				radius);
 		}
 		else
 			pGradationPattern = cairo_pattern_create_linear (0.,
-				fMargin + fHeight + fOffsetY,
+				iMargin + fHeight + fOffsetY,
 				0.,
-				fMargin + fOffsetY);
+				iMargin + fOffsetY);
 		g_return_val_if_fail (cairo_pattern_status (pGradationPattern) == CAIRO_STATUS_SUCCESS, NULL);	
 		
 		cairo_pattern_set_extend (pGradationPattern, CAIRO_EXTEND_PAD);
@@ -296,7 +334,7 @@ static cairo_pattern_t *_cairo_dock_create_graph_pattern (CairoDockGraph *pGraph
 #define dc .5
 #define _guess_color(i) (((pGraph->fLowColor[i] < pGraph->fHighColor[i] && pGraph->fLowColor[i] > dc) || pGraph->fLowColor[i] > 1-dc) ? pGraph->fLowColor[i] - dc : pGraph->fLowColor[i] + dc)
 //#define _guess_color(i) (1. - pGraph->fLowColor[i])
-static void _set_overlay_zones (CairoDockGraph *pGraph)
+static void _set_overlay_zones (Graph *pGraph)
 {
 	CairoDataRenderer *pRenderer = CAIRO_DATA_RENDERER (pGraph);
 	int iNbValues = cairo_data_renderer_get_nb_values (pRenderer);
@@ -305,10 +343,10 @@ static void _set_overlay_zones (CairoDockGraph *pGraph)
 	
 	// on complete le data-renderer.
 	int iNbDrawings = iNbValues / pRenderer->iRank;
-	double fMargin = pGraph->fMargin;
-	double fOneGraphHeight = iHeight - 2*fMargin;
+	int iMargin = pGraph->iMargin;
+	double fOneGraphHeight = iHeight - 2*iMargin;
 	fOneGraphHeight /= iNbDrawings;
-	double fOneGraphWidth = iWidth - 2*fMargin;
+	double fOneGraphWidth = iWidth - 2*iMargin;
 	fOneGraphWidth /= iNbDrawings;
 	int iTextWidth = MIN (48, pRenderer->iWidth/2);  // on definit une taille pour les zones de texte.
 	int iTextHeight = MIN (16, fOneGraphHeight/1.5);
@@ -328,20 +366,20 @@ static void _set_overlay_zones (CairoDockGraph *pGraph)
 			{
 				if (pGraph->bMixGraphs)
 				{
-					pLabel->param.fX = (double)(fMargin + i * fOneGraphWidth + iLabelWidth/2) / iWidth - .5;
-					pLabel->param.fY = (double)(iHeight - fMargin - iLabelHeight/2) / iHeight - .5;
+					pLabel->param.fX = (double)(iMargin + i * fOneGraphWidth + iLabelWidth/2) / iWidth - .5;
+					pLabel->param.fY = (double)(iHeight - iMargin - iLabelHeight/2) / iHeight - .5;
 				}
 				else
 				{
-					pLabel->param.fX = (double) (fMargin + iLabelWidth/2) / iWidth - .5;
-					pLabel->param.fY = .5 - (double)(fMargin + h + i * fOneGraphHeight + iLabelHeight/2) / iHeight;
+					pLabel->param.fX = (double) (iMargin + iLabelWidth/2) / iWidth - .5;
+					pLabel->param.fY = .5 - (double)(iMargin + h + i * fOneGraphHeight + iLabelHeight/2) / iHeight;
 				}
 				pLabel->param.fWidth = (double)iLabelWidth / iWidth;
 				pLabel->param.fHeight = (double)iLabelHeight / iHeight;
-				pLabel->param.pColor[0] = myIconsParam.quickInfoTextDescription.fBackgroundColor[0];
-				pLabel->param.pColor[1] = myIconsParam.quickInfoTextDescription.fBackgroundColor[1];
-				pLabel->param.pColor[2] = myIconsParam.quickInfoTextDescription.fBackgroundColor[2];
-				pLabel->param.pColor[3] = 1.;  // meme couleur que les axes.
+				pLabel->param.pColor[0] = 1.;
+                pLabel->param.pColor[1] = 1.;
+                pLabel->param.pColor[2] = 1.;
+                pLabel->param.pColor[3] = 1.;  // white, a little transparent
 			}
 			else
 			{
@@ -353,13 +391,13 @@ static void _set_overlay_zones (CairoDockGraph *pGraph)
 			pValuesText = &pRenderer->pValuesText[i];
 			if (pGraph->bMixGraphs)
 			{
-				pValuesText->fX = (double)(fMargin + i * fOneGraphWidth + iTextWidth/2) / iWidth - .5;
-				pValuesText->fY = (double)(fMargin + h + iTextHeight/2) / iHeight - .5;
+				pValuesText->fX = (double)(iMargin + i * fOneGraphWidth + iTextWidth/2) / iWidth - .5;
+				pValuesText->fY = (double)(iMargin + h + iTextHeight/2) / iHeight - .5;
 			}
 			else
 			{
 				pValuesText->fX = (double)0.;  // centered.
-				pValuesText->fY = .5 - (double)(fMargin + (i+1) * fOneGraphHeight - iTextHeight/2 - h) / iHeight;
+				pValuesText->fY = .5 - (double)(iMargin + (i+1) * fOneGraphHeight - iTextHeight/2 - h) / iHeight;
 			}
 			pValuesText->fWidth = (double)iTextWidth / iWidth;
 			pValuesText->fHeight = (double)iTextHeight / iHeight;
@@ -383,7 +421,7 @@ static void _set_overlay_zones (CairoDockGraph *pGraph)
 	}
 }
 
-static void cairo_dock_load_graph (CairoDockGraph *pGraph, CairoContainer *pContainer, CairoGraphAttribute *pAttribute)
+static void load (Graph *pGraph, CairoContainer *pContainer, CairoGraphAttribute *pAttribute)
 {
 	CairoDataRenderer *pRenderer = CAIRO_DATA_RENDERER (pGraph);
 	
@@ -413,15 +451,15 @@ static void cairo_dock_load_graph (CairoDockGraph *pGraph, CairoContainer *pCont
 			0.);
 	}
 	
-	pGraph->iRadius = MAX (pAttribute->iRadius, MIN (iWidth, iHeight)/3.);
-	pGraph->fMargin = pGraph->iRadius * (1. - sqrt(2)/2);
+	pGraph->iRadius = MIN (iWidth, iHeight)/12.;
+	pGraph->iMargin = pGraph->iRadius * (1. - sqrt(2)/2);
 	if (pAttribute->fBackGroundColor != NULL)
 		memcpy (pGraph->fBackGroundColor, pAttribute->fBackGroundColor, 4 * sizeof (double));
 	pGraph->pBackgroundSurface = _cairo_dock_create_graph_background (
 		iWidth,
 		iHeight,
 		pGraph->iRadius,
-		pGraph->fMargin,
+		pGraph->iMargin,
 		pGraph->fBackGroundColor,
 		pGraph->iType,
 		iNbValues / pRenderer->iRank);
@@ -433,14 +471,16 @@ static void cairo_dock_load_graph (CairoDockGraph *pGraph, CairoContainer *pCont
 }
 
 
-static void cairo_dock_reload_graph (CairoDockGraph *pGraph)
+static void reload (Graph *pGraph)
 {
 	CairoDataRenderer *pRenderer = CAIRO_DATA_RENDERER (pGraph);
 	int iNbValues = cairo_data_renderer_get_nb_values (pRenderer);
 	int iWidth = pRenderer->iWidth, iHeight = pRenderer->iHeight;
+	pGraph->iRadius = MIN (iWidth, iHeight)/12.;
+	pGraph->iMargin = pGraph->iRadius * (1. - sqrt(2)/2);
 	if (pGraph->pBackgroundSurface != NULL)
 		cairo_surface_destroy (pGraph->pBackgroundSurface);
-	pGraph->pBackgroundSurface = _cairo_dock_create_graph_background (iWidth, iHeight, pGraph->iRadius, pGraph->fMargin, pGraph->fBackGroundColor, pGraph->iType, iNbValues / pRenderer->iRank);
+	pGraph->pBackgroundSurface = _cairo_dock_create_graph_background (iWidth, iHeight, pGraph->iRadius, pGraph->iMargin, pGraph->fBackGroundColor, pGraph->iType, iNbValues / pRenderer->iRank);
 	if (pGraph->iBackgroundTexture != 0)
 		_cairo_dock_delete_texture (pGraph->iBackgroundTexture);
 	if (g_bUseOpenGL && 0)
@@ -460,7 +500,7 @@ static void cairo_dock_reload_graph (CairoDockGraph *pGraph)
 }
 
 
-static void cairo_dock_unload_graph (CairoDockGraph *pGraph)
+static void unload (Graph *pGraph)
 {
 	cd_debug ("");
 	if (pGraph->pBackgroundSurface != NULL)
@@ -490,12 +530,12 @@ static void cairo_dock_unload_graph (CairoDockGraph *pGraph)
 void cairo_dock_register_data_renderer_graph (void)
 {
 	CairoDockDataRendererRecord *pRecord = g_new0 (CairoDockDataRendererRecord, 1);
-	pRecord->interface.load			= (CairoDataRendererLoadFunc) cairo_dock_load_graph;
-	pRecord->interface.render		= (CairoDataRendererRenderFunc) cairo_dock_render_graph;
+	pRecord->interface.load			= (CairoDataRendererLoadFunc) load;
+	pRecord->interface.render		= (CairoDataRendererRenderFunc) render;
 	pRecord->interface.render_opengl	= (CairoDataRendererRenderOpenGLFunc) NULL;
-	pRecord->interface.reload		= (CairoDataRendererReloadFunc) cairo_dock_reload_graph;
-	pRecord->interface.unload		= (CairoDataRendererUnloadFunc) cairo_dock_unload_graph;
-	pRecord->iStructSize			= sizeof (CairoDockGraph);
+	pRecord->interface.reload		= (CairoDataRendererReloadFunc) reload;
+	pRecord->interface.unload		= (CairoDataRendererUnloadFunc) unload;
+	pRecord->iStructSize			= sizeof (Graph);
 	pRecord->cThemeDirName = NULL;
 	pRecord->cDefaultTheme = NULL;
 	
